@@ -102,7 +102,7 @@ class KNotifyPrivate
 #endif
 
 extern "C"{
-	KDE_EXPORT int kdemain(int argc, char **argv) {
+	TDE_EXPORT int kdemain(int argc, char **argv) {
 		TDEAboutData aboutdata("knotify", I18N_NOOP("KNotify"),
 					"3.0", I18N_NOOP("TDE Notification Server"),
 					TDEAboutData::License_GPL, "(C) 1997-2003, KDE Developers");
