@@ -29,7 +29,7 @@ struct BoardInfo
 
 class LotsaEdits : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
@@ -50,7 +50,7 @@ class LotsaEdits : public TQWidget
 
 class BoardInfoDlg : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
