@@ -20,7 +20,7 @@
 #ifndef TQMAKE_LEX_H
 #define TQMAKE_LEX_H
 
-#include "qmake_yacc.hpp"
+#include "qmake_yacc.h"
 #include <iostream>
 
 #ifndef DONT_INCLUDE_FLEXLEXER
