@@ -31,7 +31,7 @@ namespace Cervisia
 
 class CvsInitDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
