@@ -119,7 +119,7 @@ AlarmDaemon::AlarmDaemon(bool autostart, TQObject *parent, const char *name)
 					}
 				}
 			// Give some extra time to KAlarm to be fully restored, then proceed as usual
-			TQTimer::singleShot(3000, this, TQT_SLOT(autostartKAlarm()));
+			TQTimer::singleShot(3000, this, TQ_SLOT(autostartKAlarm()));
 			}
 		}
 	}
@@ -168,7 +168,7 @@ void AlarmDaemon::startMonitoring()
 {
 	// Set up the alarm timer
 	mAlarmTimer = new TQTimer(this);
-	connect(mAlarmTimer, TQT_SIGNAL(timeout()), TQT_SLOT(checkAlarmsSlot()));
+	connect(mAlarmTimer, TQ_SIGNAL(timeout()), TQ_SLOT(checkAlarmsSlot()));
 	setTimerStatus();
 
 	// Start monitoring calendar files.
@@ -216,7 +216,7 @@ void AlarmDaemon::reloadCal(ADCalendar* cal, bool reset)
 	{
 		cal->close();
 		if (!cal->setLoadedConnected())
-			connect(cal, TQT_SIGNAL(loaded(ADCalendar*, bool)), TQT_SLOT(calendarLoaded(ADCalendar*, bool)));
+			connect(cal, TQ_SIGNAL(loaded(ADCalendar*, bool)), TQ_SLOT(calendarLoaded(ADCalendar*, bool)));
 		cal->loadFile(reset);
 	}
 	else if (reset)
