@@ -74,8 +74,8 @@ Kalzium::Kalzium()
 	m_infoDialog = 0;
 	m_toolboxCurrent = 0;
 
-	connect( m_PerodicTableView, TQT_SIGNAL( ElementClicked( int ) ), TQT_TQOBJECT(this), TQT_SLOT( openInformationDialog( int ) ));
-	connect( m_PerodicTableView, TQT_SIGNAL( MouseOver( int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotStatusbar( int ) ));
+	connect( m_PerodicTableView, TQ_SIGNAL( ElementClicked( int ) ), this, TQ_SLOT( openInformationDialog( int ) ));
+	connect( m_PerodicTableView, TQ_SIGNAL( MouseOver( int ) ), this, TQ_SLOT( slotStatusbar( int ) ));
 	
 	// layouting
 	setCentralWidget( centralWidget );
@@ -107,14 +107,14 @@ Kalzium::Kalzium()
 
 void Kalzium::setupActions()
 {
-	m_actionNoScheme = new TDEToggleAction(i18n("&No Color Scheme"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotNoLook()), actionCollection(), "view_look_noscheme");
+	m_actionNoScheme = new TDEToggleAction(i18n("&No Color Scheme"), 0, this, TQ_SLOT(slotNoLook()), actionCollection(), "view_look_noscheme");
 
 	// the actions for the color schemes
-	m_actionGroups = new TDEToggleAction(i18n("Show &Groups"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotLookGroups()), actionCollection(), "view_look_groups");
-	m_actionBlocks = new TDEToggleAction(i18n("Show &Blocks"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotLookBlocks()), actionCollection(), "view_look_blocks");
-	m_actionAcid = new TDEToggleAction(i18n("Show &Acid Behavior"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotLookAcidBehavior()), actionCollection(), "view_look_acid");
-	m_actionFamily = new TDEToggleAction(i18n("Show &Family"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotLookFamily()), actionCollection(), "view_look_family");
-	m_actionCrystal = new TDEToggleAction(i18n("Show &Crystal Structures"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotLookCrystal()), actionCollection(), "view_look_crystal");
+	m_actionGroups = new TDEToggleAction(i18n("Show &Groups"), 0, this, TQ_SLOT(slotLookGroups()), actionCollection(), "view_look_groups");
+	m_actionBlocks = new TDEToggleAction(i18n("Show &Blocks"), 0, this, TQ_SLOT(slotLookBlocks()), actionCollection(), "view_look_blocks");
+	m_actionAcid = new TDEToggleAction(i18n("Show &Acid Behavior"), 0, this, TQ_SLOT(slotLookAcidBehavior()), actionCollection(), "view_look_acid");
+	m_actionFamily = new TDEToggleAction(i18n("Show &Family"), 0, this, TQ_SLOT(slotLookFamily()), actionCollection(), "view_look_family");
+	m_actionCrystal = new TDEToggleAction(i18n("Show &Crystal Structures"), 0, this, TQ_SLOT(slotLookCrystal()), actionCollection(), "view_look_crystal");
 
 	//the actions for switching PerodicTableView
 	TQStringList gradientlist;
@@ -127,9 +127,9 @@ void Kalzium::setupActions()
 	gradientlist.append(i18n("Melting Point"));
 	gradientlist.append(i18n("Electronegativity"));
 	gradientlist.append(i18n("Electron Affinity"));
-	gradient_action = new TDESelectAction(i18n("&Gradient"), 0, TQT_TQOBJECT(this), 0, actionCollection(), "view_look_gradmenu");
+	gradient_action = new TDESelectAction(i18n("&Gradient"), 0, this, 0, actionCollection(), "view_look_gradmenu");
 	gradient_action->setItems(gradientlist);
-	connect (gradient_action, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSwitchtoGradient(int)));
+	connect (gradient_action, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSwitchtoGradient(int)));
 
 	// the actions for switching PerodicTableView
 	TQStringList numlist;
@@ -137,28 +137,28 @@ void Kalzium::setupActions()
 	numlist.append(i18n("Show &IUPAC"));
 	numlist.append(i18n("Show &CAS"));
 	numlist.append(i18n("Show &Old IUPAC"));
-	numeration_action = new TDESelectAction (i18n("&Numeration"), 0, TQT_TQOBJECT(this), 0, actionCollection(), "view_numerationtype");
+	numeration_action = new TDESelectAction (i18n("&Numeration"), 0, this, 0, actionCollection(), "view_numerationtype");
 	numeration_action->setItems(numlist);
 	numeration_action->setCurrentItem(Prefs::numeration()); 
-	connect (numeration_action, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSwitchtoNumeration(int)));
+	connect (numeration_action, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSwitchtoNumeration(int)));
 
-	m_SidebarAction = new TDEAction(i18n("Show &Sidebar"), "sidebar", 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowHideSidebar()), actionCollection(), "view_sidebar");
+	m_SidebarAction = new TDEAction(i18n("Show &Sidebar"), "sidebar", 0, this, TQ_SLOT(slotShowHideSidebar()), actionCollection(), "view_sidebar");
 	
 #ifdef HAVE_FACILE
-	m_EQSolverAction = new TDEAction(i18n("&Equation Solver..."), "eqchem", 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowEQSolver()), actionCollection(), "tools_eqsolver");
+	m_EQSolverAction = new TDEAction(i18n("&Equation Solver..."), "eqchem", 0, this, TQ_SLOT(slotShowEQSolver()), actionCollection(), "tools_eqsolver");
 #endif
 	
 	// tools actions
-	m_pPlotAction = new TDEAction(i18n("&Plot Data..."), "plot", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlotData()), actionCollection(), "tools_plotdata");
-	m_pGlossaryAction = new TDEAction(i18n("&Glossary..."), "glossary", 0, TQT_TQOBJECT(this), TQT_SLOT(slotGlossary()), actionCollection(), "tools_glossary");
+	m_pPlotAction = new TDEAction(i18n("&Plot Data..."), "plot", 0, this, TQ_SLOT(slotPlotData()), actionCollection(), "tools_plotdata");
+	m_pGlossaryAction = new TDEAction(i18n("&Glossary..."), "glossary", 0, this, TQ_SLOT(slotGlossary()), actionCollection(), "tools_glossary");
 
 	// other period view options
-	m_pLegendAction = new TDEAction(i18n("Show &Legend"), "legend", 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowLegend()), actionCollection(), "view_legend");
-	m_pTooltipAction = new TDEAction(i18n("Show &Tooltip"), "tooltip", 0, TQT_TQOBJECT(this), TQT_SLOT(slotEnableTooltips()), actionCollection(), "view_tooltip");
+	m_pLegendAction = new TDEAction(i18n("Show &Legend"), "legend", 0, this, TQ_SLOT(slotShowLegend()), actionCollection(), "view_legend");
+	m_pTooltipAction = new TDEAction(i18n("Show &Tooltip"), "tooltip", 0, this, TQ_SLOT(slotEnableTooltips()), actionCollection(), "view_tooltip");
 	
 	// the standard actions
-	KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(showSettingsDialog()), actionCollection());
-	KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT (closeAllWindows()),actionCollection() );
+	KStdAction::preferences(this, TQ_SLOT(showSettingsDialog()), actionCollection());
+	KStdAction::quit(kapp, TQ_SLOT (closeAllWindows()),actionCollection() );
 
 	slotShowScheme( Prefs::colorschemebox() );
 	slotSwitchtoNumeration( Prefs::numeration() );
@@ -213,7 +213,7 @@ void Kalzium::setupSidebars()
 	lay->activate();
 	m_detailWidget = new DetailedGraphicalOverview( fake, "DetailedGraphicalOverview" );
 	m_detailWidget->setMinimumSize( 200, m_detailWidget->minimumSize().height() );
-	connect( m_PerodicTableView, TQT_SIGNAL( MouseOver( int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotSelectedNumber( int ) ));
+	connect( m_PerodicTableView, TQ_SIGNAL( MouseOver( int ) ), this, TQ_SLOT( slotSelectedNumber( int ) ));
  	lay->addWidget( m_detailWidget );
 	lay->addItem( new TQSpacerItem( 10, 10, TQSizePolicy::Fixed, TQSizePolicy::MinimumExpanding ) );
 	m_toolbox->addItem( fake, SmallIcon( "overview" ), i18n( "Overview" ) );
@@ -222,26 +222,26 @@ void Kalzium::setupSidebars()
 	m_toolbox->addItem( m_calcWidget, SmallIcon( "calculate" ), i18n( "Calculate" ) );
 
 	m_timeWidget = new TimeWidgetIMPL( this, "TimeWidget" );
-	connect( m_timeWidget->time_slider, TQT_SIGNAL( valueChanged( int ) ),
-	         m_PerodicTableView, TQT_SLOT( setDate( int ) ) );
-	connect( m_timeWidget->time_slider, TQT_SIGNAL( valueChanged( int ) ),
-	         m_timeWidget, TQT_SLOT( slotChanged( int ) ) );
-	connect( m_timeWidget->Number1, TQT_SIGNAL( valueChanged( int ) ),
-	         m_timeWidget, TQT_SLOT( slotChanged( int ) ) );
+	connect( m_timeWidget->time_slider, TQ_SIGNAL( valueChanged( int ) ),
+	         m_PerodicTableView, TQ_SLOT( setDate( int ) ) );
+	connect( m_timeWidget->time_slider, TQ_SIGNAL( valueChanged( int ) ),
+	         m_timeWidget, TQ_SLOT( slotChanged( int ) ) );
+	connect( m_timeWidget->Number1, TQ_SIGNAL( valueChanged( int ) ),
+	         m_timeWidget, TQ_SLOT( slotChanged( int ) ) );
 	m_toolbox->addItem( m_timeWidget, SmallIcon( "timeline" ), i18n( "Timeline" ) );
 
 	m_somWidget = new SOMWidgetIMPL( this, "somWidget" );
-	connect( m_somWidget->temp_slider, TQT_SIGNAL( valueChanged( int ) ),
-	         m_PerodicTableView, TQT_SLOT( setTemperature( int ) ) );
+	connect( m_somWidget->temp_slider, TQ_SIGNAL( valueChanged( int ) ),
+	         m_PerodicTableView, TQ_SLOT( setTemperature( int ) ) );
 	m_toolbox->addItem( m_somWidget, SmallIcon( "statematter" ), i18n( "State of Matter" ) );
 	
-	connect( m_toolbox, TQT_SIGNAL( currentChanged( int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotToolboxCurrentChanged( int ) ) );
+	connect( m_toolbox, TQ_SIGNAL( currentChanged( int ) ), this, TQ_SLOT( slotToolboxCurrentChanged( int ) ) );
 
 	moveDockWindow( m_dockWin, DockLeft );
 	setDockEnabled( /*m_dockWin, */DockTop, false );
 	setDockEnabled( /*m_dockWin, */DockBottom, false );
 	m_dockWin->hide();
-	connect( m_dockWin, TQT_SIGNAL(visibilityChanged(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotSidebarVisibilityChanged(bool)));
+	connect( m_dockWin, TQ_SIGNAL(visibilityChanged(bool)), this, TQ_SLOT(slotSidebarVisibilityChanged(bool)));
 
 }
 
@@ -263,7 +263,7 @@ void Kalzium::slotShowEQSolver()
 	eqsolver->setMinimumSize( 600,400 );
 
 	vbox->addWidget( eqsolver );
-        connect(dlg, TQT_SIGNAL(applyClicked()), eqsolver, TQT_SLOT(compute()));
+        connect(dlg, TQ_SIGNAL(applyClicked()), eqsolver, TQ_SLOT(compute()));
 	dlg->show();
 #endif
 }
@@ -398,8 +398,8 @@ void Kalzium::showSettingsDialog()
 
 	//TDEConfigDialog didn't find an instance of this dialog, so lets create it :
 	TDEConfigDialog *dialog = new TDEConfigDialog(this,"settings", Prefs::self());
-	connect( dialog, TQT_SIGNAL( settingsChanged() ), this , TQT_SLOT( slotUpdateSettings() ) );
-	connect( dialog, TQT_SIGNAL( settingsChanged() ), m_somWidget, TQT_SLOT( reloadUnits() ) );
+	connect( dialog, TQ_SIGNAL( settingsChanged() ), this , TQ_SLOT( slotUpdateSettings() ) );
+	connect( dialog, TQ_SIGNAL( settingsChanged() ), m_somWidget, TQ_SLOT( reloadUnits() ) );
 	dialog->addPage( new setColors( 0, "colors_page"), i18n("Colors"), "colorize");
 	dialog->addPage( new setupUnits( 0, "units_page"), i18n("Units"), "gear");
 	dialog->addPage( new setupMisc( 0, "miscpage" ), i18n( "Miscellaneous" ), "misc" );
@@ -440,10 +440,10 @@ void Kalzium::openInformationDialog( int number )
 			                        this, "detailedDlg" );
 
 			// Remove the selection when this dialog finishes or hides.
-			connect(m_infoDialog, TQT_SIGNAL(hidden()),
-			        m_PerodicTableView,        TQT_SLOT(unSelect()));
-			connect(m_infoDialog, TQT_SIGNAL(elementChanged(int)),
-			        m_PerodicTableView,        TQT_SLOT(selectElement(int)));
+			connect(m_infoDialog, TQ_SIGNAL(hidden()),
+			        m_PerodicTableView,        TQ_SLOT(unSelect()));
+			connect(m_infoDialog, TQ_SIGNAL(elementChanged(int)),
+			        m_PerodicTableView,        TQ_SLOT(selectElement(int)));
 		}
 		m_infoDialog->show();
 	}
