@@ -251,7 +251,7 @@ class LeitnerSystem;
 
 class KEduVocDocument : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   friend class KEduVocKvtmlWriter;
   friend class KEduVocKvtmlReader;
