@@ -328,15 +328,15 @@ void KateSuperRange::init()
   setBehaviour(DoNotExpand);
 
   // Not necessarily the best implementation
-  connect(m_start, TQT_SIGNAL(positionDirectlyChanged()),  TQT_SIGNAL(contentsChanged()));
-  connect(m_end, TQT_SIGNAL(positionDirectlyChanged()),  TQT_SIGNAL(contentsChanged()));
+  connect(m_start, TQ_SIGNAL(positionDirectlyChanged()),  TQ_SIGNAL(contentsChanged()));
+  connect(m_end, TQ_SIGNAL(positionDirectlyChanged()),  TQ_SIGNAL(contentsChanged()));
 
-  connect(m_start, TQT_SIGNAL(positionChanged()),  TQT_SLOT(slotEvaluateChanged()));
-  connect(m_end, TQT_SIGNAL(positionChanged()),  TQT_SLOT(slotEvaluateChanged()));
-  connect(m_start, TQT_SIGNAL(positionUnChanged()), TQT_SLOT(slotEvaluateUnChanged()));
-  connect(m_end, TQT_SIGNAL(positionUnChanged()), TQT_SLOT(slotEvaluateUnChanged()));
-  connect(m_start, TQT_SIGNAL(positionDeleted()), TQT_SIGNAL(boundaryDeleted()));
-  connect(m_end, TQT_SIGNAL(positionDeleted()), TQT_SIGNAL(boundaryDeleted()));
+  connect(m_start, TQ_SIGNAL(positionChanged()),  TQ_SLOT(slotEvaluateChanged()));
+  connect(m_end, TQ_SIGNAL(positionChanged()),  TQ_SLOT(slotEvaluateChanged()));
+  connect(m_start, TQ_SIGNAL(positionUnChanged()), TQ_SLOT(slotEvaluateUnChanged()));
+  connect(m_end, TQ_SIGNAL(positionUnChanged()), TQ_SLOT(slotEvaluateUnChanged()));
+  connect(m_start, TQ_SIGNAL(positionDeleted()), TQ_SIGNAL(boundaryDeleted()));
+  connect(m_end, TQ_SIGNAL(positionDeleted()), TQ_SIGNAL(boundaryDeleted()));
 }
 
 KateSuperRange::~KateSuperRange()
@@ -581,8 +581,8 @@ void KateSuperRangeList::connectAll()
   if (!m_connect) {
     m_connect = true;
     for (KateSuperRange* range = first(); range; range = next()) {
-      connect(range, TQT_SIGNAL(destroyed(TQObject*)), TQT_SLOT(slotDeleted(TQObject*)));
-      connect(range, TQT_SIGNAL(eliminated()), TQT_SLOT(slotEliminated()));
+      connect(range, TQ_SIGNAL(destroyed(TQObject*)), TQ_SLOT(slotDeleted(TQObject*)));
+      connect(range, TQ_SIGNAL(eliminated()), TQ_SLOT(slotEliminated()));
     }
   }
 }
@@ -727,9 +727,9 @@ int KateSuperRangeList::compareItems(TQPtrCollection::Item item1, TQPtrCollectio
 TQPtrCollection::Item KateSuperRangeList::newItem(TQPtrCollection::Item d)
 {
   if (m_connect) {
-    connect(static_cast<KateSuperRange*>(d), TQT_SIGNAL(destroyed(TQObject*)), TQT_SLOT(slotDeleted(TQObject*)));
-    connect(static_cast<KateSuperRange*>(d), TQT_SIGNAL(eliminated()), TQT_SLOT(slotEliminated()));
-    connect(static_cast<KateSuperRange*>(d), TQT_SIGNAL(tagRange(KateSuperRange*)), TQT_SIGNAL(tagRange(KateSuperRange*)));
+    connect(static_cast<KateSuperRange*>(d), TQ_SIGNAL(destroyed(TQObject*)), TQ_SLOT(slotDeleted(TQObject*)));
+    connect(static_cast<KateSuperRange*>(d), TQ_SIGNAL(eliminated()), TQ_SLOT(slotEliminated()));
+    connect(static_cast<KateSuperRange*>(d), TQ_SIGNAL(tagRange(KateSuperRange*)), TQ_SIGNAL(tagRange(KateSuperRange*)));
 
     // HACK HACK
     static_cast<KateSuperRange*>(d)->slotTagRange();
