@@ -115,7 +115,7 @@ void CatalogManager::init()
     _foundFilesList.clear();
     _toBeSearched.clear();
     _timerFind = new TQTimer( this );
-    connect(_timerFind, TQT_SIGNAL( timeout() ), TQT_TQOBJECT(this), TQT_SLOT(findNextFile()) );
+    connect(_timerFind, TQ_SIGNAL( timeout() ), this, TQ_SLOT(findNextFile()) );
     _searchStopped = false;
 
    _prefDialog=0;
@@ -132,8 +132,8 @@ void CatalogManager::init()
 	_project = KBabel::ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
    }
    
-   connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	, TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+   connect( _project, TQ_SIGNAL (signalCatManSettingsChanged())
+	, this, TQ_SLOT (updateSettings()));
 
    TQWidget *view = new TQWidget(this);
    TQVBoxLayout* layout= new TQVBoxLayout(view);
@@ -144,20 +144,20 @@ void CatalogManager::init()
    layout->addWidget(_catalogManager);
    layout->setStretchFactor(_catalogManager,1);
 
-   connect(this,TQT_SIGNAL(settingsChanged(KBabel::CatManSettings))
-            ,TQT_TQOBJECT(_catalogManager),TQT_SLOT(setSettings(KBabel::CatManSettings)));
-   connect(_catalogManager,TQT_SIGNAL(openFile(TQString,TQString))
-           ,this,TQT_SLOT(openFile(TQString,TQString)));
-   connect(_catalogManager,TQT_SIGNAL(openFileInNewWindow(TQString,TQString))
-           ,this,TQT_SLOT(openFileInNewWindow(TQString,TQString)));
-   connect(_catalogManager,TQT_SIGNAL(openTemplate(TQString,TQString,TQString))
-           ,this,TQT_SLOT(openTemplate(TQString,TQString,TQString)));
-   connect(_catalogManager,TQT_SIGNAL(openTemplateInNewWindow(TQString,TQString,TQString))
-           ,this,TQT_SLOT(openTemplateInNewWindow(TQString,TQString,TQString)));
-   connect(_catalogManager,TQT_SIGNAL(gotoFileEntry(TQString,TQString,int))
-           ,this,TQT_SLOT(openFile(TQString,TQString,int)));
-   connect(_catalogManager, TQT_SIGNAL(selectedChanged(uint)),
-           TQT_TQOBJECT(this), TQT_SLOT(selectedChanged(uint)));
+   connect(this,TQ_SIGNAL(settingsChanged(KBabel::CatManSettings))
+            ,_catalogManager,TQ_SLOT(setSettings(KBabel::CatManSettings)));
+   connect(_catalogManager,TQ_SIGNAL(openFile(TQString,TQString))
+           ,this,TQ_SLOT(openFile(TQString,TQString)));
+   connect(_catalogManager,TQ_SIGNAL(openFileInNewWindow(TQString,TQString))
+           ,this,TQ_SLOT(openFileInNewWindow(TQString,TQString)));
+   connect(_catalogManager,TQ_SIGNAL(openTemplate(TQString,TQString,TQString))
+           ,this,TQ_SLOT(openTemplate(TQString,TQString,TQString)));
+   connect(_catalogManager,TQ_SIGNAL(openTemplateInNewWindow(TQString,TQString,TQString))
+           ,this,TQ_SLOT(openTemplateInNewWindow(TQString,TQString,TQString)));
+   connect(_catalogManager,TQ_SIGNAL(gotoFileEntry(TQString,TQString,int))
+           ,this,TQ_SLOT(openFile(TQString,TQString,int)));
+   connect(_catalogManager, TQ_SIGNAL(selectedChanged(uint)),
+           this, TQ_SLOT(selectedChanged(uint)));
 
    KWin::setIcons(winId(),BarIcon("catalogmanager",32)
            ,SmallIcon("catalogmanager"));
@@ -172,20 +172,20 @@ void CatalogManager::init()
    _progressLabel->hide();
    _progressBar->hide();
 
-   connect(_catalogManager,TQT_SIGNAL(prepareProgressBar(TQString,int))
-           , TQT_TQOBJECT(this), TQT_SLOT(prepareProgressBar(TQString,int)));
-   connect(_catalogManager,TQT_SIGNAL(clearProgressBar())
-           , TQT_TQOBJECT(this), TQT_SLOT(clearProgressBar()));
-   connect(_catalogManager,TQT_SIGNAL(progress(int))
-           , _progressBar, TQT_SLOT(setProgress(int)));
-//   connect(_catalogManager, TQT_SIGNAL(signalBuildTree(bool))
-//	   , TQT_TQOBJECT(this), TQT_SLOT(enableMenuForFiles(bool)));
-   connect(_catalogManager, TQT_SIGNAL(signalBuildTree(bool))
-	   , TQT_TQOBJECT(this), TQT_SLOT(enableActions(bool)));
-   connect(this, TQT_SIGNAL(searchStopped())
-	   , TQT_TQOBJECT(_catalogManager), TQT_SLOT(stopSearch()));
-   connect(_catalogManager, TQT_SIGNAL(prepareFindProgressBar(int))
-	   , TQT_TQOBJECT(this), TQT_SLOT(prepareStatusProgressBar(int)));
+   connect(_catalogManager,TQ_SIGNAL(prepareProgressBar(TQString,int))
+           , this, TQ_SLOT(prepareProgressBar(TQString,int)));
+   connect(_catalogManager,TQ_SIGNAL(clearProgressBar())
+           , this, TQ_SLOT(clearProgressBar()));
+   connect(_catalogManager,TQ_SIGNAL(progress(int))
+           , _progressBar, TQ_SLOT(setProgress(int)));
+//   connect(_catalogManager, TQ_SIGNAL(signalBuildTree(bool))
+//	   , this, TQ_SLOT(enableMenuForFiles(bool)));
+   connect(_catalogManager, TQ_SIGNAL(signalBuildTree(bool))
+	   , this, TQ_SLOT(enableActions(bool)));
+   connect(this, TQ_SIGNAL(searchStopped())
+	   , _catalogManager, TQ_SLOT(stopSearch()));
+   connect(_catalogManager, TQ_SIGNAL(prepareFindProgressBar(int))
+	   , this, TQ_SLOT(prepareStatusProgressBar(int)));
 
    setCentralWidget(view);
    resize( 600,300);
@@ -206,8 +206,8 @@ void CatalogManager::init()
        _catalogManager->setRMBMenuDir(popup);
    }
 
-   connect(_catalogManager, TQT_SIGNAL(signalSearchedFile(int))
-           , _statusProgressBar, TQT_SLOT(advance(int)));
+   connect(_catalogManager, TQ_SIGNAL(signalSearchedFile(int))
+           , _statusProgressBar, TQ_SLOT(advance(int)));
 
    restoreView();
 }
@@ -219,61 +219,61 @@ void CatalogManager::setupActions()
     TDEAction *action;
 
     // the file menu
-    action = new TDEAction( i18n("&Open"), CTRL+Key_O, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(slotOpenFile()),actionCollection(), "open");
+    action = new TDEAction( i18n("&Open"), CTRL+Key_O, _catalogManager,
+                          TQ_SLOT(slotOpenFile()),actionCollection(), "open");
     action->setEnabled(false);
-    action = new TDEAction(i18n("&Open Template"),Key_Space,TQT_TQOBJECT(_catalogManager),
-                         TQT_SLOT(slotOpenTemplate()),actionCollection(), "open_template");
+    action = new TDEAction(i18n("&Open Template"),Key_Space,_catalogManager,
+                         TQ_SLOT(slotOpenTemplate()),actionCollection(), "open_template");
     action->setEnabled(false);
-    action = new TDEAction(i18n("Open in &New Window"),CTRL+SHIFT+Key_O,TQT_TQOBJECT(_catalogManager),
-                         TQT_SLOT(slotOpenFileInNewWindow()),actionCollection(), "open_new_window");
+    action = new TDEAction(i18n("Open in &New Window"),CTRL+SHIFT+Key_O,_catalogManager,
+                         TQ_SLOT(slotOpenFileInNewWindow()),actionCollection(), "open_new_window");
     action->setEnabled(false);
 
-    action = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT (closeAllWindows()), actionCollection());
+    action = KStdAction::quit(kapp, TQ_SLOT (closeAllWindows()), actionCollection());
 
     actionMap["open_template"] = NEEDS_POT;
 
     // the edit menu
-    action = new TDEAction( i18n("Fi&nd in Files..."), CTRL+Key_F, TQT_TQOBJECT(this),
-                          TQT_SLOT(find()), actionCollection(), "find_in_files");
+    action = new TDEAction( i18n("Fi&nd in Files..."), CTRL+Key_F, this,
+                          TQ_SLOT(find()), actionCollection(), "find_in_files");
     action->setEnabled(false);
-    action = new TDEAction( i18n("Re&place in Files..."), CTRL+Key_R, TQT_TQOBJECT(this),
-                          TQT_SLOT(replace()), actionCollection(), "replace_in_files");
+    action = new TDEAction( i18n("Re&place in Files..."), CTRL+Key_R, this,
+                          TQ_SLOT(replace()), actionCollection(), "replace_in_files");
     action->setEnabled(false);
-    action = new TDEAction( i18n("&Stop Searching"), "process-stop", Key_Escape, TQT_TQOBJECT(this),
-                          TQT_SLOT(stopSearching()), actionCollection(), "stop_search");
+    action = new TDEAction( i18n("&Stop Searching"), "process-stop", Key_Escape, this,
+                          TQ_SLOT(stopSearching()), actionCollection(), "stop_search");
     action->setEnabled(false);
-    action = new TDEAction( i18n("&Reload"), "reload", TDEStdAccel::reload(), TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(updateCurrent()), actionCollection(), "reload");
+    action = new TDEAction( i18n("&Reload"), "reload", TDEStdAccel::reload(), _catalogManager,
+                          TQ_SLOT(updateCurrent()), actionCollection(), "reload");
     action->setEnabled(false);
 
     // the marking menu
-    action = new TDEAction( i18n("&Toggle Marking"), CTRL+Key_M, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(toggleMark()), actionCollection(), "toggle_marking");
+    action = new TDEAction( i18n("&Toggle Marking"), CTRL+Key_M, _catalogManager,
+                          TQ_SLOT(toggleMark()), actionCollection(), "toggle_marking");
     action->setEnabled(false);
-    action = new TDEAction( i18n("Remove Marking"), 0, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(slotClearMarksInDir()), actionCollection(), "remove_marking");
+    action = new TDEAction( i18n("Remove Marking"), 0, _catalogManager,
+                          TQ_SLOT(slotClearMarksInDir()), actionCollection(), "remove_marking");
     action->setEnabled(false);
-    action = new TDEAction( i18n("Toggle All Markings"), 0, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(toggleAllMarks()), actionCollection(), "toggle_all_marking");
+    action = new TDEAction( i18n("Toggle All Markings"), 0, _catalogManager,
+                          TQ_SLOT(toggleAllMarks()), actionCollection(), "toggle_all_marking");
     action->setEnabled(false);
-    action = new TDEAction( i18n("Remove All Markings"), 0, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(clearAllMarks()), actionCollection(), "remove_all_marking");
+    action = new TDEAction( i18n("Remove All Markings"), 0, _catalogManager,
+                          TQ_SLOT(clearAllMarks()), actionCollection(), "remove_all_marking");
     action->setEnabled(false);
-    action = new TDEAction( i18n("Mark Modified Files"), 0, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(markModifiedFiles()), actionCollection(), "mark_modified_files");
+    action = new TDEAction( i18n("Mark Modified Files"), 0, _catalogManager,
+                          TQ_SLOT(markModifiedFiles()), actionCollection(), "mark_modified_files");
     // fixme to enabling this when loading is done using updateFinished() signal
     action->setEnabled(true);
-    action = new TDEAction( i18n("&Load Markings..."), 0, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(loadMarks()), actionCollection(), "load_marking");
+    action = new TDEAction( i18n("&Load Markings..."), 0, _catalogManager,
+                          TQ_SLOT(loadMarks()), actionCollection(), "load_marking");
     action->setEnabled(false);
-    action = new TDEAction( i18n("&Save Markings..."), 0, TQT_TQOBJECT(_catalogManager),
-                          TQT_SLOT(saveMarks()), actionCollection(), "save_marking");
+    action = new TDEAction( i18n("&Save Markings..."), 0, _catalogManager,
+                          TQ_SLOT(saveMarks()), actionCollection(), "save_marking");
     action->setEnabled(false);
-    (void)new TDEAction(i18n("&Mark Files..."), 0, TQT_TQOBJECT(_catalogManager),
-                      TQT_SLOT(slotMarkPattern()), actionCollection(), "mark_pattern");
-    (void)new TDEAction(i18n("&Unmark Files..."), 0, TQT_TQOBJECT(_catalogManager),
-                      TQT_SLOT(slotUnmarkPattern()), actionCollection(), "unmark_pattern");
+    (void)new TDEAction(i18n("&Mark Files..."), 0, _catalogManager,
+                      TQ_SLOT(slotMarkPattern()), actionCollection(), "mark_pattern");
+    (void)new TDEAction(i18n("&Unmark Files..."), 0, _catalogManager,
+                      TQ_SLOT(slotUnmarkPattern()), actionCollection(), "unmark_pattern");
 
     actionMap["remove_marking"]     = NEEDS_MARK;
     actionMap["remove_all_marking"] = NEEDS_MARK;
@@ -282,102 +282,102 @@ void CatalogManager::setupActions()
 
     // go menu
     action = new TDEAction(i18n("Nex&t Untranslated"), "nextuntranslated", ALT+Key_Next,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextUntranslated()),actionCollection(), "go_next_untrans");
+                         _catalogManager, TQ_SLOT(gotoNextUntranslated()),actionCollection(), "go_next_untrans");
     action->setEnabled(false);
     action = new TDEAction(i18n("Prev&ious Untranslated"), "prevuntranslated", ALT+Key_Prior,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousUntranslated()),actionCollection(), "go_prev_untrans");
+                         _catalogManager, TQ_SLOT(gotoPreviousUntranslated()),actionCollection(), "go_prev_untrans");
     action->setEnabled(false);
     action = new TDEAction(i18n("Ne&xt Fuzzy"), "nextfuzzy", CTRL+Key_Next,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextFuzzy()),actionCollection(), "go_next_fuzzy");
+                         _catalogManager, TQ_SLOT(gotoNextFuzzy()),actionCollection(), "go_next_fuzzy");
     action->setEnabled(false);
     action = new TDEAction(i18n("Pre&vious Fuzzy"), "prevfuzzy", CTRL+Key_Prior,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousFuzzy()),actionCollection(), "go_prev_fuzzy");
+                         _catalogManager, TQ_SLOT(gotoPreviousFuzzy()),actionCollection(), "go_prev_fuzzy");
     action->setEnabled(false);
     action = new TDEAction(i18n("N&ext Fuzzy or Untranslated"), "nextfuzzyuntrans", CTRL+SHIFT+Key_Next,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextFuzzyOrUntranslated()),actionCollection(), "go_next_fuzzyUntr");
+                         _catalogManager, TQ_SLOT(gotoNextFuzzyOrUntranslated()),actionCollection(), "go_next_fuzzyUntr");
     action->setEnabled(false);
     action = new TDEAction(i18n("P&revious Fuzzy or Untranslated"), "prevfuzzyuntrans", CTRL+SHIFT+Key_Prior,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousFuzzyOrUntranslated()),actionCollection(), "go_prev_fuzzyUntr");
+                         _catalogManager, TQ_SLOT(gotoPreviousFuzzyOrUntranslated()),actionCollection(), "go_prev_fuzzyUntr");
     action->setEnabled(false);
 
     action = new TDEAction(i18n("Next Err&or"), "nexterror", ALT+SHIFT+Key_Next,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextError()),actionCollection(), "go_next_error");
+                         _catalogManager, TQ_SLOT(gotoNextError()),actionCollection(), "go_next_error");
     action->setEnabled(false);
     action = new TDEAction(i18n("Previo&us Error"), "preverror", ALT+SHIFT+Key_Prior,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousError()),actionCollection(), "go_prev_error");
+                         _catalogManager, TQ_SLOT(gotoPreviousError()),actionCollection(), "go_prev_error");
     action->setEnabled(false);
     action = new TDEAction(i18n("Next Te&mplate Only"), "nexttemplate", CTRL+Key_Down,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextTemplate()),actionCollection(), "go_next_template");
+                         _catalogManager, TQ_SLOT(gotoNextTemplate()),actionCollection(), "go_next_template");
     action->setEnabled(false);
     action = new TDEAction(i18n("Previous Temp&late Only"), "prevtemplate", CTRL+Key_Up,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousTemplate()),actionCollection(), "go_prev_template");
+                         _catalogManager, TQ_SLOT(gotoPreviousTemplate()),actionCollection(), "go_prev_template");
     action->setEnabled(false);
     action = new TDEAction(i18n("Next Tran&slation Exists"), "nextpo", ALT+Key_Down,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextPo()),actionCollection(), "go_next_po");
+                         _catalogManager, TQ_SLOT(gotoNextPo()),actionCollection(), "go_next_po");
     action->setEnabled(false);
     action = new TDEAction(i18n("Previous Transl&ation Exists"), "prevpo", ALT+Key_Up,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousPo()),actionCollection(), "go_prev_po");
+                         _catalogManager, TQ_SLOT(gotoPreviousPo()),actionCollection(), "go_prev_po");
     action->setEnabled(false);
 
     action = new TDEAction(i18n("Previous Marke&d"), "prevmarked", SHIFT+Key_Up,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousMarked()),actionCollection(), "go_prev_marked");
+                         _catalogManager, TQ_SLOT(gotoPreviousMarked()),actionCollection(), "go_prev_marked");
     action->setEnabled(false);
     action = new TDEAction(i18n("Next &Marked"), "nextmarked", SHIFT+Key_Down,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextMarked()),actionCollection(), "go_next_marked");
+                         _catalogManager, TQ_SLOT(gotoNextMarked()),actionCollection(), "go_next_marked");
     action->setEnabled(false);
 
     // project menu
     // the project menu
    action = new TDEAction(i18n("&New..."), "document-new"
-           , TQT_TQOBJECT(this), TQT_SLOT(projectNew()),actionCollection()
+           , this, TQ_SLOT(projectNew()),actionCollection()
            ,"project_new");
 
    action = new TDEAction(i18n("&Open..."), "document-open"
-           , TQT_TQOBJECT(this), TQT_SLOT(projectOpen()),actionCollection()
+           , this, TQ_SLOT(projectOpen()),actionCollection()
            ,"project_open");
 
    action = new TDEAction(i18n("C&lose"), "window-close"
-           , TQT_TQOBJECT(this), TQT_SLOT(projectClose()),actionCollection()
+           , this, TQ_SLOT(projectClose()),actionCollection()
            ,"project_close");
 
    action->setEnabled (_project->filename() != KBabel::ProjectManager::defaultProjectName() );
 
    action = new TDEAction(i18n("&Configure..."), "configure"
-           , TQT_TQOBJECT(this), TQT_SLOT(projectConfigure()),actionCollection()
+           , this, TQ_SLOT(projectConfigure()),actionCollection()
            ,"project_settings");
 
     // tools menu
     action = new TDEAction( i18n("&Statistics"), "statistics",  CTRL+Key_S,
-                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(statistics()), actionCollection(), "statistics");
+                          _catalogManager, TQ_SLOT(statistics()), actionCollection(), "statistics");
     action->setEnabled(false);
     action = new TDEAction( i18n("S&tatistics in Marked"), "statistics",  CTRL+ALT+Key_S,
-                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(markedStatistics()), actionCollection(), "statistics_marked");
+                          _catalogManager, TQ_SLOT(markedStatistics()), actionCollection(), "statistics_marked");
     action->setEnabled(false);
     action = new TDEAction( i18n("Check S&yntax"), "syntax", CTRL+Key_Y,
-                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(checkSyntax()), actionCollection(), "syntax");
+                          _catalogManager, TQ_SLOT(checkSyntax()), actionCollection(), "syntax");
     action->setEnabled(false);
     action = new TDEAction( i18n("S&pell Check"), "tools-check-spelling",  CTRL+Key_I,
-                          TQT_TQOBJECT(this), TQT_SLOT(spellcheck()), actionCollection(), "tools-check-spelling");
+                          this, TQ_SLOT(spellcheck()), actionCollection(), "tools-check-spelling");
     action->setEnabled(false);
     action = new TDEAction( i18n("Spell Check in &Marked"), "tools-check-spelling", CTRL+ALT+Key_I,
-                          TQT_TQOBJECT(this), TQT_SLOT(markedSpellcheck()), actionCollection(), "spellcheck_marked");
+                          this, TQ_SLOT(markedSpellcheck()), actionCollection(), "spellcheck_marked");
     action->setEnabled(false);
     action = new TDEAction( i18n("&Rough Translation"),  CTRL+Key_T,
-                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(roughTranslation()), actionCollection(), "rough_translation");
+                          _catalogManager, TQ_SLOT(roughTranslation()), actionCollection(), "rough_translation");
     action->setEnabled(false);
     action = new TDEAction( i18n("Rough Translation in M&arked"), CTRL+ALT+Key_T,
-                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(markedRoughTranslation()), actionCollection(), "rough_translation_marked");
+                          _catalogManager, TQ_SLOT(markedRoughTranslation()), actionCollection(), "rough_translation_marked");
     action->setEnabled(false);
     action = new TDEAction( i18n("Mai&l"), "mail-send", CTRL+Key_A,
-                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(mailFiles()), actionCollection(), "mail_file");
+                          _catalogManager, TQ_SLOT(mailFiles()), actionCollection(), "mail_file");
     action->setEnabled(false);
     action = new TDEAction( i18n("Mail Mar&ked"), "mail-send", CTRL+ALT+Key_A,
-                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(mailMarkedFiles()), actionCollection(),	"mail_file_marked");
+                          _catalogManager, TQ_SLOT(mailMarkedFiles()), actionCollection(),	"mail_file_marked");
     action->setEnabled(false);
 
     action = new TDEAction( i18n("&Pack"), "application-x-tar", CTRL+Key_B,
-                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(packageFiles()), actionCollection(), "package_file");
-    action = new TDEAction( i18n("Pack &Marked"), "application-x-tar", CTRL+ALT+Key_B, TQT_TQOBJECT(_catalogManager), TQT_SLOT(packageMarkedFiles()), actionCollection(), "package_file_marked");
+                         _catalogManager, TQ_SLOT(packageFiles()), actionCollection(), "package_file");
+    action = new TDEAction( i18n("Pack &Marked"), "application-x-tar", CTRL+ALT+Key_B, _catalogManager, TQ_SLOT(packageMarkedFiles()), actionCollection(), "package_file_marked");
     action->setEnabled(false);
 
     actionMap["statistics_marked"]        = NEEDS_DIR | NEEDS_MARK;
@@ -393,7 +393,7 @@ void CatalogManager::setupActions()
     TQValueList<KDataToolInfo> tools = ToolAction::validationTools();
 
     TQPtrList<TDEAction> actions = ToolAction::dataToolActionList(
-	tools, TQT_TQOBJECT(_catalogManager), TQT_SLOT(validateUsingTool( const KDataToolInfo &, const TQString& ))
+	tools, _catalogManager, TQ_SLOT(validateUsingTool( const KDataToolInfo &, const TQString& ))
 	,"validate", false, actionCollection() );
 
     TDEActionMenu* m_menu = new TDEActionMenu(i18n("&Validation"), actionCollection(),
@@ -407,7 +407,7 @@ void CatalogManager::setupActions()
     }
 
     actions = ToolAction::dataToolActionList(
-	tools, TQT_TQOBJECT(_catalogManager), TQT_SLOT(validateMarkedUsingTool( const KDataToolInfo &, const TQString& ))
+	tools, _catalogManager, TQ_SLOT(validateMarkedUsingTool( const KDataToolInfo &, const TQString& ))
 	,"validate", false, actionCollection(), "marked_" );
     m_menu = new TDEActionMenu(i18n("V&alidation Marked"), actionCollection(),
           "dynamic_validation_marked");
@@ -422,20 +422,20 @@ void CatalogManager::setupActions()
 
     // CVS submenu
     // Actions for PO files
-    (void)new TDEAction( i18n( "Update" ), "go-down", 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsUpdate( ) ), actionCollection( ), "cvs_update" );
-    (void)new TDEAction( i18n( "Update Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsUpdateMarked( ) ), actionCollection( ), "cvs_update_marked" );
-    (void)new TDEAction( i18n( "Commit" ), "go-up", 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsCommit( ) ), actionCollection( ), "cvs_commit" );
-    (void)new TDEAction( i18n( "Commit Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsCommitMarked( ) ), actionCollection( ), "cvs_commit_marked" );
-    (void)new TDEAction( i18n( "Status" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsStatus( ) ), actionCollection( ), "cvs_status" );
-    (void)new TDEAction( i18n( "Status for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsStatusMarked( ) ), actionCollection( ), "cvs_status_marked" );
-    (void)new TDEAction( i18n( "Show Diff" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsDiff( ) ), actionCollection( ), "cvs_diff" );
+    (void)new TDEAction( i18n( "Update" ), "go-down", 0, _catalogManager,
+      TQ_SLOT( cvsUpdate( ) ), actionCollection( ), "cvs_update" );
+    (void)new TDEAction( i18n( "Update Marked" ), 0, _catalogManager,
+      TQ_SLOT( cvsUpdateMarked( ) ), actionCollection( ), "cvs_update_marked" );
+    (void)new TDEAction( i18n( "Commit" ), "go-up", 0, _catalogManager,
+      TQ_SLOT( cvsCommit( ) ), actionCollection( ), "cvs_commit" );
+    (void)new TDEAction( i18n( "Commit Marked" ), 0, _catalogManager,
+      TQ_SLOT( cvsCommitMarked( ) ), actionCollection( ), "cvs_commit_marked" );
+    (void)new TDEAction( i18n( "Status" ), 0, _catalogManager,
+      TQ_SLOT( cvsStatus( ) ), actionCollection( ), "cvs_status" );
+    (void)new TDEAction( i18n( "Status for Marked" ), 0, _catalogManager,
+      TQ_SLOT( cvsStatusMarked( ) ), actionCollection( ), "cvs_status_marked" );
+    (void)new TDEAction( i18n( "Show Diff" ), 0, _catalogManager,
+      TQ_SLOT( cvsDiff( ) ), actionCollection( ), "cvs_diff" );
 
     // CVS
     actionMap["cvs_update"]        = NEEDS_PO | NEEDS_PO_CVS;
@@ -448,28 +448,28 @@ void CatalogManager::setupActions()
 
     // SVN submenu
     // Actions for PO files
-    (void)new TDEAction( i18n( "Update" ), "go-down", 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnUpdate( ) ), actionCollection( ), "svn_update" );
-    (void)new TDEAction( i18n( "Update Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnUpdateMarked( ) ), actionCollection( ), "svn_update_marked" );
-    (void)new TDEAction( i18n( "Commit" ), "go-up", 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnCommit( ) ), actionCollection( ), "svn_commit" );
-    (void)new TDEAction( i18n( "Commit Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnCommitMarked( ) ), actionCollection( ), "svn_commit_marked" );
-    (void)new TDEAction( i18n( "Status (Local)" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnStatusLocal() ), actionCollection( ), "svn_status_local" );
-    (void)new TDEAction( i18n( "Status (Local) for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnStatusLocalMarked() ), actionCollection( ), "svn_status_local_marked" );
-    (void)new TDEAction( i18n( "Status (Remote)" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnStatusRemote() ), actionCollection( ), "svn_status_remote" );
-    (void)new TDEAction( i18n( "Status (Remote) for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnStatusRemoteMarked() ), actionCollection( ), "svn_status_remote_marked" );
-    (void)new TDEAction( i18n( "Show Diff" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnDiff( ) ), actionCollection( ), "svn_diff" );
-    (void)new TDEAction( i18n( "Show Information" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnInfo() ), actionCollection( ), "svn_info" );
-    (void)new TDEAction( i18n( "Show Information for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnInfoMarked() ), actionCollection( ), "svn_info_marked" );
+    (void)new TDEAction( i18n( "Update" ), "go-down", 0, _catalogManager,
+    TQ_SLOT( svnUpdate( ) ), actionCollection( ), "svn_update" );
+    (void)new TDEAction( i18n( "Update Marked" ), 0, _catalogManager,
+    TQ_SLOT( svnUpdateMarked( ) ), actionCollection( ), "svn_update_marked" );
+    (void)new TDEAction( i18n( "Commit" ), "go-up", 0, _catalogManager,
+    TQ_SLOT( svnCommit( ) ), actionCollection( ), "svn_commit" );
+    (void)new TDEAction( i18n( "Commit Marked" ), 0, _catalogManager,
+    TQ_SLOT( svnCommitMarked( ) ), actionCollection( ), "svn_commit_marked" );
+    (void)new TDEAction( i18n( "Status (Local)" ), 0, _catalogManager,
+    TQ_SLOT( svnStatusLocal() ), actionCollection( ), "svn_status_local" );
+    (void)new TDEAction( i18n( "Status (Local) for Marked" ), 0, _catalogManager,
+    TQ_SLOT( svnStatusLocalMarked() ), actionCollection( ), "svn_status_local_marked" );
+    (void)new TDEAction( i18n( "Status (Remote)" ), 0, _catalogManager,
+    TQ_SLOT( svnStatusRemote() ), actionCollection( ), "svn_status_remote" );
+    (void)new TDEAction( i18n( "Status (Remote) for Marked" ), 0, _catalogManager,
+    TQ_SLOT( svnStatusRemoteMarked() ), actionCollection( ), "svn_status_remote_marked" );
+    (void)new TDEAction( i18n( "Show Diff" ), 0, _catalogManager,
+    TQ_SLOT( svnDiff( ) ), actionCollection( ), "svn_diff" );
+    (void)new TDEAction( i18n( "Show Information" ), 0, _catalogManager,
+    TQ_SLOT( svnInfo() ), actionCollection( ), "svn_info" );
+    (void)new TDEAction( i18n( "Show Information for Marked" ), 0, _catalogManager,
+    TQ_SLOT( svnInfoMarked() ), actionCollection( ), "svn_info_marked" );
 
     // SVN
     actionMap["svn_update"]        = NEEDS_PO | NEEDS_PO_SVN;
@@ -485,14 +485,14 @@ void CatalogManager::setupActions()
     actionMap["svn_info_marked"]   = NEEDS_PO | NEEDS_PO_SVN | NEEDS_MARK;
 
     // CVS Actions for POT files
-    (void)new TDEAction( i18n( "Update Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsUpdateTemplate( ) ), actionCollection( ), "cvs_update_template" );
-    (void)new TDEAction( i18n( "Update Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsUpdateMarkedTemplate( ) ), actionCollection( ), "cvs_update_marked_template" );
-    (void)new TDEAction( i18n( "Commit Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsCommitTemplate( ) ), actionCollection( ), "cvs_commit_template" );
-    (void)new TDEAction( i18n( "Commit Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-      TQT_SLOT( cvsCommitMarkedTemplate( ) ), actionCollection( ), "cvs_commit_marked_template" );
+    (void)new TDEAction( i18n( "Update Templates" ), 0, _catalogManager,
+      TQ_SLOT( cvsUpdateTemplate( ) ), actionCollection( ), "cvs_update_template" );
+    (void)new TDEAction( i18n( "Update Marked Templates" ), 0, _catalogManager,
+      TQ_SLOT( cvsUpdateMarkedTemplate( ) ), actionCollection( ), "cvs_update_marked_template" );
+    (void)new TDEAction( i18n( "Commit Templates" ), 0, _catalogManager,
+      TQ_SLOT( cvsCommitTemplate( ) ), actionCollection( ), "cvs_commit_template" );
+    (void)new TDEAction( i18n( "Commit Marked Templates" ), 0, _catalogManager,
+      TQ_SLOT( cvsCommitMarkedTemplate( ) ), actionCollection( ), "cvs_commit_marked_template" );
 
     actionMap["cvs_update_template"]        = NEEDS_POT | NEEDS_POT_CVS;
     actionMap["cvs_update_marked_template"] = NEEDS_POT | NEEDS_POT_CVS | NEEDS_MARK;
@@ -500,14 +500,14 @@ void CatalogManager::setupActions()
     actionMap["cvs_commit_marked_template"] = NEEDS_POT | NEEDS_POT_CVS | NEEDS_MARK;
 
     // SVN Actions for POT files
-    (void)new TDEAction( i18n( "Update Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnUpdateTemplate( ) ), actionCollection( ), "svn_update_template" );
-    (void)new TDEAction( i18n( "Update Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnUpdateMarkedTemplate( ) ), actionCollection( ), "svn_update_marked_template" );
-    (void)new TDEAction( i18n( "Commit Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnCommitTemplate( ) ), actionCollection( ), "svn_commit_template" );
-    (void)new TDEAction( i18n( "Commit Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
-    TQT_SLOT( svnCommitMarkedTemplate( ) ), actionCollection( ), "svn_commit_marked_template" );
+    (void)new TDEAction( i18n( "Update Templates" ), 0, _catalogManager,
+    TQ_SLOT( svnUpdateTemplate( ) ), actionCollection( ), "svn_update_template" );
+    (void)new TDEAction( i18n( "Update Marked Templates" ), 0, _catalogManager,
+    TQ_SLOT( svnUpdateMarkedTemplate( ) ), actionCollection( ), "svn_update_marked_template" );
+    (void)new TDEAction( i18n( "Commit Templates" ), 0, _catalogManager,
+    TQ_SLOT( svnCommitTemplate( ) ), actionCollection( ), "svn_commit_template" );
+    (void)new TDEAction( i18n( "Commit Marked Templates" ), 0, _catalogManager,
+    TQ_SLOT( svnCommitMarkedTemplate( ) ), actionCollection( ), "svn_commit_marked_template" );
 
     actionMap["svn_update_template"]        = NEEDS_POT | NEEDS_POT_SVN;
     actionMap["svn_update_marked_template"] = NEEDS_POT | NEEDS_POT_SVN | NEEDS_MARK;
@@ -515,7 +515,7 @@ void CatalogManager::setupActions()
     actionMap["svn_commit_marked_template"] = NEEDS_POT | NEEDS_POT_SVN | NEEDS_MARK;
 
     // settings menu
-    // FIXME: KStdAction::preferences(this, TQT_SLOT( optionsPreferences()), actionCollection());
+    // FIXME: KStdAction::preferences(this, TQ_SLOT( optionsPreferences()), actionCollection());
 
     createStandardStatusBarAction();
 
@@ -530,7 +530,7 @@ void CatalogManager::setupActions()
                                actionCollection(), "file_commands");
     _catalogManager->setFileCommandsMenu( actionMenu->popupMenu());
 
-    action = new TDEAction(i18n("&Delete"),Key_Delete,TQT_TQOBJECT(_catalogManager),TQT_SLOT(slotDeleteFile()),actionCollection(), "delete");
+    action = new TDEAction(i18n("&Delete"),Key_Delete,_catalogManager,TQ_SLOT(slotDeleteFile()),actionCollection(), "delete");
     action->setEnabled(false);
 
 #if KDE_IS_VERSION( 3, 2, 90 )
@@ -1188,11 +1188,11 @@ void CatalogManager::projectNew()
     KBabel::Project::Ptr p = KBabel::ProjectWizard::newProject();
     if( p )
     {
-	disconnect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+	disconnect( _project, TQ_SIGNAL (signalCatManSettingsChanged())
+	    , this, TQ_SLOT (updateSettings()));
         _project = p;
-	connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+	connect( _project, TQ_SIGNAL (signalCatManSettingsChanged())
+	    , this, TQ_SLOT (updateSettings()));
 
 	_configFile = _project->filename();
         restoreSettings();
@@ -1217,11 +1217,11 @@ void CatalogManager::projectOpen()
     KBabel::Project::Ptr p = KBabel::ProjectManager::open(file);
     if( p )
     {
-	disconnect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+	disconnect( _project, TQ_SIGNAL (signalCatManSettingsChanged())
+	    , this, TQ_SLOT (updateSettings()));
         _project = p;
-	connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+	connect( _project, TQ_SIGNAL (signalCatManSettingsChanged())
+	    , this, TQ_SLOT (updateSettings()));
 
 	_configFile = p->filename();
         restoreSettings();
@@ -1238,11 +1238,11 @@ void CatalogManager::projectOpen()
 
 void CatalogManager::projectClose()
 {
-    disconnect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+    disconnect( _project, TQ_SIGNAL (signalCatManSettingsChanged())
+	    , this, TQ_SLOT (updateSettings()));
     _project = KBabel::ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
-    connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+    connect( _project, TQ_SIGNAL (signalCatManSettingsChanged())
+	    , this, TQ_SLOT (updateSettings()));
     _configFile = _project->filename();
     restoreSettings();
     updateSettings();
@@ -1262,8 +1262,8 @@ void CatalogManager::projectConfigure()
 {
     KBabel::ProjectDialog* _projectDialog = new ProjectDialog(_project);
 
-    connect (_projectDialog, TQT_SIGNAL (settingsChanged())
-	, TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
+    connect (_projectDialog, TQ_SIGNAL (settingsChanged())
+	, this, TQ_SLOT (updateSettings()));
 
     // settings are updated via signals
     _projectDialog->exec();
