@@ -62,7 +62,7 @@ class KURLRequester;
 
 struct ModuleInfo;
 
-class KDE_EXPORT SavePreferences : public KTabCtl
+class TDE_EXPORT SavePreferences : public KTabCtl
 {
    TQ_OBJECT
   
