@@ -35,7 +35,7 @@
 #include <tdecmdlineargs.h>
 #include <kdebug.h>
 #include <tdeglobal.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 
 #include <tqregexp.h>
 #include <tqtimer.h>
