@@ -68,10 +68,10 @@ KCMDnssd::KCMDnssd(TQWidget *parent, const char *name, const TQStringList&)
 	domain = new KSimpleConfig( TQString::fromLatin1( KDE_CONFDIR "/tdednssdrc" ));
 	domain->setGroup("publishing");
 	load();
-	connect(hostedit,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(wdchanged()));
-	connect(secretedit,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(wdchanged()));
-	connect(domainedit,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(wdchanged()));
-	connect(enableZeroconf,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(enableZeroconfChanged(bool)));
+	connect(hostedit,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(wdchanged()));
+	connect(secretedit,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(wdchanged()));
+	connect(domainedit,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(wdchanged()));
+	connect(enableZeroconf,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(enableZeroconfChanged(bool)));
 	m_enableZeroconfChanged=false;
 	if (DNSSD::Configuration::self()->publishDomain().isEmpty()) WANButton->setEnabled(false);
 	kcfg_PublishType->hide(); //unused with Avahi
@@ -84,7 +84,7 @@ KCMDnssd::~KCMDnssd()
 
 void KCMDnssd::save()
 {
-	setCursor(TQCursor(Qt::BusyCursor));
+	setCursor(TQCursor(TQt::BusyCursor));
 	TDECModule::save();
 	if (geteuid()==0 && m_wdchanged) saveMdnsd(); 
 	domain->setFileWriteMode(0644); // this should be readable for everyone
@@ -112,14 +112,14 @@ void KCMDnssd::save()
 	    proc->start(TDEProcess::Block);
 	  }
 	}
-	setCursor(TQCursor(Qt::ArrowCursor));
+	setCursor(TQCursor(TQt::ArrowCursor));
 }
 
 void KCMDnssd::load()
 {
 	if (geteuid()==0) loadMdnsd();
 	enableZeroconf->setChecked(false);
-	TQProcess avahiStatus(TQString("/usr/share/avahi/avahi_status"), TQT_TQOBJECT(this), "avahiStatus");
+	TQProcess avahiStatus(TQString("/usr/share/avahi/avahi_status"), this, "avahiStatus");
 	avahiStatus.start();
 	while (avahiStatus.isRunning()) {
 	  kapp->processEvents();
