@@ -85,7 +85,7 @@ public:
     TQString name() const;
     virtual void notifyValueChange();
 
-    virtual void setChanged( bool b, bool updateDb = TRUE );
+    virtual void setChanged( bool b, bool updateDb = true );
     bool isChanged() const;
 
     virtual void placeEditor( TQWidget *w );
@@ -143,7 +143,7 @@ class PropertyTextItem : public TQObject,
 
 public:
     PropertyTextItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
-		      const TQString &propName, bool comment, bool multiLine, bool ascii = FALSE, bool a = FALSE );
+		      const TQString &propName, bool comment, bool multiLine, bool ascii = false, bool a = false );
     ~PropertyTextItem();
 
     virtual void createChildren();
@@ -156,7 +156,7 @@ public:
     virtual bool hasSubItems() const;
     virtual void childValueChanged( PropertyItem *child );
 
-    virtual void setChanged( bool b, bool updateDb = TRUE );
+    virtual void setChanged( bool b, bool updateDb = true );
 
 private slots:
     void setValue();
@@ -579,7 +579,7 @@ private:
 struct EnumItem {
     EnumItem( const TQString &k, bool s )
 	: key( k ), selected( s ) {}
-    EnumItem() : key( TQString() ), selected( FALSE ) {}
+    EnumItem() : key( TQString() ), selected( false ) {}
     bool operator==( const EnumItem &item ) const {
 	return key == item.key;
     }
@@ -690,7 +690,7 @@ public:
     virtual void setPropertyValue( PropertyItem *i );
     virtual void setCurrentProperty( const TQString &n );
 
-    void layoutInitValue( PropertyItem *i, bool changed = FALSE );
+    void layoutInitValue( PropertyItem *i, bool changed = false );
     PropertyEditor *propertyEditor() const;
     TQString whatsThisAt( const TQPoint &p );
     void showCurrentWhatsThis();
