@@ -60,7 +60,7 @@ WorkspaceItem::WorkspaceItem( TQListView *parent, Project* p )
     project = p;
     t = ProjectType;
     setPixmap( 0, SmallIcon( "designer_folder.png" , KDevDesignerPartFactory::instance()) );
-    setExpandable( FALSE );
+    setExpandable( false );
 }
 
 WorkspaceItem::WorkspaceItem( TQListViewItem *parent, SourceFile* sf )
@@ -104,8 +104,8 @@ WorkspaceItem::WorkspaceItem( TQListViewItem *parent, FormFile* ff, Type type )
 
 void WorkspaceItem::init()
 {
-    autoOpen = FALSE;
-    useOddColor = FALSE;
+    autoOpen = false;
+    useOddColor = false;
     project = 0;
     sourceFile = 0;
     formFile = 0;
@@ -130,7 +130,7 @@ void WorkspaceItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
 
     if ( isModified() ) {
 	TQFont f = p->font();
-	f.setBold( TRUE );
+	f.setBold( true );
 	p->setFont( f );
     }
 
@@ -215,7 +215,7 @@ bool WorkspaceItem::checkCompletion( const TQString& completion )
     case ObjectType:
 	return completion == object->name();
     }
-    return FALSE;
+    return false;
 }
 
 
@@ -234,7 +234,7 @@ bool WorkspaceItem::isModified() const
 	return project->fakeFormFileFor( object )->isModified();
 	break;
     }
-    return FALSE; // shut up compiler
+    return false; // shut up compiler
 }
 
 TQString WorkspaceItem::key( int column, bool ) const
@@ -261,7 +261,7 @@ TQColor WorkspaceItem::backgroundColor()
 void WorkspaceItem::setOpen( bool b )
 {
     TQListViewItem::setOpen( b );
-    autoOpen = FALSE;
+    autoOpen = false;
 }
 
 void WorkspaceItem::setAutoOpen( bool b )
@@ -273,14 +273,14 @@ void WorkspaceItem::setAutoOpen( bool b )
 Workspace::Workspace( TQWidget *parent, MainWindow *mw )
     : TQListView( parent, 0, WStyle_Customize | WStyle_NormalBorder | WStyle_Title |
 		 WStyle_Tool | WStyle_MinMax | WStyle_SysMenu ), mainWindow( mw ),
-	project( 0 ), completionDirty( FALSE )
+	project( 0 ), completionDirty( false )
 {
     init_colors();
 
     setDefaultRenameAction( Accept );
-    blockNewForms = FALSE;
+    blockNewForms = false;
     bufferEdit = 0;
-    header()->setStretchEnabled( TRUE );
+    header()->setStretchEnabled( true );
     header()->hide();
     setSorting( 0 );
     setResizePolicy( TQScrollView::Manual );
@@ -291,7 +291,7 @@ Workspace::Workspace( TQWidget *parent, MainWindow *mw )
     setPalette( p );
 #endif
     addColumn( i18n( "Files" ) );
-    setAllColumnsShowFocus( TRUE );
+    setAllColumnsShowFocus( true );
     connect( this, TQ_SIGNAL( mouseButtonClicked( int, TQListViewItem *, const TQPoint &, int ) ),
 	     this, TQ_SLOT( itemClicked( int, TQListViewItem *, const TQPoint& ) ) ),
     connect( this, TQ_SIGNAL( doubleClicked( TQListViewItem * ) ),
@@ -300,8 +300,8 @@ Workspace::Workspace( TQWidget *parent, MainWindow *mw )
 	     this, TQ_SLOT( rmbClicked( TQListViewItem *, const TQPoint& ) ) ),
     setHScrollBarMode( AlwaysOff );
     setVScrollBarMode( AlwaysOn );
-    viewport()->setAcceptDrops( TRUE );
-    setAcceptDrops( TRUE );
+    viewport()->setAcceptDrops( true );
+    setAcceptDrops( true );
     setColumnWidthMode( 1, Manual );
 }
 
@@ -343,7 +343,7 @@ void Workspace::setCurrentProject( Project *pro )
 
     projectItem = new WorkspaceItem( this, project );
 
-    projectItem->setOpen( TRUE );
+    projectItem->setOpen( true );
 
     for ( TQPtrListIterator<SourceFile> sources = project->sourceFiles();
 	  sources.current(); ++sources ) {
@@ -368,7 +368,7 @@ void Workspace::setCurrentProject( Project *pro )
     }
 
     updateColors();
-    completionDirty = TRUE;
+    completionDirty = true;
 }
 
 void Workspace::sourceFileAdded( SourceFile* sf )
@@ -411,7 +411,7 @@ void Workspace::objectRemoved( TQObject *o )
 
 void Workspace::update()
 {
-    completionDirty = TRUE;
+    completionDirty = true;
     triggerUpdate();
 }
 
@@ -431,9 +431,9 @@ void Workspace::activeFormChanged( FormWindow *fw )
     WorkspaceItem *i = findItem( fw->formFile() );
     if ( i ) {
 	setCurrentItem( i );
-	setSelected( i, TRUE );
+	setSelected( i, true );
 	if ( !i->isOpen() )
-	    i->setAutoOpen( TRUE );
+	    i->setAutoOpen( true );
     }
 
     closeAutoOpenItems();
@@ -449,15 +449,15 @@ void Workspace::activeEditorChanged( SourceEditor *se )
 	WorkspaceItem *i = findItem( se->formWindow()->formFile() );
 	if ( i && i->firstChild() ) {
 	    if ( !i->isOpen() )
-		i->setAutoOpen( TRUE );
+		i->setAutoOpen( true );
 	    setCurrentItem( i->firstChild() );
-	    setSelected( i->firstChild(), TRUE );
+	    setSelected( i->firstChild(), true );
 	}
     } else {
 	WorkspaceItem *i = findItem( se->sourceFile() );
 	if ( i ) {
 	    setCurrentItem( i );
-	    setSelected( i, TRUE );
+	    setSelected( i, true );
 	}
     }
 
@@ -503,7 +503,7 @@ void Workspace::closeAutoOpenItems()
 	if ( i->type() == WorkspaceItem::FormSourceType ) {
 	    if ( !i->isSelected() && !ip->isSelected()
 		 && ip->isAutoOpen() ) {
-		ip->setAutoOpen( FALSE );
+		ip->setAutoOpen( false );
 	    }
 	}
     }
@@ -518,7 +518,7 @@ void Workspace::closeEvent( TQCloseEvent *e )
 void Workspace::itemDoubleClicked( TQListViewItem *i )
 {
     if ( ( (WorkspaceItem*)i)->type()== WorkspaceItem::ProjectType )
-	i->setOpen( TRUE );
+	i->setOpen( true );
 }
 
 void Workspace::itemClicked( int button, TQListViewItem *i, const TQPoint& )
@@ -536,7 +536,7 @@ void Workspace::itemClicked( int button, TQListViewItem *i, const TQPoint& )
 	wi->formFile->showFormWindow();
 	break;
     case WorkspaceItem::FormSourceType:
-	wi->formFile->showEditor( FALSE );
+	wi->formFile->showEditor( false );
 	break;
     case WorkspaceItem::SourceFileType:
 	mainWindow->editSource( wi->sourceFile );
@@ -592,7 +592,7 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
     enum { OPEN_SOURCE, REMOVE_SOURCE, OPEN_FORM, REMOVE_FORM,
 	   OPEN_FORM_SOURCE, REMOVE_FORM_SOURCE, OPEN_OBJECT_SOURCE };
     TQPopupMenu menu( this );
-    menu.setCheckable( TRUE );
+    menu.setCheckable( true );
     switch ( wi->type() ) {
     case WorkspaceItem::SourceFileType:
 	menu.insertItem( i18n( "&Open Source File" ), OPEN_SOURCE );
@@ -632,7 +632,7 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
 	project->removeFormFile( wi->formFile );
 	break;
     case REMOVE_FORM_SOURCE:
-	( (WorkspaceItem*)i )->formFile->setModified( TRUE );
+	( (WorkspaceItem*)i )->formFile->setModified( true );
 	( (WorkspaceItem*)i )->formFile->setCodeFileState( FormFile::Deleted );
 	delete ( (WorkspaceItem*)i )->formFile->editor();
 	break;
@@ -665,7 +665,7 @@ void Workspace::updateBufferEdit()
 {
     if ( !bufferEdit || !completionDirty || !MainWindow::self)
 	return;
-    completionDirty = FALSE;
+    completionDirty = false;
     TQStringList completion = MainWindow::self->projectFileNames();
     TQListViewItemIterator it( this );
     while ( it.current() ) {
@@ -701,7 +701,7 @@ void Workspace::updateColors()
     TQListViewItem* i = firstChild();
     if ( i )
 	i = i->firstChild();
-    bool b = TRUE;
+    bool b = true;
     while ( i ) {
 	WorkspaceItem* wi = ( WorkspaceItem*) i;
 	i = i->nextSibling();
