@@ -36,10 +36,10 @@ KGrFigure :: KGrFigure (int px, int py)
 }
 
 // Initialise the global settings flags.
-bool           KGrFigure::variableTiming = TRUE;
-bool           KGrFigure::alwaysCollectNugget    = TRUE;
-bool           KGrFigure::runThruHole    = TRUE;
-bool           KGrFigure::reappearAtTop  = TRUE;
+bool           KGrFigure::variableTiming = true;
+bool           KGrFigure::alwaysCollectNugget    = true;
+bool           KGrFigure::runThruHole    = true;
+bool           KGrFigure::reappearAtTop  = true;
 SearchStrategy KGrFigure::searchStrategy = LOW;
 
 int KGrFigure::herox = 0;
@@ -155,7 +155,7 @@ void KGrFigure::walkUp(int WALKDELAY)
 	    rely -= STEP;
 	    absy -= STEP;
 	}
-	walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+	walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
     }
     else {
 	// End of 4-step cycle: move up to next cell, if possible.
@@ -185,7 +185,7 @@ void KGrFigure::walkDown(int WALKDELAY, int FALLDELAY)
 		rely += STEP;
 		absy += STEP;
 	    }
-	    walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+	    walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
 	}
 	else {
 	    // End of 4-step cycle: move down to next cell, if possible.
@@ -217,7 +217,7 @@ void KGrFigure::walkLeft (int WALKDELAY, int FALLDELAY)
 		relx -= STEP;
 		absx -=STEP;
 	    }
-	    walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+	    walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
 	}
 	else {
 	    // End of 4-pixmap cycle: start again, in next cell if possible.
@@ -249,7 +249,7 @@ void KGrFigure::walkRight(int WALKDELAY, int FALLDELAY)
 		relx += STEP;
 		absx += STEP;	// nur vorwrts gehen, wenn es auch mglich ist
 	    }
-	    walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+	    walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
 	}
 	else {
 	    actualPixmap -= 4;		// Schritt war vollendet
@@ -277,7 +277,7 @@ void KGrFigure::initFall(int apm, int FALLDELAY)
   actualPixmap = apm;
   walkCounter=1;
   walkTimer->stop();
-  fallTimer->start((FALLDELAY * NSPEED) / speed, TRUE);
+  fallTimer->start((FALLDELAY * NSPEED) / speed, true);
 }
 
 void KGrFigure::showFigure ()
@@ -303,12 +303,12 @@ KGrHero :: KGrHero (KGrCanvas * view, int x, int y)
   herox = x;
   heroy = y;
 
-  started = FALSE;
-  mouseMode = TRUE;
+  started = false;
+  mouseMode = true;
   walkCounter = 1;
 
-  walkFrozen = FALSE;
-  fallFrozen = FALSE;
+  walkFrozen = false;
+  fallFrozen = false;
 
   connect (walkTimer, TQ_SIGNAL (timeout ()), TQ_SLOT (walkTimeDone ()));
   connect (fallTimer, TQ_SIGNAL (timeout ()), TQ_SLOT (fallTimeDone ()));
@@ -380,22 +380,22 @@ void KGrHero::setKey(Direction key)
 {
     // Keyboard control of hero: direction is fixed until next key is pressed.
     // Sets a simulated mouse-pointer above, below, left, right or on the hero.
-    mouseMode = FALSE;
-    stopped = FALSE;
+    mouseMode = false;
+    stopped = false;
     switch (key) {
     case UP:	mousex = x; mousey = 0; break;
     case DOWN:	mousex = x; mousey = FIELDHEIGHT + 1; break;
     case LEFT:	mousex = 0; mousey = y; break;
     case RIGHT:	mousex = FIELDWIDTH + 1; mousey = y; break;
-    case STAND:	stopped = TRUE;  mousex = x; mousey = y; break;
+    case STAND:	stopped = true;  mousex = x; mousey = y; break;
     }
 }
 
 void KGrHero::setDirection(int i, int j)
 {
     // Mouse control of hero: direction is updated continually on a timer.
-    mouseMode = TRUE;
-    stopped = FALSE;
+    mouseMode = true;
+    stopped = false;
     mousex = i;
     mousey = j;
 }
@@ -446,11 +446,11 @@ void KGrHero::setNextDir()
 
 void KGrHero::doStep() {
     if (walkFrozen) {
-	walkFrozen = FALSE;
+	walkFrozen = false;
 	walkTimeDone();
     }
     if (fallFrozen) {
-	fallFrozen = FALSE;
+	fallFrozen = false;
 	fallTimeDone();
     }
 }
@@ -479,7 +479,7 @@ void KGrHero::init(int a,int b)
     walkTimer->stop();
     fallTimer->stop();
     walkCounter = 1;
-    started = FALSE;
+    started = false;
 
     x = mem_x = a;
     y = mem_y = b;
@@ -503,9 +503,9 @@ void KGrHero::init(int a,int b)
 
 void KGrHero::start()
 {
-    started = TRUE;
-    walkFrozen = FALSE;
-    fallFrozen = FALSE;
+    started = true;
+    walkFrozen = false;
+    fallFrozen = false;
 
     if (!(canStand()||hangAtPole())) {		// Held muss wohl fallen...
 	status = FALLING;
@@ -539,7 +539,7 @@ void KGrHero::setSpeed (int gamespeed)
 void KGrHero::walkTimeDone ()
 {
   if (! started) return;	// Ignore signals from earlier play.
-  if (KGrObject::frozen) {walkFrozen = TRUE; return; }
+  if (KGrObject::frozen) {walkFrozen = true; return; }
 
   if ((*playfield)[x][y]->whatIam() == BRICK) {
     emit caughtHero();		// Brick closed over hero.
@@ -587,7 +587,7 @@ void KGrHero::walkTimeDone ()
     if (!canStand()&&!hangAtPole())
       initFall(FALL1, FALLDELAY);
     else
-      walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+      walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
 
   // This additional showFigure() is to update the hero position after it is
   // altered by the hero-enemy deadlock fix in standOnEnemy().  Messy, but ...
@@ -602,11 +602,11 @@ void KGrHero::walkTimeDone ()
 void KGrHero::fallTimeDone()
 {
     if (! started) return;		// Ignore signals from earlier play.
-    if (KGrObject::frozen) {fallFrozen = TRUE; return; }
+    if (KGrObject::frozen) {fallFrozen = true; return; }
 
     if (!standOnEnemy()) {
 	if (walkCounter++ < 4) {	// Held fllt vier Positionen
-	    fallTimer->start((FALLDELAY * NSPEED) / speed, TRUE);
+	    fallTimer->start((FALLDELAY * NSPEED) / speed, true);
 	    rely+=STEP;
 	    absy+=STEP;
 	}
@@ -617,12 +617,12 @@ void KGrHero::fallTimeDone()
 	    absy = y*16;		// wird Null und Figur eins runter
 	    collectNugget();		// gesetzt. Zeit evtl. Nugget zu nehmen
 	    if (! (canStand()||hangAtPole())) {	// Held muss wohl weiterfallen.
-		fallTimer->start((FALLDELAY * NSPEED) / speed, TRUE);
+		fallTimer->start((FALLDELAY * NSPEED) / speed, true);
 		walkCounter = 1;
 	    }
 	    else {			// Held hat Boden (oder Feind) unter den
 		status = STANDING;	// Fssen oder hngt an Stange -> steh!
-		walkTimer->start((WALKDELAY * NSPEED) / speed, TRUE);
+		walkTimer->start((WALKDELAY * NSPEED) / speed, true);
 		direction = (actualPixmap == 19) ? RIGHT : LEFT;
 		if ((*playfield)[x][y]->whatIam() == POLE)
 		    actualPixmap = (direction == RIGHT)? RIGHTCLIMB1:LEFTCLIMB1;
@@ -643,11 +643,11 @@ void KGrHero::fallTimeDone()
 	    // else
 		// Reduce jerkiness when descending over a falling enemy.
 		// actualPixmap = (direction == RIGHT)? RIGHTWALK1:LEFTWALK1;
-	    walkTimer->start((WALKDELAY * NSPEED) / speed, TRUE);
+	    walkTimer->start((WALKDELAY * NSPEED) / speed, true);
 	}
 	else {
 	    // Else, freeze hero until enemy moves out of the way.
-	    fallTimer->start((FALLDELAY * NSPEED) / speed, TRUE);
+	    fallTimer->start((FALLDELAY * NSPEED) / speed, true);
 	}
     }
     if (isInEnemy() && (! standOnEnemy()))
@@ -812,9 +812,9 @@ KGrEnemy :: KGrEnemy (KGrCanvas * view, int x, int y)
   birthX=x;
   birthY=y;
 
-  walkFrozen = FALSE;
-  fallFrozen = FALSE;
-  captiveFrozen = FALSE;
+  walkFrozen = false;
+  fallFrozen = false;
+  captiveFrozen = false;
 
   captiveTimer = new TQTimer (this);
   connect (captiveTimer,TQ_SIGNAL(timeout()),TQ_SLOT(captiveTimeDone()));
@@ -828,15 +828,15 @@ int KGrEnemy::CAPTIVEDELAY = 0;
 
 void KGrEnemy::doStep() {
     if (walkFrozen) {
-	walkFrozen = FALSE;
+	walkFrozen = false;
 	walkTimeDone();
     }
     if (fallFrozen) {
-	fallFrozen = FALSE;
+	fallFrozen = false;
 	fallTimeDone();
     }
     if (captiveFrozen) {
-	captiveFrozen = FALSE;
+	captiveFrozen = false;
 	captiveTimeDone();
     }
 }
@@ -885,7 +885,7 @@ void KGrEnemy::init(int a,int b)
 
 void KGrEnemy::walkTimeDone ()
 {
-  if (KGrObject::frozen) {walkFrozen = TRUE; return; }
+  if (KGrObject::frozen) {walkFrozen = true; return; }
 
   // Check we are alive BEFORE checking for friends being in the way.
   // Maybe a friend overhead is blocking our escape from a brick.
@@ -932,7 +932,7 @@ void KGrEnemy::walkTimeDone ()
       }
       status = WALKING; // initialisiere die Zhlervariablen und
       walkCounter = 1; // den Timer um den Held weiter
-      walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE); // zu jagen
+      walkTimer->start ((WALKDELAY * NSPEED) / speed, true); // zu jagen
       startWalk ();
       }
   }
@@ -953,14 +953,14 @@ void KGrEnemy::walkTimeDone ()
       rely = 0; absy = 16 * y;
       startWalk ();
     }
-    walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+    walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
   }
   showFigure();
 }
 
 void KGrEnemy::fallTimeDone ()
 {
-  if (KGrObject::frozen) {fallFrozen = TRUE; return; }
+  if (KGrObject::frozen) {fallFrozen = true; return; }
 
   if ((*playfield)[x][y+1]->whatIam() == HOLE) {  // wenn Enemy ins Loch fllt
     ((KGrBrick*)(*playfield)[x][y+1])->useHole(); // reserviere das Loch, damit
@@ -990,12 +990,12 @@ void KGrEnemy::fallTimeDone ()
     }
 
   if (standOnEnemy()) {				// Don't fall into a friend.
-    fallTimer->start((FALLDELAY * NSPEED) / speed, TRUE);
+    fallTimer->start((FALLDELAY * NSPEED) / speed, true);
     return;
   }
 
   if (walkCounter++ < 4){
-    fallTimer->start((FALLDELAY * NSPEED) / speed, TRUE);
+    fallTimer->start((FALLDELAY * NSPEED) / speed, true);
     { rely+=STEP; absy+=STEP;}
   }
   else {
@@ -1003,10 +1003,10 @@ void KGrEnemy::fallTimeDone ()
     if ((*playfield)[x][y]->whatIam() == USEDHOLE) {
         captiveCounter = 0;
         status = CAPTIVE;
-        captiveTimer->start((CAPTIVEDELAY * NSPEED) / speed, TRUE);
+        captiveTimer->start((CAPTIVEDELAY * NSPEED) / speed, true);
     }
     else if (!(canStand()||hangAtPole())) {
-	fallTimer->start((FALLDELAY * NSPEED) / speed, TRUE);
+	fallTimer->start((FALLDELAY * NSPEED) / speed, true);
 	walkCounter=1;
     }
     else {
@@ -1019,7 +1019,7 @@ void KGrEnemy::fallTimeDone ()
     status = WALKING;
     walkCounter = 1;
     direction = searchbestway(x,y,herox,heroy);
-    walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+    walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
     startWalk ();
     if (!nuggets)
       collectNugget();
@@ -1031,7 +1031,7 @@ void KGrEnemy::fallTimeDone ()
 
 void KGrEnemy::captiveTimeDone()
 {
-  if (KGrObject::frozen) {captiveFrozen = TRUE; return; }
+  if (KGrObject::frozen) {captiveFrozen = true; return; }
   if ((*playfield)[x][y]->whatIam()==BRICK)
     dieAndReappear();
   else
@@ -1039,11 +1039,11 @@ void KGrEnemy::captiveTimeDone()
       status = WALKING;
       walkCounter = 1;
       direction = UP;
-      walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+      walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
       captiveCounter = 0;
     } else {
       captiveCounter ++;
-      captiveTimer->start((CAPTIVEDELAY * NSPEED) / speed, TRUE);
+      captiveTimer->start((CAPTIVEDELAY * NSPEED) / speed, true);
       showFigure();
     }
 }
@@ -1055,11 +1055,11 @@ void KGrEnemy::startSearching()
 
     if (canStand()||((*playfield)[x][y+1]->whatIam()==USEDHOLE)) {
 	status = WALKING;
-	walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+	walkTimer->start ((WALKDELAY * NSPEED) / speed, true);
     }
     else {
 	status = FALLING;
-	fallTimer->start ((FALLDELAY * NSPEED) / speed, TRUE);
+	fallTimer->start ((FALLDELAY * NSPEED) / speed, true);
     }
 
     walkCounter = 1;
@@ -1137,7 +1137,7 @@ void KGrEnemy::dieAndReappear()
 
     if (reappearAtTop) {
 	// Follow Traditional rules: enemies reappear at top.
-	looking = TRUE;
+	looking = true;
 	y = 2;
 	// Randomly look for a free spot in row 2.  Limit the number of tries.
 	for (i = 1; ((i <= 3) && looking); i++) {
@@ -1145,7 +1145,7 @@ void KGrEnemy::dieAndReappear()
 	    switch ((*playfield)[x][2]->whatIam()) {
 	    case FREE:
 	    case HLADDER:
-		looking = FALSE;
+		looking = false;
 		break;
 	    default:
 		break;
@@ -1160,7 +1160,7 @@ void KGrEnemy::dieAndReappear()
 		switch ((*playfield)[x][y]->whatIam()) {
 		case FREE:
 		case HLADDER:
-		    looking = FALSE;
+		    looking = false;
 		    break;
 		default:
 		    break;
@@ -1540,7 +1540,7 @@ int KGrEnemy::distanceDown (int x, int y, int deltah)
 
     int rungs = -1;
     int exitRung = 0;
-    bool canGoThru = TRUE;
+    bool canGoThru = true;
     char objType;
 
     // If there is a way down at (x,y), return its length, else return zero.
@@ -1557,7 +1557,7 @@ int KGrEnemy::distanceDown (int x, int y, int deltah)
 	    if ((objType == HOLE) && (rungs < 0))
 		rungs = 0;		// Enemy can go SIDEWAYS through a hole.
 	    else
-		canGoThru = FALSE;	// Cannot go through here.
+		canGoThru = false;	// Cannot go through here.
 	    break;
 	case LADDER:
 	case POLE:			// Can go through or stop.
@@ -1575,7 +1575,7 @@ int KGrEnemy::distanceDown (int x, int y, int deltah)
 			exitRung = rungs;
 		}
 		else
-		    canGoThru = FALSE;	// Should stop at hero's level.
+		    canGoThru = false;	// Should stop at hero's level.
 	    }
 	    break;
 	default:
@@ -1603,9 +1603,9 @@ bool KGrEnemy::searchOK (int direction, int x, int y)
     if (canWalkLR (direction, x, y) > 0) {
 	// Can go into that cell, but check for a fall.
 	if (willNotFall (x+direction, y))
-	    return TRUE;
+	    return true;
     }
-    return FALSE;			// Cannot go into and through that cell.
+    return false;			// Cannot go into and through that cell.
 }
 
 int KGrEnemy::canWalkLR (int direction, int x, int y)
@@ -1637,7 +1637,7 @@ bool KGrEnemy::willNotFall (int x, int y)
     switch ( (*playfield)[x][y]->whatIam()) {
     case LADDER:
     case POLE:
-	return TRUE; break;		// OK, can hang on ladder or pole.
+	return true; break;		// OK, can hang on ladder or pole.
     default:
 	break;
     }
@@ -1661,12 +1661,12 @@ bool KGrEnemy::willNotFall (int x, int y)
 	for (c = 0; c < cmax; c++) {
 	    enemy = enemies->at(c);
 	    if ((enemy->getx()==16*x) && (enemy->gety()==16*(y+1)))
-		return TRUE;		// Standing on a friend.
+		return true;		// Standing on a friend.
 	}
-	return FALSE; break;		// Will fall: there is no floor.
+	return false; break;		// Will fall: there is no floor.
 
     default:
-	return TRUE; break;		// OK, will not fall.
+	return true; break;		// OK, will not fall.
     }
 }
 
@@ -1733,13 +1733,13 @@ bool KGrEnemy::bumpingFriend()
 		if ((dx >= -32) && (dx < 16) && (dy > -16) && (dy < 16)) {
 		    if ((enemy->direction == RIGHT) &&
 			(enemy->status == WALKING)  && (absx%16==0)) {
-			return TRUE;
+			return true;
 		    }
 		    else if (dx >= -16) {
 			if ((dx > -16) && (enemyId < enemy->enemyId))
-			    return FALSE;
+			    return false;
 			else
-			    return TRUE;	// Wait for the one in front.
+			    return true;	// Wait for the one in front.
 		    }
 		}
 		break;
@@ -1747,13 +1747,13 @@ bool KGrEnemy::bumpingFriend()
 		if ((dx > -16) && (dx < 32) && (dy > -16) && (dy < 16)) {
 		    if ((enemy->direction == LEFT) &&
 			(enemy->status == WALKING) && (absx%16==0)) {
-			return TRUE;
+			return true;
 		    }
 		    else if (dx <= 16) {
 			if ((dx < 16) && (enemyId < enemy->enemyId))
-			    return FALSE;
+			    return false;
 			else
-			    return TRUE;	// Wait for the one in front.
+			    return true;	// Wait for the one in front.
 		    }
 		}
 		break;
@@ -1761,13 +1761,13 @@ bool KGrEnemy::bumpingFriend()
 		if ((dy >= -32) && (dy < 16) && (dx > -16) && (dx < 16)) {
 		    if ((enemy->direction == DOWN) &&
 			(enemy->status == WALKING) && (absy%16==0)) {
-			return TRUE;
+			return true;
 		    }
 		    else if (dy >= -16) {
 			if ((dy > -16) && (enemyId < enemy->enemyId))
-			    return FALSE;
+			    return false;
 			else
-			    return TRUE;	// Wait for the one above.
+			    return true;	// Wait for the one above.
 		    }
 		}
 		break;
@@ -1775,13 +1775,13 @@ bool KGrEnemy::bumpingFriend()
 		if ((dy > -16) && (dy < 32) && (dx > -16) && (dx < 16)) {
 		    if ((enemy->direction == UP) &&
 			(enemy->status == WALKING) && (absy%16==0)) {
-			return TRUE;
+			return true;
 		    }
 		    else if (dy <= 16) {
 			if ((dy < 16) && (enemyId < enemy->enemyId))
-			    return FALSE;
+			    return false;
 			else
-			    return TRUE;	// Wait for the one below.
+			    return true;	// Wait for the one below.
 		    }
 		}
 		break;
@@ -1790,7 +1790,7 @@ bool KGrEnemy::bumpingFriend()
 	    }
 	}
     }
-    return FALSE;
+    return false;
 }
 
 KGrEnemy :: ~KGrEnemy ()
