@@ -49,7 +49,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 extern "C"
 {
-  KDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
+  TDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
   {
     TDEGlobal::locale()->insertCatalogue("kmathapplet");
     return new MathApplet(configFile, KPanelApplet::Stretch, 0, parent, "kmathapplet");
@@ -139,14 +139,14 @@ void MathApplet::useDegrees() {
 	mContextMenu->setItemChecked(0, true);
 	mContextMenu->setItemChecked(1, false);
 	Parser dummy;
-	dummy.setAngleMode(1);
+	dummy.setAngleMode(true);
 }
 
 void MathApplet::useRadians() {
 	mContextMenu->setItemChecked(0, false);
 	mContextMenu->setItemChecked(1, true);
 	Parser dummy;
-	dummy.setAngleMode(0);
+	dummy.setAngleMode(false);
 }
 
 void MathApplet::resizeEvent(TQResizeEvent*)
