@@ -44,7 +44,7 @@
 #endif // QT_H
 
 
-class Q_EXPORT TQBrush: public Qt
+class TQ_EXPORT TQBrush: public Qt
 {
 friend class TQPainter;
 public:
@@ -84,8 +84,8 @@ private:
  *****************************************************************************/
 
 #ifndef TQT_NO_DATASTREAM
-Q_EXPORT TQDataStream &operator<<( TQDataStream &, const TQBrush & );
-Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQBrush & );
+TQ_EXPORT TQDataStream &operator<<( TQDataStream &, const TQBrush & );
+TQ_EXPORT TQDataStream &operator>>( TQDataStream &, TQBrush & );
 #endif
 
 #endif // TQBRUSH_H
