@@ -107,7 +107,7 @@ public:
       quick test. Eg., actions that have a mail address as parameter
       shouldn't try real address validation, but only check if the
       string representation is empty. */
-  virtual bool isEmpty() const { return FALSE; }
+  virtual bool isEmpty() const { return false; }
 
   /** Creates a widget for setting the filter action parameter. Also
       sets the value of the widget. */
@@ -138,7 +138,7 @@ public:
 
   /** Called from the filter when a folder is removed.  Tests if the
       folder @p aFolder is used and changes to @p aNewFolder in this
-      case. Returns TRUE if a change was made.  */
+      case. Returns true if a change was made.  */
   virtual bool folderRemoved(KMFolder* aFolder, KMFolder* aNewFolder);
 
   /** Static function that creates a filter action of this type. */
@@ -431,7 +431,7 @@ public:
 
   /** Called from the filter when a folder is removed.  Tests if the
       folder @p aFolder is used and changes to @p aNewFolder in this
-      case. Returns TRUE if a change was made.  */
+      case. Returns true if a change was made.  */
   virtual bool folderRemoved(KMFolder* aFolder, KMFolder* aNewFolder);
 
 protected:
