@@ -1,4 +1,3 @@
-// -*- mode: C++; c-file-style: "gnu" -*-
 // kmfoldermaildir.cpp
 // Author: Kurt Granroth <granroth@kde.org>
 
@@ -1123,7 +1122,7 @@ TQ_INT64 KMFolderMaildir::doFolderSize() const
   item = new KFileItem( S_IFDIR, -1, location() + "/tmp" );
   list.append( item );
   s_DirSizeJobQueue.append(
-    tqMakePair( TQGuardedPtr<const KMFolderMaildir>( this ), list ) );
+    qMakePair( TQGuardedPtr<const KMFolderMaildir>( this ), list ) );
 
   // if there's only one entry in the queue then we can start
   // a dirSizeJob right away
@@ -1132,8 +1131,8 @@ TQ_INT64 KMFolderMaildir::doFolderSize() const
     //kdDebug(5006) << k_funcinfo << "Starting dirSizeJob for folder "
     //  << location() << endl;
     KDirSize* job = KDirSize::dirSizeJob( list );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-             this, TQT_SLOT( slotDirSizeJobResult( TDEIO::Job* ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+             this, TQ_SLOT( slotDirSizeJobResult( TDEIO::Job* ) ) );
   }
 
   return -1;
@@ -1164,8 +1163,8 @@ void KMFolderMaildir::slotDirSizeJobResult( TDEIO::Job* job )
         //kdDebug(5006) << k_funcinfo << "Starting dirSizeJob for folder "
         //  << entry.first->location() << endl;
         KDirSize* job = KDirSize::dirSizeJob( entry.second );
-        connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-                 entry.first, TQT_SLOT( slotDirSizeJobResult( TDEIO::Job* ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+                 entry.first, TQ_SLOT( slotDirSizeJobResult( TDEIO::Job* ) ) );
         break;
       }
       else
