@@ -173,8 +173,8 @@ KMKernel::KMKernel (TQObject *parent, const char *name) :
 #ifdef __TDE_HAVE_TDEHWLIB
   mNetworkManager = TDEGlobal::networkManager();
   if (mNetworkManager) {
-    connect( mNetworkManager, TQT_SIGNAL( networkDeviceStateChanged( TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString ) ),
-        this, TQT_SLOT( slotNetworkStateChanged( TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString ) ) );
+    connect( mNetworkManager, TQ_SIGNAL( networkDeviceStateChanged( TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString ) ),
+        this, TQ_SLOT( slotNetworkStateChanged( TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString ) ) );
     if (networkStateConnected()) {
       resumeNetworkJobs();
     }
@@ -1582,17 +1582,17 @@ void KMKernel::init()
   the_weaverLogger->attach (the_weaver);
 //#endif
 
-  connect( the_folderMgr, TQT_SIGNAL( folderRemoved(KMFolder*) ),
-           this, TQT_SIGNAL( folderRemoved(KMFolder*) ) );
-  connect( the_dimapFolderMgr, TQT_SIGNAL( folderRemoved(KMFolder*) ),
-           this, TQT_SIGNAL( folderRemoved(KMFolder*) ) );
-  connect( the_imapFolderMgr, TQT_SIGNAL( folderRemoved(KMFolder*) ),
-           this, TQT_SIGNAL( folderRemoved(KMFolder*) ) );
-  connect( the_searchFolderMgr, TQT_SIGNAL( folderRemoved(KMFolder*) ),
-           this, TQT_SIGNAL( folderRemoved(KMFolder*) ) );
+  connect( the_folderMgr, TQ_SIGNAL( folderRemoved(KMFolder*) ),
+           this, TQ_SIGNAL( folderRemoved(KMFolder*) ) );
+  connect( the_dimapFolderMgr, TQ_SIGNAL( folderRemoved(KMFolder*) ),
+           this, TQ_SIGNAL( folderRemoved(KMFolder*) ) );
+  connect( the_imapFolderMgr, TQ_SIGNAL( folderRemoved(KMFolder*) ),
+           this, TQ_SIGNAL( folderRemoved(KMFolder*) ) );
+  connect( the_searchFolderMgr, TQ_SIGNAL( folderRemoved(KMFolder*) ),
+           this, TQ_SIGNAL( folderRemoved(KMFolder*) ) );
 
   mBackgroundTasksTimer = new TQTimer( this, "mBackgroundTasksTimer" );
-  connect( mBackgroundTasksTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotRunBackgroundTasks() ) );
+  connect( mBackgroundTasksTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotRunBackgroundTasks() ) );
 #ifdef DEBUG_SCHEDULER // for debugging, see jobscheduler.h
   mBackgroundTasksTimer->start( 10000, true ); // 10s, singleshot
 #else
@@ -1982,7 +1982,7 @@ void KMKernel::dumpDeadLetters()
     return;
 
   for ( TQPtrListIterator<TDEMainWindow> it(*TDEMainWindow::memberList) ; it.current() != 0; ++it ) {
-    if ( KMail::Composer * win = ::tqqt_cast<KMail::Composer*>( it.current() ) ) {
+    if ( KMail::Composer * win = ::tqt_cast<KMail::Composer*>( it.current() ) ) {
       win->autoSaveMessage();
       // saving the message has to be finished right here, we are called from a dtor,
       // therefore we have no chance to finish this later
@@ -2020,10 +2020,10 @@ void KMKernel::byteArrayToRemoteFile(const TQByteArray &aData, const KURL &aURL,
   TDEIO::Job *job = TDEIO::put(aURL, -1, overwrite, false);
   putData pd; pd.url = aURL; pd.data = aData; pd.offset = 0;
   mPutJobs.insert(job, pd);
-  connect(job, TQT_SIGNAL(dataReq(TDEIO::Job*,TQByteArray&)),
-    TQT_SLOT(slotDataReq(TDEIO::Job*,TQByteArray&)));
-  connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
-    TQT_SLOT(slotResult(TDEIO::Job*)));
+  connect(job, TQ_SIGNAL(dataReq(TDEIO::Job*,TQByteArray&)),
+    TQ_SLOT(slotDataReq(TDEIO::Job*,TQByteArray&)));
+  connect(job, TQ_SIGNAL(result(TDEIO::Job*)),
+    TQ_SLOT(slotResult(TDEIO::Job*)));
 }
 
 void KMKernel::slotDataReq(TDEIO::Job *job, TQByteArray &data)
@@ -2079,8 +2079,8 @@ void KMKernel::slotShowConfigurationDialog()
 {
   if( !mConfigureDialog ) {
     mConfigureDialog = new ConfigureDialog( 0, "configure", false );
-    connect( mConfigureDialog, TQT_SIGNAL( configChanged() ),
-             this, TQT_SLOT( slotConfigChanged() ) );
+    connect( mConfigureDialog, TQ_SIGNAL( configChanged() ),
+             this, TQ_SLOT( slotConfigChanged() ) );
   }
 
   if( KMKernel::getKMMainWidget() == 0 )
