@@ -30,7 +30,7 @@ class RecipientsEditor;
 
 class Composer : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     Composer( TQWidget *parent );
