@@ -43,17 +43,17 @@
 #include "dialogs.h"
 
 const MainWidget::KeyData MainWidget::KEY_DATA[NB_KEYS] = {
-{I18N_NOOP("Move Up"),     "keyboard_moveup",    Key_Up,    TQT_SLOT(moveUp())},
-{I18N_NOOP("Move Down"),   "keyboard_movedown",  Key_Down,  TQT_SLOT(moveDown())},
-{I18N_NOOP("Move Right"),  "keyboard_moveright", Key_Right, TQT_SLOT(moveRight())},
-{I18N_NOOP("Move Left"),   "keyboard_moveleft",  Key_Left,  TQT_SLOT(moveLeft())},
-{I18N_NOOP("Move at Left Edge"), "keyboard_leftedge", Key_Home, TQT_SLOT(moveLeftEdge())},
-{I18N_NOOP("Move at Right Edge"), "keyboard_rightedge", Key_End, TQT_SLOT(moveRightEdge())},
-{I18N_NOOP("Move at Top Edge"), "keyboard_topedge", Key_PageUp, TQT_SLOT(moveTop())},
-{I18N_NOOP("Move at Bottom Edge"), "keyboard_bottomedge", Key_PageDown, TQT_SLOT(moveBottom())},
-{I18N_NOOP("Reveal Mine"), "keyboard_revealmine", Key_Space, TQT_SLOT(reveal())},
-{I18N_NOOP("Mark Mine"),   "keyboard_markmine",  Key_W,     TQT_SLOT(mark())},
-{I18N_NOOP("Automatic Reveal"), "keyboard_autoreveal", Key_Return, TQT_SLOT(autoReveal())}
+{I18N_NOOP("Move Up"),     "keyboard_moveup",    Key_Up,    TQ_SLOT(moveUp())},
+{I18N_NOOP("Move Down"),   "keyboard_movedown",  Key_Down,  TQ_SLOT(moveDown())},
+{I18N_NOOP("Move Right"),  "keyboard_moveright", Key_Right, TQ_SLOT(moveRight())},
+{I18N_NOOP("Move Left"),   "keyboard_moveleft",  Key_Left,  TQ_SLOT(moveLeft())},
+{I18N_NOOP("Move at Left Edge"), "keyboard_leftedge", Key_Home, TQ_SLOT(moveLeftEdge())},
+{I18N_NOOP("Move at Right Edge"), "keyboard_rightedge", Key_End, TQ_SLOT(moveRightEdge())},
+{I18N_NOOP("Move at Top Edge"), "keyboard_topedge", Key_PageUp, TQ_SLOT(moveTop())},
+{I18N_NOOP("Move at Bottom Edge"), "keyboard_bottomedge", Key_PageDown, TQ_SLOT(moveBottom())},
+{I18N_NOOP("Reveal Mine"), "keyboard_revealmine", Key_Space, TQ_SLOT(reveal())},
+{I18N_NOOP("Mark Mine"),   "keyboard_markmine",  Key_W,     TQ_SLOT(mark())},
+{I18N_NOOP("Automatic Reveal"), "keyboard_autoreveal", Key_Return, TQ_SLOT(autoReveal())}
 };
 
 
@@ -63,33 +63,33 @@ MainWidget::MainWidget()
     KNotifyClient::startDaemon();
 
     _status = new Status(this);
-    connect(_status, TQT_SIGNAL(gameStateChangedSignal(KMines::GameState)),
-            TQT_SLOT(gameStateChanged(KMines::GameState)));
-    connect(_status, TQT_SIGNAL(pause()), TQT_SLOT(pause()));
+    connect(_status, TQ_SIGNAL(gameStateChangedSignal(KMines::GameState)),
+            TQ_SLOT(gameStateChanged(KMines::GameState)));
+    connect(_status, TQ_SIGNAL(pause()), TQ_SLOT(pause()));
 
 	// Game & Popup
-	KStdGameAction::gameNew(TQT_TQOBJECT(_status), TQT_SLOT(restartGame()), actionCollection());
-	_pause = KStdGameAction::pause(TQT_TQOBJECT(_status), TQT_SLOT(pauseGame()),
+	KStdGameAction::gameNew(_status, TQ_SLOT(restartGame()), actionCollection());
+	_pause = KStdGameAction::pause(_status, TQ_SLOT(pauseGame()),
                                   actionCollection());
-	KStdGameAction::highscores(TQT_TQOBJECT(this), TQT_SLOT(showHighscores()),
+	KStdGameAction::highscores(this, TQ_SLOT(showHighscores()),
                                actionCollection());
-	KStdGameAction::quit(TQT_TQOBJECT(tqApp), TQT_SLOT(quit()), actionCollection());
+	KStdGameAction::quit(tqApp, TQ_SLOT(quit()), actionCollection());
 
 	// keyboard
     _keybCollection = new TDEActionCollection(this);
     for (uint i=0; i<NB_KEYS; i++) {
         const KeyData &d = KEY_DATA[i];
-        (void)new TDEAction(i18n(d.label), d.keycode, TQT_TQOBJECT(_status),
+        (void)new TDEAction(i18n(d.label), d.keycode, _status,
                           d.slot, _keybCollection, d.name);
     }
 
 	// Settings
-	KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(configureSettings()),
+	KStdAction::preferences(this, TQ_SLOT(configureSettings()),
                             actionCollection());
-	KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(configureKeys()), actionCollection());
-    KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(configureNotifications()),
+	KStdAction::keyBindings(this, TQ_SLOT(configureKeys()), actionCollection());
+    KStdAction::configureNotifications(this, TQ_SLOT(configureNotifications()),
                                        actionCollection());
-    KStdGameAction::configureHighscores(TQT_TQOBJECT(this), TQT_SLOT(configureHighscores()),
+    KStdGameAction::configureHighscores(this, TQ_SLOT(configureHighscores()),
                                         actionCollection());
 	// Levels
     _levels = KStdGameAction::chooseGameType(0, 0, actionCollection());
@@ -97,27 +97,27 @@ MainWidget::MainWidget()
     for (uint i=0; i<=Level::NB_TYPES; i++)
         list += i18n(Level::LABELS[i]);
     _levels->setItems(list);
-    connect(_levels, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(_status), TQT_SLOT(newGame(int)));
+    connect(_levels, TQ_SIGNAL(activated(int)), _status, TQ_SLOT(newGame(int)));
 
     // Adviser
     _advise =
-        KStdGameAction::hint(TQT_TQOBJECT(_status), TQT_SLOT(advise()), actionCollection());
-    _solve = KStdGameAction::solve(TQT_TQOBJECT(_status), TQT_SLOT(solve()), actionCollection());
-    (void)new TDEAction(i18n("Solving Rate..."), 0, TQT_TQOBJECT(_status), TQT_SLOT(solveRate()),
+        KStdGameAction::hint(_status, TQ_SLOT(advise()), actionCollection());
+    _solve = KStdGameAction::solve(_status, TQ_SLOT(solve()), actionCollection());
+    (void)new TDEAction(i18n("Solving Rate..."), 0, _status, TQ_SLOT(solveRate()),
                       actionCollection(), "solve_rate");
 
     // Log
     (void)new TDEAction(KGuiItem(i18n("View Log"), "viewmag"), 0,
-                      TQT_TQOBJECT(_status), TQT_SLOT(viewLog()),
+                      _status, TQ_SLOT(viewLog()),
                       actionCollection(), "log_view");
     (void)new TDEAction(KGuiItem(i18n("Replay Log"), "media-playback-start"),
-                      0, TQT_TQOBJECT(_status), TQT_SLOT(replayLog()),
+                      0, _status, TQ_SLOT(replayLog()),
                       actionCollection(), "log_replay");
     (void)new TDEAction(KGuiItem(i18n("Save Log..."), "document-save"), 0,
-                      TQT_TQOBJECT(_status), TQT_SLOT(saveLog()),
+                      _status, TQ_SLOT(saveLog()),
                       actionCollection(), "log_save");
     (void)new TDEAction(KGuiItem(i18n("Load Log..."), "document-open"), 0,
-                      TQT_TQOBJECT(_status), TQT_SLOT(loadLog()),
+                      _status, TQ_SLOT(loadLog()),
                       actionCollection(), "log_load");
 
 	setupGUI( TDEMainWindow::Save | Create );
@@ -163,7 +163,7 @@ void MainWidget::configureSettings()
     dialog->addPage(new AppearanceConfig, i18n("Appearance"), "style");
     CustomConfig *cc = new CustomConfig;
     dialog->addPage(cc, i18n("Custom Game"), "package_settings");
-    connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_SLOT(settingsChanged()));
+    connect(dialog, TQ_SIGNAL(settingsChanged()), TQ_SLOT(settingsChanged()));
     dialog->show();
     cc->init();
     gc->init();
