@@ -138,8 +138,8 @@ TQString KNConfig::Identity::getSignature()
         for ( TQStringList::Iterator it = command.begin(); it != command.end(); ++it )
           process << (*it);
 
-        connect(&process, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), TQT_SLOT(slotReceiveStdout(TDEProcess *, char *, int)));
-        connect(&process, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), TQT_SLOT(slotReceiveStderr(TDEProcess *, char *, int)));
+        connect(&process, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)), TQ_SLOT(slotReceiveStdout(TDEProcess *, char *, int)));
+        connect(&process, TQ_SIGNAL(receivedStderr(TDEProcess *, char *, int)), TQ_SLOT(slotReceiveStderr(TDEProcess *, char *, int)));
 
         if (!process.start(TDEProcess::Block,TDEProcess::AllOutput))
           KMessageBox::error(knGlobals.topWidget, i18n("Cannot run the signature generator."));
