@@ -27,11 +27,11 @@
 #include <tqstring.h>
 #include <tqstringlist.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace KODE {
 
-class KDE_EXPORT Style
+class TDE_EXPORT Style
 {
   public:
     Style();
