@@ -19,7 +19,7 @@
 	@author Andras Mantia <amantia@kdewebdev.org>
 */
 
-class KDE_EXPORT ToolBox : public TQToolBox, public KommanderWidget
+class TDE_EXPORT ToolBox : public TQToolBox, public KommanderWidget
 {
   TQ_OBJECT
   
