@@ -32,7 +32,7 @@
 #include <tdelocale.h>
 #include <tdemessagebox.h>
 #include <kstdaction.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdetempfile.h>
 #include <tdeparts/genericfactory.h>
 //#include <ktempdir.h>
