@@ -22,7 +22,7 @@
 #include <tdeaction.h>
 #include <tdeglobal.h>
 #include <tdeconfig.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdehtml_part.h>
 #include <kgenericfactory.h>
 
