@@ -11,7 +11,7 @@ class KURL;
 
 class PluginDomtreeviewer : public KParts::Plugin
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   PluginDomtreeviewer( TQObject* parent, const char* name,
