@@ -23,7 +23,7 @@
 class KCMKuick
 	: public TDECModule
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
