@@ -30,7 +30,7 @@ class TDEConfigDialog;
 namespace KSB_News {
 
   class NoRSSWidget : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
