@@ -49,21 +49,21 @@ ChatTextEditPart::ChatTextEditPart( Kopete::ChatSession *session, TQWidget *pare
 	edit()->setAutoFormatting( TQTextEdit::AutoNone );
 
 	// some signals and slots connections
-	connect( edit(), TQT_SIGNAL( textChanged()), this, TQT_SLOT( slotTextChanged() ) );
+	connect( edit(), TQ_SIGNAL( textChanged()), this, TQ_SLOT( slotTextChanged() ) );
 
 	// timers for typing notifications
 	m_typingRepeatTimer = new TQTimer(this, "m_typingRepeatTimer");
 	m_typingStopTimer   = new TQTimer(this, "m_typingStopTimer");
 
-	connect( m_typingRepeatTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotRepeatTypingTimer() ) );
-	connect( m_typingStopTimer,   TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotStoppedTypingTimer() ) );
+	connect( m_typingRepeatTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotRepeatTypingTimer() ) );
+	connect( m_typingStopTimer,   TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotStoppedTypingTimer() ) );
 
-	connect( session, TQT_SIGNAL( contactAdded(const Kopete::Contact*, bool) ),
-	         this, TQT_SLOT( slotContactAdded(const Kopete::Contact*) ) );
-	connect( session, TQT_SIGNAL( contactRemoved(const Kopete::Contact*, const TQString&, Kopete::Message::MessageFormat, bool) ),
-	         this, TQT_SLOT( slotContactRemoved(const Kopete::Contact*) ) );
-	connect( session, TQT_SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus & , const Kopete::OnlineStatus &) ),
-	         this, TQT_SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
+	connect( session, TQ_SIGNAL( contactAdded(const Kopete::Contact*, bool) ),
+	         this, TQ_SLOT( slotContactAdded(const Kopete::Contact*) ) );
+	connect( session, TQ_SIGNAL( contactRemoved(const Kopete::Contact*, const TQString&, Kopete::Message::MessageFormat, bool) ),
+	         this, TQ_SLOT( slotContactRemoved(const Kopete::Contact*) ) );
+	connect( session, TQ_SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus & , const Kopete::OnlineStatus &) ),
+	         this, TQ_SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
 	
 	slotContactAdded( session->myself() );
 	for ( TQPtrListIterator<Kopete::Contact> it( session->members() ); it.current(); ++it )
@@ -195,8 +195,8 @@ void ChatTextEditPart::slotPropertyChanged( Kopete::Contact*, const TQString &ke
 
 void ChatTextEditPart::slotContactAdded( const Kopete::Contact *contact )
 {
-	connect( contact, TQT_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
-	         this, TQT_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
+	connect( contact, TQ_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
+	         this, TQ_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
 	
 	TQString contactName = contact->property(Kopete::Global::Properties::self()->nickName()).value().toString();
 	mComplete->addItem( contactName );
@@ -204,8 +204,8 @@ void ChatTextEditPart::slotContactAdded( const Kopete::Contact *contact )
 
 void ChatTextEditPart::slotContactRemoved( const Kopete::Contact *contact )
 {
-	disconnect( contact, TQT_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
-	            this, TQT_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
+	disconnect( contact, TQ_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
+	            this, TQ_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
 	
 	TQString contactName = contact->property(Kopete::Global::Properties::self()->nickName()).value().toString();
 	mComplete->removeItem( contactName );
