@@ -27,7 +27,7 @@ class TQStringList;
 
 class KOPETE_EXPORT OscarListNonServerContacts : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     OscarListNonServerContacts( TQWidget* parent );
