@@ -31,7 +31,7 @@
 #include <tdefile.h>
 #include <korganizer/koeventviewer.h>
 #include <libkcal/scheduler.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include "koglobals.h"
 #include "interfaces/korganizer/calendarviewbase.h"
@@ -78,7 +78,7 @@ class CalendarViewExtension : public TQWidget
   @short main calendar view widget
   @author Cornelius Schumacher
 */
-class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::Observer
+class TDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::Observer
 {
     TQ_OBJECT
   
