@@ -284,7 +284,7 @@ KOAgendaView::KOAgendaView( Calendar *cal,
 
   // Create agenda splitter
 #ifndef KORG_NOSPLITTER
-  mSplitterAgenda = new TQSplitter(Qt::Vertical,this);
+  mSplitterAgenda = new TQSplitter(TQt::Vertical,this);
   topLayout->addWidget(mSplitterAgenda);
 
 #if KDE_IS_VERSION( 3, 1, 93 )
@@ -315,7 +315,7 @@ KOAgendaView::KOAgendaView( Calendar *cal,
     mExpandButton->setPixmap( mNotExpandedPixmap );
     mExpandButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed,
                                   TQSizePolicy::Fixed ) );
-    connect( mExpandButton, TQT_SIGNAL( clicked() ), TQT_SIGNAL( toggleExpand() ) );
+    connect( mExpandButton, TQ_SIGNAL( clicked() ), TQ_SIGNAL( toggleExpand() ) );
   } else {
     TQLabel *label = new TQLabel( i18n("All Day"), mDummyAllDayLeft );
     label->setAlignment( TQt::AlignRight | TQt::AlignVCenter | TQt::WordBreak );
@@ -373,27 +373,27 @@ KOAgendaView::KOAgendaView( Calendar *cal,
   updateTimeBarWidth();
 
   // Scrolling
-  connect(mAgenda->verticalScrollBar(),TQT_SIGNAL(valueChanged(int)),
-          mTimeLabels, TQT_SLOT(positionChanged()));
+  connect(mAgenda->verticalScrollBar(),TQ_SIGNAL(valueChanged(int)),
+          mTimeLabels, TQ_SLOT(positionChanged()));
 
   connect( mAgenda,
-    TQT_SIGNAL( zoomView( const int, const TQPoint & ,const Qt::Orientation ) ),
-    TQT_SLOT( zoomView( const int, const TQPoint &, const Qt::Orientation ) ) );
+    TQ_SIGNAL( zoomView( const int, const TQPoint & ,const TQt::Orientation ) ),
+    TQ_SLOT( zoomView( const int, const TQPoint &, const TQt::Orientation ) ) );
 
-  connect(mTimeLabels->verticalScrollBar(),TQT_SIGNAL(valueChanged(int)),
-          TQT_SLOT(setContentsPos(int)));
+  connect(mTimeLabels->verticalScrollBar(),TQ_SIGNAL(valueChanged(int)),
+          TQ_SLOT(setContentsPos(int)));
 
   // Create Events, depends on type of agenda
-  connect( mAgenda, TQT_SIGNAL(newTimeSpanSignal(const TQPoint &, const TQPoint &)),
-                    TQT_SLOT(newTimeSpanSelected(const TQPoint &, const TQPoint &)));
-  connect( mAllDayAgenda, TQT_SIGNAL(newTimeSpanSignal(const TQPoint &, const TQPoint &)),
-                          TQT_SLOT(newTimeSpanSelectedAllDay(const TQPoint &, const TQPoint &)));
+  connect( mAgenda, TQ_SIGNAL(newTimeSpanSignal(const TQPoint &, const TQPoint &)),
+                    TQ_SLOT(newTimeSpanSelected(const TQPoint &, const TQPoint &)));
+  connect( mAllDayAgenda, TQ_SIGNAL(newTimeSpanSignal(const TQPoint &, const TQPoint &)),
+                          TQ_SLOT(newTimeSpanSelectedAllDay(const TQPoint &, const TQPoint &)));
 
   // event indicator update
-  connect( mAgenda, TQT_SIGNAL(lowerYChanged(int)),
-                    TQT_SLOT(updateEventIndicatorTop(int)));
-  connect( mAgenda, TQT_SIGNAL(upperYChanged(int)),
-                    TQT_SLOT(updateEventIndicatorBottom(int)));
+  connect( mAgenda, TQ_SIGNAL(lowerYChanged(int)),
+                    TQ_SLOT(updateEventIndicatorTop(int)));
+  connect( mAgenda, TQ_SIGNAL(upperYChanged(int)),
+                    TQ_SLOT(updateEventIndicatorBottom(int)));
 
   if ( !readOnly() ) {
     connectAgenda( mAgenda, mAgendaPopup, mAllDayAgenda );
@@ -417,53 +417,53 @@ KOAgendaView::~KOAgendaView()
 void KOAgendaView::connectAgenda( KOAgenda *agenda, TQPopupMenu *popup,
                                   KOAgenda *otherAgenda )
 {
-  connect( agenda, TQT_SIGNAL(showIncidencePopupSignal(Calendar *,Incidence *,const TQDate &)),
-           popup, TQT_SLOT(showIncidencePopup(Calendar *,Incidence *,const TQDate &)) );
+  connect( agenda, TQ_SIGNAL(showIncidencePopupSignal(Calendar *,Incidence *,const TQDate &)),
+           popup, TQ_SLOT(showIncidencePopup(Calendar *,Incidence *,const TQDate &)) );
 
-  connect( agenda, TQT_SIGNAL(showNewEventPopupSignal()),
-           TQT_SLOT(showNewEventPopup()) );
+  connect( agenda, TQ_SIGNAL(showNewEventPopupSignal()),
+           TQ_SLOT(showNewEventPopup()) );
 
 
   // Create/Show/Edit/Delete Event
-  connect( agenda, TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &)),
-           TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &)) );
+  connect( agenda, TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &)),
+           TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &)) );
 
-  connect( agenda, TQT_SIGNAL(newStartSelectSignal()),
-           otherAgenda, TQT_SLOT(clearSelection()) );
-  connect( agenda, TQT_SIGNAL(newStartSelectSignal()),
-           TQT_SIGNAL(timeSpanSelectionChanged()) );
+  connect( agenda, TQ_SIGNAL(newStartSelectSignal()),
+           otherAgenda, TQ_SLOT(clearSelection()) );
+  connect( agenda, TQ_SIGNAL(newStartSelectSignal()),
+           TQ_SIGNAL(timeSpanSelectionChanged()) );
 
-  connect( agenda, TQT_SIGNAL(editIncidenceSignal(Incidence *,const TQDate &)),
-           TQT_SIGNAL(editIncidenceSignal(Incidence *,const TQDate &)) );
-  connect( agenda, TQT_SIGNAL(showIncidenceSignal(Incidence *,const TQDate &)),
-           TQT_SIGNAL(showIncidenceSignal(Incidence *,const TQDate &)) );
-  connect( agenda, TQT_SIGNAL(deleteIncidenceSignal(Incidence *)),
-           TQT_SIGNAL(deleteIncidenceSignal(Incidence *)) );
+  connect( agenda, TQ_SIGNAL(editIncidenceSignal(Incidence *,const TQDate &)),
+           TQ_SIGNAL(editIncidenceSignal(Incidence *,const TQDate &)) );
+  connect( agenda, TQ_SIGNAL(showIncidenceSignal(Incidence *,const TQDate &)),
+           TQ_SIGNAL(showIncidenceSignal(Incidence *,const TQDate &)) );
+  connect( agenda, TQ_SIGNAL(deleteIncidenceSignal(Incidence *)),
+           TQ_SIGNAL(deleteIncidenceSignal(Incidence *)) );
 
-  connect( agenda, TQT_SIGNAL(startMultiModify(const TQString &)),
-           TQT_SIGNAL(startMultiModify(const TQString &)) );
-  connect( agenda, TQT_SIGNAL(endMultiModify()),
-           TQT_SIGNAL(endMultiModify()) );
+  connect( agenda, TQ_SIGNAL(startMultiModify(const TQString &)),
+           TQ_SIGNAL(startMultiModify(const TQString &)) );
+  connect( agenda, TQ_SIGNAL(endMultiModify()),
+           TQ_SIGNAL(endMultiModify()) );
 
-  connect( agenda, TQT_SIGNAL(itemModified(KOAgendaItem *)),
-           TQT_SLOT(updateEventDates(KOAgendaItem *)) );
+  connect( agenda, TQ_SIGNAL(itemModified(KOAgendaItem *)),
+           TQ_SLOT(updateEventDates(KOAgendaItem *)) );
 
-  connect( agenda, TQT_SIGNAL(enableAgendaUpdate(bool)),
-           TQT_SLOT(enableAgendaUpdate(bool)) );
+  connect( agenda, TQ_SIGNAL(enableAgendaUpdate(bool)),
+           TQ_SLOT(enableAgendaUpdate(bool)) );
 
   // drag signals
-  connect( agenda, TQT_SIGNAL(startDragSignal(Incidence *)),
-           TQT_SLOT(startDrag(Incidence *)) );
+  connect( agenda, TQ_SIGNAL(startDragSignal(Incidence *)),
+           TQ_SLOT(startDrag(Incidence *)) );
 
   // synchronize selections
-  connect( agenda, TQT_SIGNAL(incidenceSelected(Incidence *,const TQDate &)),
-           otherAgenda, TQT_SLOT(deselectItem()) );
-  connect( agenda, TQT_SIGNAL(incidenceSelected(Incidence *,const TQDate &)),
-           TQT_SIGNAL(incidenceSelected(Incidence *,const TQDate &)) );
+  connect( agenda, TQ_SIGNAL(incidenceSelected(Incidence *,const TQDate &)),
+           otherAgenda, TQ_SLOT(deselectItem()) );
+  connect( agenda, TQ_SIGNAL(incidenceSelected(Incidence *,const TQDate &)),
+           TQ_SIGNAL(incidenceSelected(Incidence *,const TQDate &)) );
 
   // rescheduling of todos by d'n'd
-  connect( agenda, TQT_SIGNAL(droppedToDo(Todo *,const TQPoint &,bool)),
-           TQT_SLOT(slotTodoDropped(Todo *,const TQPoint &,bool)) );
+  connect( agenda, TQ_SIGNAL(droppedToDo(Todo *,const TQPoint &,bool)),
+           TQ_SLOT(slotTodoDropped(Todo *,const TQPoint &,bool)) );
 
 }
 
@@ -561,7 +561,7 @@ void KOAgendaView::zoomOutHorizontally( const TQDate &date )
 }
 
 void KOAgendaView::zoomView( const int delta, const TQPoint &pos,
-  const Qt::Orientation orient )
+  const TQt::Orientation orient )
 {
   static TQDate zoomDate;
   static TQTimer *t = new TQTimer( this );
@@ -569,7 +569,7 @@ void KOAgendaView::zoomView( const int delta, const TQPoint &pos,
 
   //Zoom to the selected incidence, on the other way
   // zoom to the date on screen after the first mousewheel move.
-  if ( orient == Qt::Horizontal ) {
+  if ( orient == TQt::Horizontal ) {
     TQDate date=mAgenda->selectedIncidenceDate();
     if ( date.isValid() )
       zoomDate=date;
@@ -584,7 +584,7 @@ void KOAgendaView::zoomView( const int delta, const TQPoint &pos,
     else
       zoomInHorizontally( zoomDate );
   } else {
-    // Qt::Vertical zoom
+    // Vertical zoom
     TQPoint posConstentsOld = mAgenda->gridToContents(pos);
     if ( delta > 0 ) {
       zoomOutVertically();
@@ -682,7 +682,7 @@ void KOAgendaView::createDayLabels( bool force )
   if ( !mIsSideBySide )
     mLayoutDayLabels->addSpacing(mAgenda->verticalScrollBar()->width());
   mDayLabels->show();
-  TQTimer::singleShot( 0, this, TQT_SLOT( updateDayLabelSizes() ) );
+  TQTimer::singleShot( 0, this, TQ_SLOT( updateDayLabelSizes() ) );
 }
 
 void KOAgendaView::enableAgendaUpdate( bool enable )
@@ -1117,7 +1117,7 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
 
   if ( !result ) {
     mPendingChanges = true;
-    TQTimer::singleShot( 0, this, TQT_SLOT(updateView()) );
+    TQTimer::singleShot( 0, this, TQ_SLOT(updateView()) );
     return;
   }
 
@@ -1131,7 +1131,7 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
   // recreated. All others have to!!!
   if ( incidence->doesRecur() ) {
     mUpdateItem = incidence;
-    TQTimer::singleShot( 0, this, TQT_SLOT( doUpdateItem() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( doUpdateItem() ) );
   }
 
     enableAgendaUpdate( true );
