@@ -50,6 +50,7 @@ Shell::Shell()
   : DCOPObject("KPDFShellDCOPIface"), KParts::MainWindow(0, "KPDF::Shell"),
     m_menuBarWasShown(true),
     m_toolBarWasShown(true),
+    m_showToolBarAction(nullptr),
     m_tabs(nullptr),
     m_tabsContextMenu(nullptr),
     m_manager(nullptr),
@@ -62,6 +63,7 @@ Shell::Shell(const KURL &url)
   : DCOPObject("KPDFShellDCOPIface"), KParts::MainWindow(0, "KPDF::Shell"),
     m_menuBarWasShown(true),
     m_toolBarWasShown(true),
+    m_showToolBarAction(nullptr),
     m_tabs(nullptr),
     m_tabsContextMenu(nullptr),
     m_manager(nullptr),
@@ -105,7 +107,6 @@ void Shell::init()
 
   setupActions();
   setupGUI(Keys | Save);
-  m_showToolBarAction = static_cast<TDEToggleAction*>(toolBarMenuAction());
 
   readSettings();
   if (!TDEGlobal::config()->hasGroup("MainWindow"))
@@ -384,6 +385,10 @@ KParts::ReadOnlyPart* Shell::createTab()
 
   part->widget()->show();
   m_manager->addPart(part, true);
+  if (!m_showToolBarAction)
+  {
+    m_showToolBarAction = static_cast<TDEToggleAction*>(toolBarMenuAction());
+  }
   return part;
 }
 
