@@ -1172,7 +1172,7 @@ void ConnectWidget::if_waiting_slot() {
       return;
     }
 
-    if_timer->start(100, TRUE); // single shot
+    if_timer->start(100, true); // single shot
     return;
   }
 
@@ -1385,7 +1385,7 @@ void auto_hostname() {
       dot=new_hostname.find('.');
       new_hostname=new_hostname.remove(dot,new_hostname.length()-dot);
       Requester::rq->setHostname(new_hostname);
-      modified_hostname = TRUE;
+      modified_hostname = true;
 
       new_hostname=hostname_entry->h_name;
       new_hostname.remove(0,dot+1);
@@ -1532,7 +1532,7 @@ void removedns() {
 
   if (  modified_hostname ) {
     Requester::rq->setHostname(old_hostname);
-    modified_hostname = FALSE;
+    modified_hostname = false;
   }
 
 }
