@@ -41,7 +41,7 @@
 #include <kstdguiitem.h>
 
 PPPdArguments::PPPdArguments(TQWidget *parent, const char *name)
-  : TQDialog(parent, name, TRUE)
+  : TQDialog(parent, name, true)
 {
   setCaption(i18n("Customize pppd Arguments"));
   KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
