@@ -33,6 +33,7 @@
 #include <tdemessagebox.h>
 #include <twin.h>
 #include <tdestartupinfo.h>
+#include <tqclipboard.h>
 
 #include <tqdockarea.h>
 #include <tqlabel.h>
@@ -51,6 +52,7 @@ const int FS_HOSTLABEL_ID = 4;
 const int FS_ADVANCED_ID = 5;
 const int FS_ICONIFY_ID = 6;
 const int FS_CLOSE_ID = 7;
+const int FS_PASTE_ID = 8;
 
 const int KRDC::TOOLBAR_AUTOHIDE_TIMEOUT = 1000;
 const int KRDC::TOOLBAR_FPS_1000 = 10000;
@@ -101,8 +103,8 @@ KRDC::KRDC(WindowMode wm, const TQString &host,
   m_localCursor(localCursor),
   m_initialWindowSize(initialWindowSize)
 {
-	connect(&m_autoHideTimer, TQT_SIGNAL(timeout()), TQT_SLOT(hideFullscreenToolbarNow()));
-	connect(&m_bumpScrollTimer, TQT_SIGNAL(timeout()), TQT_SLOT(bumpScroll()));
+	connect(&m_autoHideTimer, TQ_SIGNAL(timeout()), TQ_SLOT(hideFullscreenToolbarNow()));
+	connect(&m_bumpScrollTimer, TQ_SIGNAL(timeout()), TQ_SLOT(bumpScroll()));
 
 	m_pindown = UserIcon("pindown");
 	m_pinup   = UserIcon("pinup");
@@ -192,18 +194,18 @@ bool KRDC::start()
 	m_scrollView->addChild(m_view);
 	TQWhatsThis::add(m_view, i18n("Here you can see the remote desktop. If the other side allows you to control it, you can also move the mouse, click or enter keystrokes. If the content does not fit your screen, click on the toolbar's full screen button or scale button. To end the connection, just close the window."));
 
-	connect(m_view, TQT_SIGNAL(changeSize(int,int)), TQT_SLOT(setSize(int,int)));
-	connect(m_view, TQT_SIGNAL(connected()), TQT_SLOT(show()));
-	connect(m_view, TQT_SIGNAL(disconnected()), TQT_SIGNAL(disconnected()));
+	connect(m_view, TQ_SIGNAL(changeSize(int,int)), TQ_SLOT(setSize(int,int)));
+	connect(m_view, TQ_SIGNAL(connected()), TQ_SLOT(show()));
+	connect(m_view, TQ_SIGNAL(disconnected()), TQ_SIGNAL(disconnected()));
 	// note that the disconnectedError() will be disconnected when kremoteview
 	// is completely initialized
-	connect(m_view, TQT_SIGNAL(disconnectedError()), TQT_SIGNAL(disconnectedError()));
-	connect(m_view, TQT_SIGNAL(statusChanged(RemoteViewStatus)),
-		TQT_SLOT(changeProgress(RemoteViewStatus)));
-	connect(m_view, TQT_SIGNAL(showingPasswordDialog(bool)),
-		TQT_SLOT(showingPasswordDialog(bool)));
-	connect(m_keyCaptureDialog, TQT_SIGNAL(keyPressed(XEvent*)),
-		m_view, TQT_SLOT(pressKey(XEvent*)));
+	connect(m_view, TQ_SIGNAL(disconnectedError()), TQ_SIGNAL(disconnectedError()));
+	connect(m_view, TQ_SIGNAL(statusChanged(RemoteViewStatus)),
+		TQ_SLOT(changeProgress(RemoteViewStatus)));
+	connect(m_view, TQ_SIGNAL(showingPasswordDialog(bool)),
+		TQ_SLOT(showingPasswordDialog(bool)));
+	connect(m_keyCaptureDialog, TQ_SIGNAL(keyPressed(XEvent*)),
+		m_view, TQ_SLOT(pressKey(XEvent*)));
 
 	ret_status = m_view->start();
 
@@ -219,8 +221,8 @@ void KRDC::changeProgress(RemoteViewStatus s) {
 		m_progress = m_progressDialog->progressBar();
 		m_progress->setTextEnabled(false);
 		m_progress->setTotalSteps(3);
-		connect(m_progressDialog, TQT_SIGNAL(cancelClicked()),
-			TQT_SIGNAL(disconnectedError()));
+		connect(m_progressDialog, TQ_SIGNAL(cancelClicked()),
+			TQ_SIGNAL(disconnectedError()));
 	}
 
 	if (s == REMOTE_VIEW_CONNECTING) {
@@ -243,10 +245,10 @@ void KRDC::changeProgress(RemoteViewStatus s) {
 		m_progress->setValue(3);
 		hideProgressDialog();
 		if (s == REMOTE_VIEW_CONNECTED) {
-			TQObject::disconnect(m_view, TQT_SIGNAL(disconnectedError()),
-					    this, TQT_SIGNAL(disconnectedError()));
-			connect(m_view, TQT_SIGNAL(disconnectedError()),
-				TQT_SIGNAL(disconnected()));
+			TQObject::disconnect(m_view, TQ_SIGNAL(disconnectedError()),
+					    this, TQ_SIGNAL(disconnectedError()));
+			connect(m_view, TQ_SIGNAL(disconnectedError()),
+				TQ_SIGNAL(disconnected()));
 			if (m_view->startFullscreen()) {
 				// m_view instance is asking to start in fullscreen mode
 				enableFullscreen(true);
@@ -268,7 +270,7 @@ void KRDC::showingPasswordDialog(bool b) {
 
 void KRDC::showProgressDialog() {
 	m_showProgress = true;
-	TQTimer::singleShot(400, this, TQT_SLOT(showProgressTimeout()));
+	TQTimer::singleShot(400, this, TQ_SLOT(showProgressTimeout()));
 }
 
 void KRDC::hideProgressDialog() {
@@ -373,6 +375,13 @@ void KRDC::enableFullscreen(bool on)
 	m_view->switchFullscreen(on);
 }
 
+void KRDC::paste()
+{
+	TQClipboard *cb = TQApplication::clipboard();
+	TQString text = cb->text(TQClipboard::Clipboard);
+	m_view->sendString(text);
+}
+
 TQSize KRDC::sizeHint()
 {
 	if ((m_isFullscreen != WINDOW_MODE_FULLSCREEN) && m_toolbar) {
@@ -387,12 +396,12 @@ TQSize KRDC::sizeHint()
 
 TQPopupMenu *KRDC::createPopupMenu(TQWidget *parent) const {
 	TDEPopupMenu *pu = new TDEPopupMenu(parent);
-	pu->insertItem(i18n("View Only"), this, TQT_SLOT(viewOnlyToggled()), 0, VIEW_ONLY_ID);
+	pu->insertItem(i18n("View Only"), this, TQ_SLOT(viewOnlyToggled()), 0, VIEW_ONLY_ID);
 	pu->setCheckable(true);
 	pu->setItemChecked(VIEW_ONLY_ID, m_view->viewOnly());
 	if (m_view->supportsLocalCursor()) {
 		pu->insertItem(i18n("Always Show Local Cursor"), this,
-			TQT_SLOT(showLocalCursorToggled()), 0,
+			TQ_SLOT(showLocalCursorToggled()), 0,
 			SHOW_LOCAL_CURSOR_ID);
 		pu->setCheckable(true);
 		pu->setItemChecked(SHOW_LOCAL_CURSOR_ID,
@@ -475,8 +484,8 @@ void KRDC::switchToFullscreen(bool scaling)
 	}
 
 	m_fsToolbar = new KFullscreenPanel(this, "fstoolbar", m_fullscreenResolution);
-	connect(m_fsToolbar, TQT_SIGNAL(mouseEnter()), TQT_SLOT(showFullscreenToolbar()));
-	connect(m_fsToolbar, TQT_SIGNAL(mouseLeave()), TQT_SLOT(hideFullscreenToolbarDelayed()));
+	connect(m_fsToolbar, TQ_SIGNAL(mouseEnter()), TQ_SLOT(showFullscreenToolbar()));
+	connect(m_fsToolbar, TQ_SIGNAL(mouseLeave()), TQ_SLOT(hideFullscreenToolbarDelayed()));
 
 	TDEToolBar *t = new TDEToolBar(m_fsToolbar);
 	m_fsToolbarWidget = t;
@@ -490,14 +499,22 @@ void KRDC::switchToFullscreen(bool scaling)
 	pinButton->setIconSet(pinIconSet);
 	TQToolTip::add(pinButton, i18n("Autohide on/off"));
 	t->setToggle(FS_AUTOHIDE_ID);
-	t->addConnection(FS_AUTOHIDE_ID, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(setFsToolbarAutoHide(bool)));
+	t->addConnection(FS_AUTOHIDE_ID, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setFsToolbarAutoHide(bool)));
 
 	t->insertButton("view-restore", FS_FULLSCREEN_ID);
 	TDEToolBarButton *fullscreenButton = t->getButton(FS_FULLSCREEN_ID);
 	TQToolTip::add(fullscreenButton, i18n("Fullscreen"));
 	t->setToggle(FS_FULLSCREEN_ID);
 	t->setButton(FS_FULLSCREEN_ID, true);
-	t->addConnection(FS_FULLSCREEN_ID, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(enableFullscreen(bool)));
+	t->addConnection(FS_FULLSCREEN_ID, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(enableFullscreen(bool)));
+
+	if(m_view->supportsSendString())
+	{
+		t->insertButton("edit-paste", FS_PASTE_ID);
+		TDEToolBarButton *pasteButton = t->getButton(FS_PASTE_ID);
+		TQToolTip::add(pasteButton, i18n("Sends clipboard text to the remote system as key presses"));
+		t->addConnection(FS_PASTE_ID, TQ_SIGNAL(clicked()), this, TQ_SLOT(paste()));
+	}
 
 	m_popup = createPopupMenu(t);
 	t->insertButton("configure", FS_ADVANCED_ID, m_popup, true, i18n("Advanced options"));
@@ -517,18 +534,18 @@ void KRDC::switchToFullscreen(bool scaling)
 		TQToolTip::add(scaleButton, i18n("Scale view"));
 		t->setToggle(FS_SCALE_ID);
 		t->setButton(FS_SCALE_ID, scaling);
-		t->addConnection(FS_SCALE_ID, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(switchToFullscreen(bool)));
+		t->addConnection(FS_SCALE_ID, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(switchToFullscreen(bool)));
 	}
 
 	t->insertButton("iconify", FS_ICONIFY_ID);
 	TDEToolBarButton *iconifyButton = t->getButton(FS_ICONIFY_ID);
 	TQToolTip::add(iconifyButton, i18n("Minimize"));
-	t->addConnection(FS_ICONIFY_ID, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(iconify()));
+	t->addConnection(FS_ICONIFY_ID, TQ_SIGNAL(clicked()), this, TQ_SLOT(iconify()));
 
 	t->insertButton("close", FS_CLOSE_ID);
 	TDEToolBarButton *closeButton = t->getButton(FS_CLOSE_ID);
 	TQToolTip::add(closeButton, i18n("Close"));
-	t->addConnection(FS_CLOSE_ID, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(quit()));
+	t->addConnection(FS_CLOSE_ID, TQ_SIGNAL(clicked()), this, TQ_SLOT(quit()));
 
 	m_fsToolbar->setChild(t);
 
@@ -585,20 +602,20 @@ void KRDC::switchToNormal(bool scaling)
 	}
 
 	if (!m_toolbar) {
-		m_dockArea = new TQDockArea(Qt::Horizontal, TQDockArea::Normal, this);
+		m_dockArea = new TQDockArea(TQt::Horizontal, TQDockArea::Normal, this);
 		m_dockArea->setSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding,
 					TQSizePolicy::Fixed));
 		TDEToolBar *t = new TDEToolBar(m_dockArea);
 		m_toolbar = t;
 		t->setIconText(TDEToolBar::IconTextRight);
-		connect(t, TQT_SIGNAL(placeChanged(TQDockWindow::Place)), TQT_SLOT(toolbarChanged()));
+		connect(t, TQ_SIGNAL(placeChanged(TQDockWindow::Place)), TQ_SLOT(toolbarChanged()));
 		t->insertButton("view-fullscreen", 0, true, i18n("Fullscreen"));
 		TDEToolBarButton *fullscreenButton = t->getButton(0);
 		TQToolTip::add(fullscreenButton, i18n("Fullscreen"));
 		TQWhatsThis::add(fullscreenButton, i18n("Switches to full screen. If the remote desktop has a different screen resolution, Remote Desktop Connection will automatically switch to the nearest resolution."));
 		t->setToggle(0);
 		t->setButton(0, false);
-		t->addConnection(0, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(enableFullscreen(bool)));
+		t->addConnection(0, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(enableFullscreen(bool)));
 
 		if (m_view->supportsScaling()) {
 			t->insertButton("zoom-fit-best", 1, true, i18n("Scale"));
@@ -607,20 +624,28 @@ void KRDC::switchToNormal(bool scaling)
 			TQWhatsThis::add(scaleButton, i18n("This option scales the remote screen to fit your window size."));
 			t->setToggle(1);
 			t->setButton(1, scaling);
-			t->addConnection(1, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(switchToNormal(bool)));
+			t->addConnection(1, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(switchToNormal(bool)));
 		}
 
 		t->insertButton("key_enter", 2, true, i18n("Special Keys"));
 		TDEToolBarButton *skButton = t->getButton(2);
 		TQToolTip::add(skButton, i18n("Enter special keys."));
 		TQWhatsThis::add(skButton, i18n("This option allows you to send special key combinations like Ctrl-Alt-Del to the remote host."));
-		t->addConnection(2, TQT_SIGNAL(clicked()), TQT_TQOBJECT(m_keyCaptureDialog), TQT_SLOT(execute()));
+		t->addConnection(2, TQ_SIGNAL(clicked()), m_keyCaptureDialog, TQ_SLOT(execute()));
 
 		if (m_popup) {
 			m_popup->deleteLater();
 			m_popup = 0;
 		}
 
+		if(m_view->supportsSendString())
+		{
+			t->insertButton("edit-paste", 4, true, i18n("Paste"));
+			TDEToolBarButton *pasteButton = t->getButton(4);
+			TQToolTip::add(pasteButton, i18n("Sends clipboard text to the remote system as key presses"));
+			t->addConnection(4, TQ_SIGNAL(clicked()), this, TQ_SLOT(paste()));
+		}
+
 		m_popup = createPopupMenu(t);
 		t->insertButton("configure", 3, m_popup, true, i18n("Advanced"));
 		TDEToolBarButton *advancedButton = t->getButton(3);
@@ -735,7 +760,7 @@ bool KRDC::event(TQEvent *e) {
 
 bool KRDC::eventFilter(TQObject *watched, TQEvent *e) {
 	/* used to get events from TQScrollView  on resize  for scale mode*/
-	if (TQT_BASE_OBJECT(watched) != TQT_BASE_OBJECT(m_scrollView))
+	if (watched != m_scrollView)
 		return false;
 	if (e->type() != TQEvent::Resize)
 		return false;
@@ -749,7 +774,7 @@ void KRDC::setSize(int w, int h)
 {
 	int dw, dh;
 
-	TQWidget *desktop = TQT_TQWIDGET(TQApplication::desktop());
+	TQWidget *desktop = TQApplication::desktop();
 	dw = desktop->width();
 	dh = desktop->height();
 
