@@ -22,14 +22,14 @@
 
 
 #include <highscore/kexthighscore.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include "SuperEngine.h"
 
 
 namespace KExtHighscore
 {
 
-class KDE_EXPORT ExtManager : public Manager
+class TDE_EXPORT ExtManager : public Manager
 {
  public:
   ExtManager();
