@@ -66,8 +66,8 @@ aHistLineEdit::aHistLineEdit(TQWidget *parent, const char *name)
     setVScrollBarMode( AlwaysOff );
     setHScrollBarMode( AlwaysOff );
 
-//    connect( this, TQT_SIGNAL( returnPressed () ), this, TQT_SLOT( slotReturn() ) );
-    connect( this, TQT_SIGNAL( textChanged () ), this, TQT_SLOT( slotMaybeResize() ) );
+//    connect( this, TQ_SIGNAL( returnPressed () ), this, TQ_SLOT( slotReturn() ) );
+    connect( this, TQ_SIGNAL( textChanged () ), this, TQ_SLOT( slotMaybeResize() ) );
 
     setTabChangesFocus(true);
     setTextFormat(PlainText);
@@ -363,7 +363,7 @@ void aHistLineEdit::mousePressEvent ( TQMouseEvent *e )
 bool aHistLineEdit::eventFilter( TQObject *o, TQEvent *e )
 {
     if ( o == this && e->type() == TQEvent::AccelOverride )
-        if(processKeyEvent( TQT_TQKEYEVENT( e ) ) == true)
+        if(processKeyEvent( static_cast<TQKeyEvent*>( e ) ) == true)
             return true;
 
     return TQTextEdit::eventFilter( o, e );
@@ -398,7 +398,7 @@ void aHistLineEdit::paintEvent ( TQPaintEvent *p )
         TQPainter paint(this);
         TQPen pen = paint.pen();
         pen.setWidth(5);
-        pen.setStyle(Qt::SolidLine);
+        pen.setStyle(TQt::SolidLine);
         pen.setColor(palette().active().highlight());
         paint.setPen(pen);
         TQRect r = frameRect();
