@@ -10,7 +10,7 @@ DisplayMgrSDI::~DisplayMgrSDI(){
 }
 
 void DisplayMgrSDI::newTopLevel(TQWidget *w, bool show){
-  if(show == TRUE)
+  if(show)
     w->show();
 }
 
