@@ -6,7 +6,7 @@
 #include <tqstringlist.h>
 
 class objFinder : public TQObject {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
