@@ -10,7 +10,7 @@ class PProgress;
 #include "controller.h"
 
 class PProgress : public PWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   static PObject *createWidget(CreateArgs &ca);
