@@ -26,7 +26,7 @@
   */
 
 class PropsView : public TDEListView  {
-   Q_OBJECT
+   TQ_OBJECT
   
 public: 
 	PropsView(TQWidget *parent=0, const char *name=0);
