@@ -42,9 +42,9 @@ TimeDialog::TimeDialog( const KStarsDateTime &now, TQWidget* parent )
 
 	HourBox = new TQSpinBox( page, "HourBox" );
 	TQFont Box_font(  HourBox->font() );
-	Box_font.setBold( TRUE );
+	Box_font.setBold( true );
 	HourBox->setFont( Box_font );
-	HourBox->setWrapping( TRUE );
+	HourBox->setWrapping( true );
 	HourBox->setMaxValue( 23 );
 	HourBox->setButtonSymbols( TQSpinBox::PlusMinus );
 	HourBox->setValue( now.time().hour() );
@@ -56,7 +56,7 @@ TimeDialog::TimeDialog( const KStarsDateTime &now, TQWidget* parent )
 	MinuteBox = new TQSpinBox( page, "MinuteBox" );
 	TQFont MinuteBox_font(  MinuteBox->font() );
 	MinuteBox->setFont( Box_font );
-	MinuteBox->setWrapping( TRUE );
+	MinuteBox->setWrapping( true );
 	MinuteBox->setMaxValue( 59 );
 	MinuteBox->setButtonSymbols( TQSpinBox::PlusMinus );
 	MinuteBox->setValue( now.time().minute() );
@@ -67,7 +67,7 @@ TimeDialog::TimeDialog( const KStarsDateTime &now, TQWidget* parent )
 	SecondBox = new TQSpinBox( page, "SecondBox" );
 	SecondBox->setFont( Box_font );
 	SecondBox->setMaxValue( 59 );
-	SecondBox->setWrapping( TRUE );
+	SecondBox->setWrapping( true );
 	SecondBox->setButtonSymbols( TQSpinBox::PlusMinus );
 	SecondBox->setValue( now.time().second() );
 	
