@@ -73,7 +73,7 @@
 #include "TopWidget.h"
 
 KSVContent::KSVContent (TDEPopupMenu* openWithMenu, KSVTopLevel* parent, const char* name)
-  : TQSplitter (Qt::Vertical, parent, name),
+  : TQSplitter (TQt::Vertical, parent, name),
     startRL (new KSVDragList*[ksv::runlevelNumber]),
     stopRL (new KSVDragList*[ksv::runlevelNumber]),
     conf(KSVConfig::self()),
@@ -102,12 +102,12 @@ KSVContent::KSVContent (TDEPopupMenu* openWithMenu, KSVTopLevel* parent, const c
   // watch services dir
   KDirWatch* dirwatch = KDirWatch::self();
   dirwatch->addDir (conf->scriptPath ());
-  connect (dirwatch, TQT_SIGNAL (dirty (const TQString&)),
-           this, TQT_SLOT (updateServicesAfterChange (const TQString&)));
-  connect (dirwatch, TQT_SIGNAL (created (const TQString&)),
-           this, TQT_SLOT (updateServicesAfterChange (const TQString&)));
-  connect (dirwatch, TQT_SIGNAL (deleted (const TQString&)),
-           this, TQT_SLOT (updateServicesAfterChange (const TQString&)));
+  connect (dirwatch, TQ_SIGNAL (dirty (const TQString&)),
+           this, TQ_SLOT (updateServicesAfterChange (const TQString&)));
+  connect (dirwatch, TQ_SIGNAL (created (const TQString&)),
+           this, TQ_SLOT (updateServicesAfterChange (const TQString&)));
+  connect (dirwatch, TQ_SIGNAL (deleted (const TQString&)),
+           this, TQ_SLOT (updateServicesAfterChange (const TQString&)));
 
   setSizes(KSVContent::panningFactorToSplitter (conf->panningFactor()));
 
@@ -126,7 +126,7 @@ KSVContent::KSVContent (TDEPopupMenu* openWithMenu, KSVTopLevel* parent, const c
   textDisplay->setStyleSheet (ksv::styleSheet());
 
   // Open With... menu
-  connect (mOpenWithMenu, TQT_SIGNAL (activated (int)), this, TQT_SLOT (openWith (int)));
+  connect (mOpenWithMenu, TQ_SIGNAL (activated (int)), this, TQ_SLOT (openWith (int)));
 
   calcMinSize();
 }
@@ -219,25 +219,25 @@ void KSVContent::initLList()
   servL->setBuddy(scripts);
 
   // doubleclick && return
-  connect (scripts, TQT_SIGNAL(executed(TQListViewItem*)),
-		   this, TQT_SLOT(slotScriptProperties(TQListViewItem*)));
-  connect (scripts, TQT_SIGNAL (returnPressed (TQListViewItem*)),
-		   this, TQT_SLOT (slotScriptProperties (TQListViewItem*)));
+  connect (scripts, TQ_SIGNAL(executed(TQListViewItem*)),
+		   this, TQ_SLOT(slotScriptProperties(TQListViewItem*)));
+  connect (scripts, TQ_SIGNAL (returnPressed (TQListViewItem*)),
+		   this, TQ_SLOT (slotScriptProperties (TQListViewItem*)));
 
   // context menus
-  connect (scripts, TQT_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
- 		   this, TQT_SLOT (popupServicesMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
+  connect (scripts, TQ_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
+ 		   this, TQ_SLOT (popupServicesMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
 
   // for cut & copy
-  connect (scripts, TQT_SIGNAL (newOrigin ()),
-		   this, TQT_SLOT (fwdOrigin ()));
+  connect (scripts, TQ_SIGNAL (newOrigin ()),
+		   this, TQ_SLOT (fwdOrigin ()));
 
   // for origin updates
-  connect (scripts, TQT_SIGNAL (newOrigin (KSVDragList*)),
-		   this, TQT_SLOT (fwdOrigin (KSVDragList*)));
+  connect (scripts, TQ_SIGNAL (newOrigin (KSVDragList*)),
+		   this, TQ_SLOT (fwdOrigin (KSVDragList*)));
 
   trash = new KSVTrash(mScriptBox, "Trash");
-  connect (trash, TQT_SIGNAL (undoAction (KSVAction*)), this, TQT_SLOT (fwdUndoAction (KSVAction*)));
+  connect (trash, TQ_SIGNAL (undoAction (KSVAction*)), this, TQ_SLOT (fwdUndoAction (KSVAction*)));
   TQWhatsThis::add (trash,
 				   i18n ("<p>You can drag services from a runlevel onto " \
                          "the <img src=\"small|trash\"/> <strong>trashcan</strong> to " \
@@ -290,21 +290,21 @@ void KSVContent::initLList()
       rlL->setBuddy(startRL[i]);
 
       // for cut'n'paste
-      connect (startRL[i], TQT_SIGNAL (newOrigin ()),
-			   this, TQT_SLOT (fwdOrigin ()));
-      connect (startRL[i], TQT_SIGNAL (newOrigin (KSVDragList*)),
-			   this, TQT_SLOT (fwdOrigin (KSVDragList*)));
+      connect (startRL[i], TQ_SIGNAL (newOrigin ()),
+			   this, TQ_SLOT (fwdOrigin ()));
+      connect (startRL[i], TQ_SIGNAL (newOrigin (KSVDragList*)),
+			   this, TQ_SLOT (fwdOrigin (KSVDragList*)));
 
-      connect (stopRL[i], TQT_SIGNAL (newOrigin ()),
-			   this, TQT_SLOT (fwdOrigin ()));
-      connect (stopRL[i], TQT_SIGNAL (newOrigin (KSVDragList*)),
-			   this, TQT_SLOT (fwdOrigin (KSVDragList*)));
+      connect (stopRL[i], TQ_SIGNAL (newOrigin ()),
+			   this, TQ_SLOT (fwdOrigin ()));
+      connect (stopRL[i], TQ_SIGNAL (newOrigin (KSVDragList*)),
+			   this, TQ_SLOT (fwdOrigin (KSVDragList*)));
     }
 
   lay->addStretch(1);
 
-  connect (scripts, TQT_SIGNAL(undoAction(KSVAction*)),
-		   this, TQT_SLOT(fwdUndoAction(KSVAction*)));
+  connect (scripts, TQ_SIGNAL(undoAction(KSVAction*)),
+		   this, TQ_SLOT(fwdUndoAction(KSVAction*)));
 
   // add text-diplay widget
   textDisplay = new TQTextEdit( TQString(), TQString(), this, "TextDisplayWidget" );
@@ -313,41 +313,41 @@ void KSVContent::initLList()
 
   for (int i = 0; i < ksv::runlevelNumber; ++i)
 	{
-	  connect (startRL[i], TQT_SIGNAL(newOrigin()), stopRL[i], TQT_SLOT(slotNewOrigin()));
-	  connect (stopRL[i], TQT_SIGNAL(newOrigin()), startRL[i], TQT_SLOT(slotNewOrigin()));
+	  connect (startRL[i], TQ_SIGNAL(newOrigin()), stopRL[i], TQ_SLOT(slotNewOrigin()));
+	  connect (stopRL[i], TQ_SIGNAL(newOrigin()), startRL[i], TQ_SLOT(slotNewOrigin()));
 
-	  connect (startRL[i], TQT_SIGNAL(undoAction(KSVAction*)),
-			   this, TQT_SLOT(fwdUndoAction(KSVAction*)));
-	  connect (stopRL[i], TQT_SIGNAL(undoAction(KSVAction*)),
-			   this, TQT_SLOT(fwdUndoAction(KSVAction*)));
+	  connect (startRL[i], TQ_SIGNAL(undoAction(KSVAction*)),
+			   this, TQ_SLOT(fwdUndoAction(KSVAction*)));
+	  connect (stopRL[i], TQ_SIGNAL(undoAction(KSVAction*)),
+			   this, TQ_SLOT(fwdUndoAction(KSVAction*)));
 
 	  // doubleclick && return
-	  connect (startRL[i], TQT_SIGNAL(executed(TQListViewItem*)),
-			   this, TQT_SLOT(slotDoubleClick(TQListViewItem*)));
-	  connect (stopRL[i], TQT_SIGNAL(executed(TQListViewItem*)),
-			   this, TQT_SLOT(slotDoubleClick(TQListViewItem*)));
-	  connect (startRL[i], TQT_SIGNAL(returnPressed(TQListViewItem*)),
-			   this, TQT_SLOT(slotDoubleClick(TQListViewItem*)));
-	  connect (stopRL[i], TQT_SIGNAL(returnPressed(TQListViewItem*)),
-			   this, TQT_SLOT(slotDoubleClick(TQListViewItem*)));
+	  connect (startRL[i], TQ_SIGNAL(executed(TQListViewItem*)),
+			   this, TQ_SLOT(slotDoubleClick(TQListViewItem*)));
+	  connect (stopRL[i], TQ_SIGNAL(executed(TQListViewItem*)),
+			   this, TQ_SLOT(slotDoubleClick(TQListViewItem*)));
+	  connect (startRL[i], TQ_SIGNAL(returnPressed(TQListViewItem*)),
+			   this, TQ_SLOT(slotDoubleClick(TQListViewItem*)));
+	  connect (stopRL[i], TQ_SIGNAL(returnPressed(TQListViewItem*)),
+			   this, TQ_SLOT(slotDoubleClick(TQListViewItem*)));
 
 	  // context menus
-	  connect (startRL[i], TQT_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
-			   this, TQT_SLOT (popupRunlevelMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
-	  connect (stopRL[i], TQT_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
-			   this, TQT_SLOT (popupRunlevelMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
+	  connect (startRL[i], TQ_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
+			   this, TQ_SLOT (popupRunlevelMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
+	  connect (stopRL[i], TQ_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)),
+			   this, TQ_SLOT (popupRunlevelMenu (TDEListView*, TQListViewItem*, const TQPoint&)));
 
 	  // cannot generate sorting number
-	  connect (startRL[i], TQT_SIGNAL(cannotGenerateNumber()),
-			   this, TQT_SLOT(fwdCannotGenerateNumber()));
-	  connect (stopRL[i], TQT_SIGNAL(cannotGenerateNumber()),
-			   this, TQT_SLOT(fwdCannotGenerateNumber()));
+	  connect (startRL[i], TQ_SIGNAL(cannotGenerateNumber()),
+			   this, TQ_SLOT(fwdCannotGenerateNumber()));
+	  connect (stopRL[i], TQ_SIGNAL(cannotGenerateNumber()),
+			   this, TQ_SLOT(fwdCannotGenerateNumber()));
 
 	  // connecting origin things for "Scripts", too
-	  connect (scripts, TQT_SIGNAL(newOrigin()), startRL[i], TQT_SLOT(slotNewOrigin()));
-	  connect (scripts, TQT_SIGNAL(newOrigin()), stopRL[i], TQT_SLOT(slotNewOrigin()));
-	  connect (startRL[i], TQT_SIGNAL(newOrigin()), scripts, TQT_SLOT(slotNewOrigin()));
-	  connect (stopRL[i], TQT_SIGNAL(newOrigin()), scripts, TQT_SLOT(slotNewOrigin()));
+	  connect (scripts, TQ_SIGNAL(newOrigin()), startRL[i], TQ_SLOT(slotNewOrigin()));
+	  connect (scripts, TQ_SIGNAL(newOrigin()), stopRL[i], TQ_SLOT(slotNewOrigin()));
+	  connect (startRL[i], TQ_SIGNAL(newOrigin()), scripts, TQ_SLOT(slotNewOrigin()));
+	  connect (stopRL[i], TQ_SIGNAL(newOrigin()), scripts, TQ_SLOT(slotNewOrigin()));
 
 	  // use this loop for setting tooltips
  	  startRL[i]->setToolTip (i18n("Drag here to start services\n" \
@@ -359,11 +359,11 @@ void KSVContent::initLList()
 		{
 		  if (i != j)
 			{
-			  connect (startRL[i], TQT_SIGNAL (newOrigin()), startRL[j], TQT_SLOT (slotNewOrigin()));
-			  connect (stopRL[i], TQT_SIGNAL (newOrigin()), stopRL[j], TQT_SLOT (slotNewOrigin()));
+			  connect (startRL[i], TQ_SIGNAL (newOrigin()), startRL[j], TQ_SLOT (slotNewOrigin()));
+			  connect (stopRL[i], TQ_SIGNAL (newOrigin()), stopRL[j], TQ_SLOT (slotNewOrigin()));
 
-			  connect (startRL[i], TQT_SIGNAL(newOrigin()), stopRL[j], TQT_SLOT(slotNewOrigin()));
-			  connect (stopRL[i], TQT_SIGNAL(newOrigin()), startRL[j], TQT_SLOT(slotNewOrigin()));
+			  connect (startRL[i], TQ_SIGNAL(newOrigin()), stopRL[j], TQ_SLOT(slotNewOrigin()));
+			  connect (stopRL[i], TQ_SIGNAL(newOrigin()), startRL[j], TQ_SLOT(slotNewOrigin()));
 			}
 		}
 	}
@@ -574,14 +574,14 @@ void KSVContent::infoOnData (KSVItem* item)
   KSVData newState = oldState;
   KSVEntryPropertiesDialog* props = new KSVEntryPropertiesDialog (newState, kapp->mainWidget());
 
-  connect (props, TQT_SIGNAL (editService (const TQString&)),
-           this, TQT_SLOT (editService (const TQString&)));
-  connect (props, TQT_SIGNAL (startService (const TQString&)),
-           this, TQT_SLOT (startService (const TQString&)));
-  connect (props, TQT_SIGNAL (stopService (const TQString&)),
-           this, TQT_SLOT (stopService (const TQString&)));
-  connect (props, TQT_SIGNAL (restartService (const TQString&)),
-           this, TQT_SLOT (restartService (const TQString&)));
+  connect (props, TQ_SIGNAL (editService (const TQString&)),
+           this, TQ_SLOT (editService (const TQString&)));
+  connect (props, TQ_SIGNAL (startService (const TQString&)),
+           this, TQ_SLOT (startService (const TQString&)));
+  connect (props, TQ_SIGNAL (stopService (const TQString&)),
+           this, TQ_SLOT (stopService (const TQString&)));
+  connect (props, TQ_SIGNAL (restartService (const TQString&)),
+           this, TQ_SLOT (restartService (const TQString&)));
 
   int res = props->exec();
 
@@ -608,9 +608,9 @@ void KSVContent::stopService (const TQString& path)
 
   *_proc << path << "stop";
 
-  connect(_proc, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotExitedProcess(TDEProcess*)));
-  connect(_proc, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
-  connect(_proc, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(_proc, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotExitedProcess(TDEProcess*)));
+  connect(_proc, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(_proc, TQ_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
 
   // refresh textDisplay
   appendLog(i18n("** <stop>Stopping</stop> <cmd>%1</cmd> **<br/>").arg(path),
@@ -634,9 +634,9 @@ void KSVContent::startService (const TQString& path)
 
   *_proc << path << "start";
 
-  connect(_proc, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotExitedProcess(TDEProcess*)));
-  connect(_proc, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
-  connect(_proc, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(_proc, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotExitedProcess(TDEProcess*)));
+  connect(_proc, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(_proc, TQ_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
 
   // refresh textDisplay
   appendLog(i18n("** <start>Starting</start> <cmd>%1</cmd> **<br/>").arg(path),
@@ -674,9 +674,9 @@ void KSVContent::restartService (const TQString& path)
 
   *_proc << path << "restart";
 
-  connect(_proc, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotExitDuringRestart(TDEProcess*)));
-  connect(_proc, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
-  connect(_proc, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(_proc, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotExitDuringRestart(TDEProcess*)));
+  connect(_proc, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(_proc, TQ_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
 
   // refresh textDisplay
   appendLog(i18n("** Re-starting <cmd>%1</cmd> **</br>").arg(path),
@@ -716,14 +716,14 @@ void KSVContent::slotScriptProperties(TQListViewItem* item)
   KSVServicePropertiesDialog* prop =
     new KSVServicePropertiesDialog (*static_cast<KSVItem*> (item)->data(), kapp->mainWidget());
 
-  connect (prop, TQT_SIGNAL (editService (const TQString&)),
-           this, TQT_SLOT (editService (const TQString&)));
-  connect (prop, TQT_SIGNAL (startService (const TQString&)),
-           this, TQT_SLOT (startService (const TQString&)));
-  connect (prop, TQT_SIGNAL (stopService (const TQString&)),
-           this, TQT_SLOT (stopService (const TQString&)));
-  connect (prop, TQT_SIGNAL (restartService (const TQString&)),
-           this, TQT_SLOT (restartService (const TQString&)));
+  connect (prop, TQ_SIGNAL (editService (const TQString&)),
+           this, TQ_SLOT (editService (const TQString&)));
+  connect (prop, TQ_SIGNAL (startService (const TQString&)),
+           this, TQ_SLOT (startService (const TQString&)));
+  connect (prop, TQ_SIGNAL (stopService (const TQString&)),
+           this, TQ_SLOT (stopService (const TQString&)));
+  connect (prop, TQ_SIGNAL (restartService (const TQString&)),
+           this, TQ_SLOT (restartService (const TQString&)));
 
   prop->exec();
 
@@ -737,9 +737,9 @@ void KSVContent::slotExitDuringRestart( TDEProcess* proc )
                          // signals connected that screw up our output
   proc->clearArguments();
 
-  connect(proc, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotExitedProcess(TDEProcess*)));
-  connect(proc, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
-  connect(proc, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQT_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(proc, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotExitedProcess(TDEProcess*)));
+  connect(proc, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
+  connect(proc, TQ_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQ_SLOT(slotOutputOrError(TDEProcess*, char*, int)));
 
   proc->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput);
 }
@@ -1026,7 +1026,7 @@ void KSVContent::popupServicesMenu (TDEListView*, TQListViewItem* i, const TQPoi
       if (i >= 1)
         mOpenWithMenu->insertSeparator();
 
-      mOpenWithMenu->insertItem (i18n ("&Other..."), this, TQT_SLOT (openWith()));
+      mOpenWithMenu->insertItem (i18n ("&Other..."), this, TQ_SLOT (openWith()));
 
       mScriptMenu->exec (p, 1);
     }
