@@ -352,7 +352,7 @@ bool TQWinMetaFile::paint( const TQPaintDevice* aTarget, bool absolute )
     mWinding = false;
     mAbsoluteCoord = absolute;
 
-    mPainter.begin( TQT_TQPAINTDEVICE(const_cast<TQPaintDevice*>(aTarget)) );
+    mPainter.begin( const_cast<TQPaintDevice*>(aTarget) );
     if ( TQWMF_DEBUG )  {
         kdDebug() << "Bounding box : " << mBBox.left()
         << " " << mBBox.top() << " " << mBBox.right() << " " << mBBox.bottom() << endl;
@@ -624,8 +624,8 @@ void TQWinMetaFile::setBkColor( long, short* parm )
 //-----------------------------------------------------------------------------
 void TQWinMetaFile::setBkMode( long, short* parm )
 {
-    if ( parm[ 0 ]==1 ) mPainter.setBackgroundMode( Qt::TransparentMode );
-    else mPainter.setBackgroundMode( Qt::OpaqueMode );
+    if ( parm[ 0 ]==1 ) mPainter.setBackgroundMode( TQt::TransparentMode );
+    else mPainter.setBackgroundMode( TQt::OpaqueMode );
 }
 
 
@@ -929,26 +929,26 @@ void TQWinMetaFile::createEmptyObject( long, short* )
 //-----------------------------------------------------------------------------
 void TQWinMetaFile::createBrushIndirect( long, short* parm )
 {
-    static Qt::BrushStyle hatchedStyleTab[] =
+    static TQt::BrushStyle hatchedStyleTab[] =
     {
-        Qt::HorPattern,
-        Qt::FDiagPattern,
-        Qt::BDiagPattern,
-        Qt::CrossPattern,
-        Qt::DiagCrossPattern
+        TQt::HorPattern,
+        TQt::FDiagPattern,
+        TQt::BDiagPattern,
+        TQt::CrossPattern,
+        TQt::DiagCrossPattern
     };
-    static Qt::BrushStyle styleTab[] =
-    { Qt::SolidPattern,
-      Qt::NoBrush,
-      Qt::FDiagPattern,   /* hatched */
-      Qt::Dense4Pattern,  /* should be custom bitmap pattern */
-      Qt::HorPattern,     /* should be BS_INDEXED (?) */
-      Qt::VerPattern,     /* should be device-independent bitmap */
-      Qt::Dense6Pattern,  /* should be device-independent packed-bitmap */
-      Qt::Dense2Pattern,  /* should be BS_PATTERN8x8 */
-      Qt::Dense3Pattern   /* should be device-independent BS_DIBPATTERN8x8 */
+    static TQt::BrushStyle styleTab[] =
+    { TQt::SolidPattern,
+      TQt::NoBrush,
+      TQt::FDiagPattern,   /* hatched */
+      TQt::Dense4Pattern,  /* should be custom bitmap pattern */
+      TQt::HorPattern,     /* should be BS_INDEXED (?) */
+      TQt::VerPattern,     /* should be device-independent bitmap */
+      TQt::Dense6Pattern,  /* should be device-independent packed-bitmap */
+      TQt::Dense2Pattern,  /* should be BS_PATTERN8x8 */
+      TQt::Dense3Pattern   /* should be device-independent BS_DIBPATTERN8x8 */
     };
-    Qt::BrushStyle style;
+    TQt::BrushStyle style;
     short arg;
     WinObjBrushHandle* handle = new WinObjBrushHandle;
     addHandle( handle );
@@ -961,7 +961,7 @@ void TQWinMetaFile::createBrushIndirect( long, short* parm )
         else
         {
             kdDebug() << "TQWinMetaFile::createBrushIndirect: invalid hatched brush " << arg << endl;
-            style = Qt::SolidPattern;
+            style = TQt::SolidPattern;
         }
     }
     else if ( arg>=0 && arg<9 )
@@ -969,7 +969,7 @@ void TQWinMetaFile::createBrushIndirect( long, short* parm )
     else
     {
         kdDebug() << "TQWinMetaFile::createBrushIndirect: invalid brush " << arg << endl;
-        style = Qt::SolidPattern;
+        style = TQt::SolidPattern;
     }
     handle->brush.setStyle( style );
     handle->brush.setColor( color( parm+1 ) );
@@ -979,10 +979,10 @@ void TQWinMetaFile::createBrushIndirect( long, short* parm )
 //-----------------------------------------------------------------------------
 void TQWinMetaFile::createPenIndirect( long, short* parm )
 {
-    static Qt::PenStyle styleTab[] =
-    { Qt::SolidLine, Qt::DashLine, Qt::DotLine, Qt::DashDotLine, Qt::DashDotDotLine,
-      Qt::NoPen, Qt::SolidLine };
-    Qt::PenStyle style;
+    static TQt::PenStyle styleTab[] =
+    { TQt::SolidLine, TQt::DashLine, TQt::DotLine, TQt::DashDotLine, TQt::DashDotDotLine,
+      TQt::NoPen, TQt::SolidLine };
+    TQt::PenStyle style;
     WinObjPenHandle* handle = new WinObjPenHandle;
     addHandle( handle );
 
@@ -990,12 +990,12 @@ void TQWinMetaFile::createPenIndirect( long, short* parm )
     else
     {
         kdDebug() << "TQWinMetaFile::createPenIndirect: invalid pen " << parm[ 0 ] << endl;
-        style = Qt::SolidLine;
+        style = TQt::SolidLine;
     }
 
     handle->pen.setStyle( style );
     handle->pen.setColor( color( parm+3 ) );
-    handle->pen.setCapStyle( Qt::RoundCap );
+    handle->pen.setCapStyle( TQt::RoundCap );
 
     //int width = 0;
     // TODO : width of pen proportional to device context width
