@@ -64,7 +64,7 @@ KTouch::KTouch()
     m_keyboardWidget(NULL),
 	m_trainer(NULL)
 {
-	setFocusPolicy(TQ_StrongFocus);
+	setFocusPolicy(TQWidget::StrongFocus);
 	setInputMethodEnabled(true);
 
 	// Set global KTouchPtr to the main KTouch Object
@@ -431,16 +431,16 @@ void KTouch::optionsPreferences() {
 	dialog->addPage(m_pageKeyboard, i18n("Keyboard Settings"), "keyboard_layout");
 	m_pageColors = new KTouchPrefColorsLayout(0, "Colors"); 
 	dialog->addPage(m_pageColors, i18n("Color Settings"), "applications-graphics");
-	connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(applyPreferences()));
+	connect(dialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(applyPreferences()));
 	// TODO : Connect some other buttons/check boxes of the dialog
-	connect(m_pageGeneral->kcfg_OverrideLectureFont, TQT_SIGNAL(toggled(bool)), 
-		TQT_TQOBJECT(this), TQT_SLOT(configOverrideLectureFontToggled(bool)));
-	connect(m_pageKeyboard->kcfg_OverrideKeyboardFont, TQT_SIGNAL(toggled(bool)), 
-		TQT_TQOBJECT(this), TQT_SLOT(configOverrideKeyboardFontToggled(bool)));
-	connect(m_pageTraining->kcfg_AutoLevelChange, TQT_SIGNAL(toggled(bool)), 
-		TQT_TQOBJECT(this), TQT_SLOT(configAutoLevelChangeToggled(bool)));
-	connect(m_pageColors->kcfg_CommonTypingLineColors, TQT_SIGNAL(toggled(bool)),
-		TQT_TQOBJECT(this), TQT_SLOT(configCommonColorsToggled(bool)));
+	connect(m_pageGeneral->kcfg_OverrideLectureFont, TQ_SIGNAL(toggled(bool)), 
+		this, TQ_SLOT(configOverrideLectureFontToggled(bool)));
+	connect(m_pageKeyboard->kcfg_OverrideKeyboardFont, TQ_SIGNAL(toggled(bool)), 
+		this, TQ_SLOT(configOverrideKeyboardFontToggled(bool)));
+	connect(m_pageTraining->kcfg_AutoLevelChange, TQ_SIGNAL(toggled(bool)), 
+		this, TQ_SLOT(configAutoLevelChangeToggled(bool)));
+	connect(m_pageColors->kcfg_CommonTypingLineColors, TQ_SIGNAL(toggled(bool)),
+		this, TQ_SLOT(configCommonColorsToggled(bool)));
 	// call the functions to enable/disable controls depending on settings
 	configOverrideLectureFontToggled(Prefs::overrideLectureFont());
 	configOverrideKeyboardFontToggled(Prefs::overrideKeyboardFont());
@@ -684,40 +684,40 @@ void KTouch::initTrainingSession() {
 void KTouch::setupActions() {
 	// *** File menu ***
     new TDEAction(i18n("&Open lecture..."), "open_lecture", 0,
-		TQT_TQOBJECT(this), TQT_SLOT(fileOpenLecture()), actionCollection(), "file_openlecture");
+		this, TQ_SLOT(fileOpenLecture()), actionCollection(), "file_openlecture");
     new TDEAction(i18n("&Edit lecture..."), "edit_lecture", 0,
-		TQT_TQOBJECT(this), TQT_SLOT(fileEditLecture()), actionCollection(), "file_editlecture");
+		this, TQ_SLOT(fileEditLecture()), actionCollection(), "file_editlecture");
     new TDEAction(i18n("&Edit color scheme..."), "edit_colors", 0,
-		TQT_TQOBJECT(this), TQT_SLOT(fileEditColors()), actionCollection(), "file_editcolors");
+		this, TQ_SLOT(fileEditColors()), actionCollection(), "file_editcolors");
 //    new TDEAction(i18n("&Edit Keyboard..."), "edit_keyboard", 0, 
-//		TQT_TQOBJECT(this), TQT_SLOT(fileEditKeyboard()), actionCollection(), "file_editkeyboard");
-    KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(fileQuit()), actionCollection());
+//		this, TQ_SLOT(fileEditKeyboard()), actionCollection(), "file_editkeyboard");
+    KStdAction::quit(this, TQ_SLOT(fileQuit()), actionCollection());
 
 	// *** Training menu ***
     new TDEAction(i18n("&Start New Session"), "launch", 0,
-        TQT_TQOBJECT(this), TQT_SLOT(trainingNewSession()), actionCollection(), "training_newsession");
+        this, TQ_SLOT(trainingNewSession()), actionCollection(), "training_newsession");
     m_trainingPause = new TDEAction(i18n("&Pause Session"), "media-playback-pause", 0,
-        TQT_TQOBJECT(this), TQT_SLOT(trainingPause()), actionCollection(), "training_pause");
+        this, TQ_SLOT(trainingPause()), actionCollection(), "training_pause");
     new TDEAction(i18n("&Lecture Statistics"), "kalarm", 0,
-        TQT_TQOBJECT(this), TQT_SLOT(trainingStatistics()), actionCollection(), "training_stats");
+        this, TQ_SLOT(trainingStatistics()), actionCollection(), "training_stats");
  
     // Setup menu entries for the training lectures
-    m_defaultLectureAction = new TDESelectAction(i18n("Default &Lectures"), 0, TQT_TQOBJECT(this), 0, actionCollection(), "default_lectures");
+    m_defaultLectureAction = new TDESelectAction(i18n("Default &Lectures"), 0, this, 0, actionCollection(), "default_lectures");
 	m_defaultLectureAction->setMenuAccelsEnabled(false);
     m_defaultLectureAction->setItems(m_lectureTitles);
     m_defaultLectureAction->setCurrentItem(0);  
-    connect (m_defaultLectureAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changeLecture(int)));
+    connect (m_defaultLectureAction, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changeLecture(int)));
 
 	// *** Settings menu ***    
-    KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection());
+    KStdAction::preferences(this, TQ_SLOT(optionsPreferences()), actionCollection());
     // Setup menu entries for keyboard layouts    
-    m_keyboardLayoutAction= new TDESelectAction(i18n("&Keyboard Layouts"), 0, TQT_TQOBJECT(this), 0, actionCollection(), "keyboard_layouts");
+    m_keyboardLayoutAction= new TDESelectAction(i18n("&Keyboard Layouts"), 0, this, 0, actionCollection(), "keyboard_layouts");
 	m_keyboardLayoutAction->setMenuAccelsEnabled(false);
     m_keyboardLayoutAction->setItems(m_keyboardTitles);
-    connect (m_keyboardLayoutAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changeKeyboard(int)));
+    connect (m_keyboardLayoutAction, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changeKeyboard(int)));
 
 	// Setup menu entries for colour schemes
-	m_keyboardColorAction = new TDESelectAction(i18n("&Color Schemes"), 0, TQT_TQOBJECT(this), 0, actionCollection(), "keyboard_schemes");
+	m_keyboardColorAction = new TDESelectAction(i18n("&Color Schemes"), 0, this, 0, actionCollection(), "keyboard_schemes");
     TQStringList schemes_list;
     for (unsigned int i=0; i<KTouchColorScheme::m_colorSchemes.count(); ++i)
 		schemes_list.append(KTouchColorScheme::m_colorSchemes[i].m_name);
@@ -726,7 +726,7 @@ void KTouch::setupActions() {
 	if (static_cast<unsigned int>(Prefs::currentColorScheme()) >=  schemes_list.count())
 		Prefs::setCurrentColorScheme(1);
    	m_keyboardColorAction->setCurrentItem(Prefs::currentColorScheme());
-    connect (m_keyboardColorAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changeColor(int)));
+    connect (m_keyboardColorAction, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changeColor(int)));
 }
 // ----------------------------------------------------------------------------
 
