@@ -77,8 +77,8 @@ KTouchSlideLine::KTouchSlideLine(TQWidget *parent)
     m_xFrameStudent = 0;  
     m_xFrameStudentCurrent = 0;
 
-    connect( &m_cursorTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(toggleCursor()) );
-    connect( &m_slideTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slide()) );
+    connect( &m_cursorTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(toggleCursor()) );
+    connect( &m_slideTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slide()) );
 }
 // ----------------------------------------------------------------------------
 
@@ -411,7 +411,7 @@ void KTouchSlideLine::updateSlidingLines() {
 
 	// draw the teacher pixmap text
     TQPainter painter;
-    painter.begin (TQT_TQPAINTDEVICE(m_teacherPixmap), this);
+    painter.begin (m_teacherPixmap, this);
     painter.setFont( m_font );
 
 	TQColor col_tt = Prefs::commonTypingLineColors() ?
@@ -532,7 +532,7 @@ void KTouchSlideLine::updateStudentLine() {
 
     // now let's draw the students pixmap
     TQPainter painter;
-    painter.begin (TQT_TQPAINTDEVICE(m_studentPixmap), this);
+    painter.begin (m_studentPixmap, this);
     if (Prefs::colorOnError()) {
         // draw the student line depending on the colour settings
         if (error) {
