@@ -28,7 +28,7 @@
 #include <tqmime.h>
 
 // KDE includes.
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdelocale.h>
 #include <tdeaboutdata.h>
 #include <tdelistview.h>
