@@ -123,59 +123,59 @@ void MainWindow::setupActions()
 	TDEActionCollection *ac = actionCollection(); // abbreviation
 	
 	// File actions
-	KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(slotNewFile()), ac);
-	openExAction = new TDEAction(i18n("Open Exa&mples..."), "bookmark_folder", CTRL+Key_E, TQT_TQOBJECT(this), TQT_SLOT(slotOpenExample()), ac, "open_examples");
-	KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(slotOpenFile()), ac);
-	m_recentFiles = KStdAction::openRecent(TQT_TQOBJECT(this), TQT_SLOT(slotOpenFile(const KURL&)), ac);
-	KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(slotSaveFile()), ac);
-	KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(slotSaveAs()), ac);
-	new TDEAction(i18n("Save &Canvas..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotSaveCanvas()), ac, "save_canvas");
-	speed = new TDESelectAction(i18n("Execution Speed"), 0, ALT+Key_S, TQT_TQOBJECT(this), TQT_SLOT( slotChangeSpeed() ), ac, "speed");
+	KStdAction::openNew(this, TQ_SLOT(slotNewFile()), ac);
+	openExAction = new TDEAction(i18n("Open Exa&mples..."), "bookmark_folder", CTRL+Key_E, this, TQ_SLOT(slotOpenExample()), ac, "open_examples");
+	KStdAction::open(this, TQ_SLOT(slotOpenFile()), ac);
+	m_recentFiles = KStdAction::openRecent(this, TQ_SLOT(slotOpenFile(const KURL&)), ac);
+	KStdAction::save(this, TQ_SLOT(slotSaveFile()), ac);
+	KStdAction::saveAs(this, TQ_SLOT(slotSaveAs()), ac);
+	new TDEAction(i18n("Save &Canvas..."), 0, 0, this, TQ_SLOT(slotSaveCanvas()), ac, "save_canvas");
+	speed = new TDESelectAction(i18n("Execution Speed"), 0, ALT+Key_S, this, TQ_SLOT( slotChangeSpeed() ), ac, "speed");
 	TQStringList speeds; speeds << i18n("Full Speed") << i18n("Slow") << i18n("Slower") << i18n("Slowest");
 	speed->setItems(speeds);
 	speed->setCurrentItem(0);
-	run = new TDEAction(i18n("&Execute Commands"), "gear", ALT+Key_Return, TQT_TQOBJECT(this), TQT_SLOT( slotExecute() ), ac, "run");
-	pause = new TDEToggleAction(i18n("Pause E&xecution"), "media-playback-pause", Key_Pause, TQT_TQOBJECT(this), TQT_SLOT( slotPauseExecution() ), ac, "pause");
+	run = new TDEAction(i18n("&Execute Commands"), "gear", ALT+Key_Return, this, TQ_SLOT( slotExecute() ), ac, "run");
+	pause = new TDEToggleAction(i18n("Pause E&xecution"), "media-playback-pause", Key_Pause, this, TQ_SLOT( slotPauseExecution() ), ac, "pause");
 	pause->setChecked(false);
 	pause->setEnabled(false);
-	stop = new TDEAction(i18n("Stop E&xecution"), "process-stop", Key_Escape, TQT_TQOBJECT(this), TQT_SLOT( slotAbortExecution() ), ac, "stop");
+	stop = new TDEAction(i18n("Stop E&xecution"), "process-stop", Key_Escape, this, TQ_SLOT( slotAbortExecution() ), ac, "stop");
 	stop->setEnabled(false);
-	KStdAction::print(TQT_TQOBJECT(this), TQT_SLOT(slotPrint()), ac);
-	KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), ac);
+	KStdAction::print(this, TQ_SLOT(slotPrint()), ac);
+	KStdAction::quit(this, TQ_SLOT(close()), ac);
 	
 	// Edit actions
-	KStdAction::undo(TQT_TQOBJECT(this), TQT_SLOT(slotUndo()), ac);
-	KStdAction::redo(TQT_TQOBJECT(this), TQT_SLOT(slotRedo()), ac);
-	KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotCut()), ac);
-	KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), ac);
-	KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), ac);
-	KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(slotSelectAll()), ac);
-	KStdAction::deselect(TQT_TQOBJECT(this), TQT_SLOT(slotClearSelection()), ac);
-	new TDEToggleAction(i18n("Toggle Insert"), Key_Insert, TQT_TQOBJECT(this), TQT_SLOT(slotToggleInsert()), ac, "set_insert");
-	KStdAction::find(TQT_TQOBJECT(this), TQT_SLOT(slotFind()), ac);
-	KStdAction::findNext(TQT_TQOBJECT(this), TQT_SLOT(slotFindNext()), ac);
-	KStdAction::findPrev(TQT_TQOBJECT(this), TQT_SLOT(slotFindPrevious()), ac);
-	KStdAction::replace(TQT_TQOBJECT(this), TQT_SLOT(slotReplace()), ac);
+	KStdAction::undo(this, TQ_SLOT(slotUndo()), ac);
+	KStdAction::redo(this, TQ_SLOT(slotRedo()), ac);
+	KStdAction::cut(this, TQ_SLOT(slotCut()), ac);
+	KStdAction::copy(this, TQ_SLOT(slotCopy()), ac);
+	KStdAction::paste(this, TQ_SLOT(slotPaste()), ac);
+	KStdAction::selectAll(this, TQ_SLOT(slotSelectAll()), ac);
+	KStdAction::deselect(this, TQ_SLOT(slotClearSelection()), ac);
+	new TDEToggleAction(i18n("Toggle Insert"), Key_Insert, this, TQ_SLOT(slotToggleInsert()), ac, "set_insert");
+	KStdAction::find(this, TQ_SLOT(slotFind()), ac);
+	KStdAction::findNext(this, TQ_SLOT(slotFindNext()), ac);
+	KStdAction::findPrev(this, TQ_SLOT(slotFindPrevious()), ac);
+	KStdAction::replace(this, TQ_SLOT(slotReplace()), ac);
 	
 	// View actions
-	new TDEToggleAction(i18n("Show &Line Numbers"), 0, Key_F11, TQT_TQOBJECT(this), TQT_SLOT(slotToggleLineNumbers()), ac, "line_numbers");
-	m_fullscreen = KStdAction::fullScreen(TQT_TQOBJECT(this), TQT_SLOT(slotToggleFullscreen()), ac, this, "full_screen");
+	new TDEToggleAction(i18n("Show &Line Numbers"), 0, Key_F11, this, TQ_SLOT(slotToggleLineNumbers()), ac, "line_numbers");
+	m_fullscreen = KStdAction::fullScreen(this, TQ_SLOT(slotToggleFullscreen()), ac, this, "full_screen");
 	m_fullscreen->setChecked(b_fullscreen);
 
 	// Tools actions
-	colorpicker = new TDEToggleAction(i18n("&Color Picker"), "colorize", ALT+Key_C, TQT_TQOBJECT(this), TQT_SLOT(slotColorPicker()), ac, "color_picker");
-	new TDEAction(i18n("&Indent"), "format-indent-more", CTRL+Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotIndent()), ac, "edit_indent");
-	new TDEAction(i18n("&Unindent"), "format-indent-less", CTRL+SHIFT+Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotUnIndent()), ac, "edit_unindent");
-	new TDEAction(i18n("Cl&ean Indentation"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotCleanIndent()), ac, "edit_cleanIndent");
-	new TDEAction(i18n("Co&mment"), 0, CTRL+Key_D, TQT_TQOBJECT(this), TQT_SLOT(slotComment()), ac, "edit_comment");
-	new TDEAction(i18n("Unc&omment"), 0, CTRL+SHIFT+Key_D, TQT_TQOBJECT(this), TQT_SLOT(slotUnComment()), ac, "edit_uncomment");
+	colorpicker = new TDEToggleAction(i18n("&Color Picker"), "colorize", ALT+Key_C, this, TQ_SLOT(slotColorPicker()), ac, "color_picker");
+	new TDEAction(i18n("&Indent"), "format-indent-more", CTRL+Key_I, this, TQ_SLOT(slotIndent()), ac, "edit_indent");
+	new TDEAction(i18n("&Unindent"), "format-indent-less", CTRL+SHIFT+Key_I, this, TQ_SLOT(slotUnIndent()), ac, "edit_unindent");
+	new TDEAction(i18n("Cl&ean Indentation"), 0, 0, this, TQ_SLOT(slotCleanIndent()), ac, "edit_cleanIndent");
+	new TDEAction(i18n("Co&mment"), 0, CTRL+Key_D, this, TQ_SLOT(slotComment()), ac, "edit_comment");
+	new TDEAction(i18n("Unc&omment"), 0, CTRL+SHIFT+Key_D, this, TQ_SLOT(slotUnComment()), ac, "edit_uncomment");
 	
 	// Settings actions
-	KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT(slotSettings()), ac );
-	new TDEAction(i18n("&Configure Editor..."), "configure", 0, TQT_TQOBJECT(this), TQT_SLOT(slotEditor()), ac, "set_confdlg");
+	KStdAction::preferences( this, TQ_SLOT(slotSettings()), ac );
+	new TDEAction(i18n("&Configure Editor..."), "configure", 0, this, TQ_SLOT(slotEditor()), ac, "set_confdlg");
 	
 	// Help actions
-	ContextHelp = new TDEAction(0, 0, Key_F2, TQT_TQOBJECT(this), TQT_SLOT(slotContextHelp()), ac, "context_help");
+	ContextHelp = new TDEAction(0, 0, Key_F2, this, TQ_SLOT(slotContextHelp()), ac, "context_help");
 	slotContextHelpUpdate(); // this sets the label of this action
 	
 	// other
@@ -204,9 +204,9 @@ void MainWindow::setupEditor()
 	slotSetHighlightstyle( Settings::logoLanguage() );
 
 	// allow the cursor position to be indicated in the statusbar
-	connect( editor, TQT_SIGNAL(cursorPositionChanged()), this, TQT_SLOT(slotCursorStatusBar()) );
+	connect( editor, TQ_SIGNAL(cursorPositionChanged()), this, TQ_SLOT(slotCursorStatusBar()) );
 	// and update the context help menu item
-	connect( editor, TQT_SIGNAL(cursorPositionChanged()), this, TQT_SLOT(slotContextHelpUpdate()) );
+	connect( editor, TQ_SIGNAL(cursorPositionChanged()), this, TQ_SLOT(slotContextHelpUpdate()) );
 	
 	translate = new Translate();
 }
@@ -236,7 +236,7 @@ void MainWindow::setupCanvas()
 	baseLayout->setColStretch(0, 1);
 	TQWhatsThis::add( canvasView, i18n("This is the canvas, here the turtle draws a picture.") );
 	canvasView->show();
-	connect( canvasView, TQT_SIGNAL( CanvasResized() ), this, TQT_SLOT( slotUpdateCanvas() ) );
+	connect( canvasView, TQ_SIGNAL( CanvasResized() ), this, TQ_SLOT( slotUpdateCanvas() ) );
 }
 
 // END
@@ -525,10 +525,10 @@ void MainWindow::slotExecute()
 	TQString txt = editorInterface->text() + "\x0a\x0a"; // parser expects input to have 2 delimiting newlines
 	TQTextIStream in(&txt); // create the stream
 	Parser parser(in); // pass the reference to the stream to the parse object
-	connect(&parser, TQT_SIGNAL( ErrorMsg(Token&, const TQString&, uint) ),
-	         errMsg, TQT_SLOT( slotAddError(Token&, const TQString&, uint) ) );
-	connect( errMsg, TQT_SIGNAL(setSelection(uint, uint, uint, uint) ),
-	           this, TQT_SLOT(slotSetSelection(uint, uint, uint, uint) ) );
+	connect(&parser, TQ_SIGNAL( ErrorMsg(Token&, const TQString&, uint) ),
+	         errMsg, TQ_SLOT( slotAddError(Token&, const TQString&, uint) ) );
+	connect( errMsg, TQ_SIGNAL(setSelection(uint, uint, uint, uint) ),
+	           this, TQ_SLOT(slotSetSelection(uint, uint, uint, uint) ) );
 	parser.parse(); // and GO!
 	TreeNode* root = parser.getTree(); // when finished parsing get the nodeTree
 	kdDebug(0)<<"############## PARSING FINISHED ##############"<<endl;
@@ -541,42 +541,42 @@ void MainWindow::slotExecute()
 	kdDebug(0)<<"############## EXECUTION STARTED ##############"<<endl;
 	exe = new Executer(root); // make Executer object, 'exe', and pass it the nodeTree
 	
-	connect(this, TQT_SIGNAL( changeSpeed(int) ), exe, TQT_SLOT(slotChangeSpeed(int) ) );
-	connect(this, TQT_SIGNAL( unpauseExecution() ), exe, TQT_SLOT( slotStopPausing() ) );
-	connect( exe, TQT_SIGNAL( setSelection(uint, uint, uint, uint) ),
-	        this, TQT_SLOT  ( slotSetSelection(uint, uint, uint, uint) ) );
-	connect( exe, TQT_SIGNAL( ErrorMsg(Token&, const TQString&, uint) ),
-	      errMsg, TQT_SLOT  ( slotAddError(Token&, const TQString&, uint) ) );
-	connect( exe, TQT_SIGNAL( InputDialog(TQString&) ), this, TQT_SLOT( slotInputDialog(TQString&) ) );
-	connect( exe, TQT_SIGNAL( MessageDialog(TQString) ), this, TQT_SLOT( slotMessageDialog(TQString) ) );
+	connect(this, TQ_SIGNAL( changeSpeed(int) ), exe, TQ_SLOT(slotChangeSpeed(int) ) );
+	connect(this, TQ_SIGNAL( unpauseExecution() ), exe, TQ_SLOT( slotStopPausing() ) );
+	connect( exe, TQ_SIGNAL( setSelection(uint, uint, uint, uint) ),
+	        this, TQ_SLOT  ( slotSetSelection(uint, uint, uint, uint) ) );
+	connect( exe, TQ_SIGNAL( ErrorMsg(Token&, const TQString&, uint) ),
+	      errMsg, TQ_SLOT  ( slotAddError(Token&, const TQString&, uint) ) );
+	connect( exe, TQ_SIGNAL( InputDialog(TQString&) ), this, TQ_SLOT( slotInputDialog(TQString&) ) );
+	connect( exe, TQ_SIGNAL( MessageDialog(TQString) ), this, TQ_SLOT( slotMessageDialog(TQString) ) );
 
 	// Connect the signals form Executer to the slots from Canvas:
-	connect( exe, TQT_SIGNAL( Clear() ), canvasView, TQT_SLOT( slotClear() ) );
-	connect( exe, TQT_SIGNAL( Go(double, double) ), canvasView, TQT_SLOT( slotGo(double, double) ) );
-	connect( exe, TQT_SIGNAL( GoX(double) ), canvasView, TQT_SLOT( slotGoX(double) ) );
-	connect( exe, TQT_SIGNAL( GoY(double) ), canvasView, TQT_SLOT( slotGoY(double) ) );
-	connect( exe, TQT_SIGNAL( Forward(double) ), canvasView, TQT_SLOT( slotForward(double) ) );
-	connect( exe, TQT_SIGNAL( Backward(double) ), canvasView, TQT_SLOT( slotBackward(double) ) );
-	connect( exe, TQT_SIGNAL( Direction(double) ), canvasView, TQT_SLOT( slotDirection(double) ) );
-	connect( exe, TQT_SIGNAL( TurnLeft(double) ), canvasView, TQT_SLOT( slotTurnLeft(double) ) );
-	connect( exe, TQT_SIGNAL( TurnRight(double) ), canvasView, TQT_SLOT( slotTurnRight(double) ) );
-	connect( exe, TQT_SIGNAL( Center() ), canvasView, TQT_SLOT( slotCenter() ) );
-	connect( exe, TQT_SIGNAL( SetPenWidth(int) ), canvasView, TQT_SLOT( slotSetPenWidth(int) ) );
-	connect( exe, TQT_SIGNAL( PenUp() ), canvasView, TQT_SLOT( slotPenUp() ) );
-	connect( exe, TQT_SIGNAL( PenDown() ), canvasView, TQT_SLOT( slotPenDown() ) );
-	connect( exe, TQT_SIGNAL( SetFgColor(int, int, int) ), canvasView, TQT_SLOT( slotSetFgColor(int, int, int) ) );
-	connect( exe, TQT_SIGNAL( SetBgColor(int, int, int) ), canvasView, TQT_SLOT( slotSetBgColor(int, int, int) ) );
-	connect( exe, TQT_SIGNAL( ResizeCanvas(int, int) ), canvasView, TQT_SLOT( slotResizeCanvas(int, int) ) );
-	connect( exe, TQT_SIGNAL( SpriteShow() ), canvasView, TQT_SLOT( slotSpriteShow() ) );
-	connect( exe, TQT_SIGNAL( SpriteHide() ), canvasView, TQT_SLOT( slotSpriteHide() ) );
-	connect( exe, TQT_SIGNAL( SpritePress() ), canvasView, TQT_SLOT( slotSpritePress() ) );
-	connect( exe, TQT_SIGNAL( SpriteChange(int) ), canvasView, TQT_SLOT( slotSpriteChange(int) ) );
-	connect( exe, TQT_SIGNAL( Print(TQString) ), canvasView, TQT_SLOT( slotPrint(TQString) ) );
-	connect( exe, TQT_SIGNAL( FontType(TQString, TQString) ), canvasView, TQT_SLOT( slotFontType(TQString, TQString) ) );
-	connect( exe, TQT_SIGNAL( FontSize(int) ), canvasView, TQT_SLOT( slotFontSize(int) ) );
-	connect( exe, TQT_SIGNAL( WrapOn() ), canvasView, TQT_SLOT( slotWrapOn() ) );
-	connect( exe, TQT_SIGNAL( WrapOff() ), canvasView, TQT_SLOT( slotWrapOff() ) );
-	connect( exe, TQT_SIGNAL( Reset() ), canvasView, TQT_SLOT( slotReset() ) );
+	connect( exe, TQ_SIGNAL( Clear() ), canvasView, TQ_SLOT( slotClear() ) );
+	connect( exe, TQ_SIGNAL( Go(double, double) ), canvasView, TQ_SLOT( slotGo(double, double) ) );
+	connect( exe, TQ_SIGNAL( GoX(double) ), canvasView, TQ_SLOT( slotGoX(double) ) );
+	connect( exe, TQ_SIGNAL( GoY(double) ), canvasView, TQ_SLOT( slotGoY(double) ) );
+	connect( exe, TQ_SIGNAL( Forward(double) ), canvasView, TQ_SLOT( slotForward(double) ) );
+	connect( exe, TQ_SIGNAL( Backward(double) ), canvasView, TQ_SLOT( slotBackward(double) ) );
+	connect( exe, TQ_SIGNAL( Direction(double) ), canvasView, TQ_SLOT( slotDirection(double) ) );
+	connect( exe, TQ_SIGNAL( TurnLeft(double) ), canvasView, TQ_SLOT( slotTurnLeft(double) ) );
+	connect( exe, TQ_SIGNAL( TurnRight(double) ), canvasView, TQ_SLOT( slotTurnRight(double) ) );
+	connect( exe, TQ_SIGNAL( Center() ), canvasView, TQ_SLOT( slotCenter() ) );
+	connect( exe, TQ_SIGNAL( SetPenWidth(int) ), canvasView, TQ_SLOT( slotSetPenWidth(int) ) );
+	connect( exe, TQ_SIGNAL( PenUp() ), canvasView, TQ_SLOT( slotPenUp() ) );
+	connect( exe, TQ_SIGNAL( PenDown() ), canvasView, TQ_SLOT( slotPenDown() ) );
+	connect( exe, TQ_SIGNAL( SetFgColor(int, int, int) ), canvasView, TQ_SLOT( slotSetFgColor(int, int, int) ) );
+	connect( exe, TQ_SIGNAL( SetBgColor(int, int, int) ), canvasView, TQ_SLOT( slotSetBgColor(int, int, int) ) );
+	connect( exe, TQ_SIGNAL( ResizeCanvas(int, int) ), canvasView, TQ_SLOT( slotResizeCanvas(int, int) ) );
+	connect( exe, TQ_SIGNAL( SpriteShow() ), canvasView, TQ_SLOT( slotSpriteShow() ) );
+	connect( exe, TQ_SIGNAL( SpriteHide() ), canvasView, TQ_SLOT( slotSpriteHide() ) );
+	connect( exe, TQ_SIGNAL( SpritePress() ), canvasView, TQ_SLOT( slotSpritePress() ) );
+	connect( exe, TQ_SIGNAL( SpriteChange(int) ), canvasView, TQ_SLOT( slotSpriteChange(int) ) );
+	connect( exe, TQ_SIGNAL( Print(TQString) ), canvasView, TQ_SLOT( slotPrint(TQString) ) );
+	connect( exe, TQ_SIGNAL( FontType(TQString, TQString) ), canvasView, TQ_SLOT( slotFontType(TQString, TQString) ) );
+	connect( exe, TQ_SIGNAL( FontSize(int) ), canvasView, TQ_SLOT( slotFontSize(int) ) );
+	connect( exe, TQ_SIGNAL( WrapOn() ), canvasView, TQ_SLOT( slotWrapOn() ) );
+	connect( exe, TQ_SIGNAL( WrapOff() ), canvasView, TQ_SLOT( slotWrapOff() ) );
+	connect( exe, TQ_SIGNAL( Reset() ), canvasView, TQ_SLOT( slotReset() ) );
 
 	// START EXECUTION on the selected speed, and use the feedbacked boolean value
 	slotChangeSpeed();
@@ -625,7 +625,7 @@ void MainWindow::finishExecution()
 	if (speed->currentItem() == 0) slotClearSelection();
 
 	// if coming from fullscreen-mode show the editor, menu- and statusbar
-	if (b_fullscreen) TQTimer::singleShot( 1000, this, TQT_SLOT( slotFinishedFullScreenExecution() ) );
+	if (b_fullscreen) TQTimer::singleShot( 1000, this, TQ_SLOT( slotFinishedFullScreenExecution() ) );
 }
 
 void MainWindow::slotChangeSpeed()
@@ -833,9 +833,9 @@ void MainWindow::slotFinishedFullScreenExecution()
 	if ( errMsg->containsErrors() ) slotBackToFullScreen(); // straight back to edit if there where errors 
 	else
 	{
-		connect( restartOrBackDialog, TQT_SIGNAL( user1Clicked() ), this, TQT_SLOT( slotRestartFullScreen() ) );
-		connect( restartOrBackDialog, TQT_SIGNAL( user2Clicked() ), this, TQT_SLOT( slotBackToFullScreen() ) );
-		connect( restartOrBackDialog, TQT_SIGNAL( finished() ), this, TQT_SLOT( slotBackToFullScreen() ) );
+		connect( restartOrBackDialog, TQ_SIGNAL( user1Clicked() ), this, TQ_SLOT( slotRestartFullScreen() ) );
+		connect( restartOrBackDialog, TQ_SIGNAL( user2Clicked() ), this, TQ_SLOT( slotBackToFullScreen() ) );
+		connect( restartOrBackDialog, TQ_SIGNAL( finished() ), this, TQ_SLOT( slotBackToFullScreen() ) );
 		restartOrBackDialog->show();
 		restartOrBackDialog->move(50, 50);
 	}
@@ -870,13 +870,13 @@ void MainWindow::slotSettings()
 	// Create a new dialog with the same name as the above checking code.
 	TDEConfigDialog *dialog = new TDEConfigDialog(this, "settings", Settings::self() );
 	// connect the help
-	connect( dialog, TQT_SIGNAL( helpClicked() ), this, TQT_SLOT( slotSettingsHelp() ) );
+	connect( dialog, TQ_SIGNAL( helpClicked() ), this, TQ_SLOT( slotSettingsHelp() ) );
 	
 	// making the filling for the 'General' settings dept.
 	general = new TQWidget();
 	TQGridLayout *generalLayout = new TQGridLayout( general, 1, 1, 11, 6, "generalLayout");
 	WidthHeightBox = new TQGroupBox( i18n("Initial Canvas Size"), general );
-	WidthHeightBox->setColumnLayout(0, Qt::Vertical );
+	WidthHeightBox->setColumnLayout(0, TQt::Vertical );
 	WidthHeightBox->layout()->setSpacing( 6 );
 	WidthHeightBox->layout()->setMargin( 11 );
 	TQVBoxLayout *WidthHeightBoxLayout = new TQVBoxLayout( WidthHeightBox->layout() );
@@ -917,7 +917,7 @@ void MainWindow::slotSettings()
 	TQWidget *language = new TQWidget();
 	TQGridLayout *languageLayout = new TQGridLayout( language, 1, 1, 11, 6, "Form1Layout");
 	TQGroupBox *groupBox1 = new TQGroupBox( language, "groupBox1" );
-	groupBox1->setColumnLayout(0, Qt::Vertical );
+	groupBox1->setColumnLayout(0, TQt::Vertical );
 	groupBox1->layout()->setSpacing( 6 );
 	groupBox1->layout()->setMargin( 11 );
 	TQGridLayout *groupBox1Layout = new TQGridLayout( groupBox1->layout() );
@@ -946,7 +946,7 @@ void MainWindow::slotSettings()
 	dialog->addPage( language, i18n("Language"), "locale", i18n("Language Settings") );
 
 	// When the user clicks OK or Apply we want to update our settings.
-	connect( dialog, TQT_SIGNAL( settingsChanged() ), this, TQT_SLOT( slotUpdateSettings() ) );
+	connect( dialog, TQ_SIGNAL( settingsChanged() ), this, TQ_SLOT( slotUpdateSettings() ) );
 
 	// Display the dialog is there where errors.
 	dialog->setInitialSize( TQSize(550, 300) );
@@ -1150,8 +1150,8 @@ void MainWindow::slotColorPicker()
 	{
 		picker = new ColorPicker(this);
 		if(picker == 0) return; // safety
-		connect( picker, TQT_SIGNAL( visible(bool) ), colorpicker, TQT_SLOT( setChecked(bool) ) );
-		connect( picker, TQT_SIGNAL( ColorCode(TQString) ), this, TQT_SLOT( slotInsertText(TQString) ) );
+		connect( picker, TQ_SIGNAL( visible(bool) ), colorpicker, TQ_SLOT( setChecked(bool) ) );
+		connect( picker, TQ_SIGNAL( ColorCode(TQString) ), this, TQ_SLOT( slotInsertText(TQString) ) );
 	}
 	// if picker is not 0, there is a colorpickerdialog which only needs to be shown OR hidden
 	if ( picker->isHidden() )
