@@ -71,19 +71,19 @@ KImageCanvas::KImageCanvas( TQWidget * parent, const char * name, const TQString
 	setMinimumSize( 0, 0 );
 	setBgColor( Defaults::bgColor );
 
-	connect( this, TQT_SIGNAL( imageChanged() ), this, TQT_SLOT( slotImageChanged() ) );
-	connect( m_pTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( hideCursor() ) );
+	connect( this, TQ_SIGNAL( imageChanged() ), this, TQ_SLOT( slotImageChanged() ) );
+	connect( m_pTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( hideCursor() ) );
 
 	KSettings::Dispatcher::self()->registerInstance(
-			KImageCanvasFactory::instance(), TQT_TQOBJECT(this),
-			TQT_SLOT( loadSettings() ) );
+			KImageCanvasFactory::instance(), this,
+			TQ_SLOT( loadSettings() ) );
 
 	viewport()->setFocusProxy( this );
 	clear();
 
 	TQWidget::setMouseTracking( true );
 	viewport()->setMouseTracking( true );
-	m_cursor.setShape( Qt::CrossCursor );
+	m_cursor.setShape( TQt::CrossCursor );
 	viewport()->setCursor( m_cursor );
 	m_pTimer->start( MOUSECURSORHIDETIME, true );
 
@@ -327,7 +327,7 @@ TQString KImageCanvas::blendEffectDescription( unsigned int idx ) const
 bool KImageCanvas::eventFilter( TQObject * obj, TQEvent * ev )
 {
 	if( ( obj == m_client || obj == m_oldClient ) && ev->type() == TQEvent::MouseMove )
-		mouseMoveEvent( TQT_TQMOUSEEVENT( ev ) );
+		mouseMoveEvent( static_cast<TQMouseEvent*>( ev ) );
 	return TQScrollView::eventFilter( obj, ev );
 }
 
@@ -517,7 +517,7 @@ void KImageCanvas::updateImage()
 {
 	kdDebug( 4620 ) << k_funcinfo << endl;
 	if( ! m_bImageUpdateScheduled )
-		TQTimer::singleShot( 0, this, TQT_SLOT( slotUpdateImage() ) );
+		TQTimer::singleShot( 0, this, TQ_SLOT( slotUpdateImage() ) );
 	m_bImageUpdateScheduled = true;
 }
 
@@ -589,7 +589,7 @@ void KImageCanvas::mouseMoveEvent( TQMouseEvent * )
 {
 	if( m_cursor.shape() == TQt::BlankCursor )
 	{
-		m_cursor.setShape( Qt::CrossCursor );
+		m_cursor.setShape( TQt::CrossCursor );
 		viewport()->setCursor( m_cursor );
 		if( m_client )
 			m_client->setCursor( m_cursor );
@@ -607,7 +607,7 @@ void KImageCanvas::resizeEvent( TQResizeEvent * ev )
 
 void KImageCanvas::contentsMousePressEvent( TQMouseEvent * ev )
 {
-	if ( ev->button() == Qt::RightButton )
+	if ( ev->button() == TQt::RightButton )
 		emit contextPress( ev->globalPos() );
 	TQScrollView::contentsMousePressEvent( ev );
 }
@@ -772,7 +772,7 @@ void KImageCanvas::timerEvent( TQTimerEvent * ev )
 void KImageCanvas::hideCursor()
 {
 	kdDebug( 4620 ) << k_funcinfo << endl;
-	m_cursor.setShape( Qt::BlankCursor );
+	m_cursor.setShape( TQt::BlankCursor );
 	viewport()->setCursor( m_cursor );
 	if( m_client )
 		m_client->setCursor( m_cursor );
@@ -940,10 +940,10 @@ KImageHolder * KImageCanvas::createNewClient()
 
 	addChild( client, 0, 0 );
 
-	connect( client, TQT_SIGNAL( contextPress( const TQPoint& ) ), TQT_SIGNAL( contextPress( const TQPoint& ) ) );
-	connect( client, TQT_SIGNAL( cursorPos( const TQPoint & ) ), TQT_SLOT( mapCursorPos( const TQPoint & ) ) );
-	connect( client, TQT_SIGNAL( selected( const TQRect & ) ), TQT_SLOT( selected( const TQRect & ) ) );
-	connect( client, TQT_SIGNAL( wannaScroll( int, int ) ), TQT_SLOT( scrollBy( int, int ) ) );
+	connect( client, TQ_SIGNAL( contextPress( const TQPoint& ) ), TQ_SIGNAL( contextPress( const TQPoint& ) ) );
+	connect( client, TQ_SIGNAL( cursorPos( const TQPoint & ) ), TQ_SLOT( mapCursorPos( const TQPoint & ) ) );
+	connect( client, TQ_SIGNAL( selected( const TQRect & ) ), TQ_SLOT( selected( const TQRect & ) ) );
+	connect( client, TQ_SIGNAL( wannaScroll( int, int ) ), TQ_SLOT( scrollBy( int, int ) ) );
 
 	return client;
 }
