@@ -14,7 +14,7 @@
  */
 class %{APPNAMELC}tdemdiView : public KMdiChildView 
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		%{APPNAMELC}tdemdiView( TQWidget *parentWidget=0L, const char *name=0L );
