@@ -94,7 +94,7 @@ class KMdiChildViewPrivate;
   *     flags = KMdi::Hide;
   *   }
   *   // set the accelerators for Toplevel MDI mode (each toplevel window needs its own accels
-  *   connect( m_pParent, TQT_SIGNAL(childViewIsDetachedNow(TQWidget*)), this, TQT_SLOT(initKeyAccel(TQWidget*)) );
+  *   connect( m_pParent, TQ_SIGNAL(childViewIsDetachedNow(TQWidget*)), this, TQ_SLOT(initKeyAccel(TQWidget*)) );
   *
   *   m_pParent->addWindow( pMDICover, flags);
   *   // correct the default settings of KMdi ('cause we haven't a tab order for subwidget focuses)
@@ -109,7 +109,7 @@ class KMDI_EXPORT KMdiChildView : public TQWidget
 {
 	friend class KMdiMainFrm;
 	friend class KMdiChildFrm;
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	// attributes
@@ -612,5 +612,3 @@ inline KMdiChildFrm *KMdiChildView::mdiParent() const
 }
 
 #endif //_TDEMDI_CHILD_VIEW_H_
-
-// kate: space-indent off; replace-tabs off; indent-mode csands; tab-width 4;
