@@ -22,7 +22,7 @@ class TDEPopupMenu;
 class KMDI_EXPORT KMdiDocumentViewTabWidget:
 			public KTabWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMdiDocumentViewTabWidget( TQWidget* parent, const char* name = 0 );
