@@ -101,7 +101,7 @@ class DefaultSourceProvider: public SourceProvider {
 
 
 Driver::Driver()
-  : depresolv( FALSE ), lexer( 0 ), m_lexerCache( this ), m_dependenceDepth( 0 ), m_maxDependenceDepth( 20 ) {
+  : depresolv( false ), lexer( 0 ), m_lexerCache( this ), m_dependenceDepth( 0 ), m_maxDependenceDepth( 20 ) {
   m_sourceProvider = new DefaultSourceProvider();
 }
 
@@ -552,7 +552,6 @@ void Driver::setupLexer( Lexer * lexer ) {
   lexer->addSkipWord( "ANTLR_USE_NAMESPACE", SkipWordAndArguments );
   lexer->addSkipWord( "ANTLR_USING_NAMESPACE", SkipWordAndArguments );
   lexer->addSkipWord( "ANTLR_END_NAMESPACE" );
-  lexer->addSkipWord( "ANTLR_C_USING", SkipWordAndArguments );
   lexer->addSkipWord( "ANTLR_API" );
 
   // gnu
