@@ -16,7 +16,7 @@
 
 class KDevJobTimer : public TQTimer
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	static void singleShot( int msec, TQObject * receiver, const char * member, void * payload );
