@@ -39,7 +39,7 @@
 #include "kcalversion.h"
 #include "person.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include <tqobject.h>
 #include <tqstring.h>
@@ -169,7 +169,7 @@ enum JournalSortField
 class LIBKCAL_EXPORT Calendar : public TQObject, public CustomProperties,
                                 public IncidenceBase::Observer
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
