@@ -25,7 +25,7 @@ namespace KCDDB
 {
   class AsyncHTTPSubmit : public HTTPSubmit
   {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
       AsyncHTTPSubmit(const TQString& from, const TQString& hostname, uint port);
