@@ -36,7 +36,7 @@ namespace KCDDB
       TQString description;
   } ;
 
-  class KDE_EXPORT Sites : public CDDB
+  class TDE_EXPORT Sites : public CDDB
   {
     public:
       Sites();
