@@ -29,7 +29,7 @@
 
 #include "kpgp.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class TQString;
 class TQRegExp;
@@ -52,7 +52,7 @@ class Key;                  // needed by KeySelectionDialog
 class KeyIDList;            // needed by KeySelectionDialog
 
 /** the passphrase dialog */
-class KDE_EXPORT PassphraseDialog : public KDialogBase
+class TDE_EXPORT PassphraseDialog : public KDialogBase
 {
   TQ_OBJECT
   
@@ -73,7 +73,7 @@ class KDE_EXPORT PassphraseDialog : public KDialogBase
 /** a widget for configuring the pgp interface. Can be included into
     a tabdialog. This widget by itself does not provide an apply/cancel
     button mechanism. */
-class KDE_EXPORT Config : public TQWidget
+class TDE_EXPORT Config : public TQWidget
 {
   TQ_OBJECT
   
@@ -101,7 +101,7 @@ class KDE_EXPORT Config : public TQWidget
 
 // -------------------------------------------------------------------------
 #define KeySelectionDialogSuper KDialogBase
-class KDE_EXPORT KeySelectionDialog: public KeySelectionDialogSuper
+class TDE_EXPORT KeySelectionDialog: public KeySelectionDialogSuper
 {
   TQ_OBJECT
   
@@ -201,7 +201,7 @@ class KDE_EXPORT KeySelectionDialog: public KeySelectionDialogSuper
   static const int sCheckSelectionDelay;
 };
 
-class KDE_EXPORT KeyRequester: public TQWidget
+class TDE_EXPORT KeyRequester: public TQWidget
 {
   TQ_OBJECT
   
@@ -254,7 +254,7 @@ protected:
 };
 
 
-class KDE_EXPORT PublicKeyRequester : public KeyRequester {
+class TDE_EXPORT PublicKeyRequester : public KeyRequester {
   TQ_OBJECT
   
 public:
@@ -274,7 +274,7 @@ protected:
 };
 
 
-class KDE_EXPORT SecretKeyRequester : public KeyRequester {
+class TDE_EXPORT SecretKeyRequester : public KeyRequester {
   TQ_OBJECT
   
 public:
@@ -295,7 +295,7 @@ protected:
 
 
 // -------------------------------------------------------------------------
-class KDE_EXPORT KeyApprovalDialog: public KDialogBase
+class TDE_EXPORT KeyApprovalDialog: public KDialogBase
 {
   TQ_OBJECT
   
@@ -331,7 +331,7 @@ class KDE_EXPORT KeyApprovalDialog: public KDialogBase
 
 
 // -------------------------------------------------------------------------
-class KDE_EXPORT CipherTextDialog: public KDialogBase
+class TDE_EXPORT CipherTextDialog: public KDialogBase
 {
   TQ_OBJECT
   
