@@ -25,6 +25,6 @@ int main( int argc, char *argv[] )
 	TDEApplication a;
 	TestWidget *t = new TestWidget(0,0);
 	t->show();
-	TQObject::connect(kapp, TQT_SIGNAL(lastWindowClosed()), kapp, TQT_SLOT(quit()));
+	TQObject::connect(kapp, TQ_SIGNAL(lastWindowClosed()), kapp, TQ_SLOT(quit()));
 	return a.exec();
 }
