@@ -6,7 +6,7 @@
 
 class KEduSimpleEntryDlg : public KEduSimpleEntryDlgForm
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
  public:
