@@ -274,7 +274,7 @@ void KCardDialog::setupDialog(bool showResizeBox)
     TQHBoxLayout* layout = new TQHBoxLayout(cardLayout);
 
     // Deck iconview
-    TQGroupBox* grp1 = new TQGroupBox(1,Qt::Horizontal, i18n("Choose Backside"), plainPage());
+    TQGroupBox* grp1 = new TQGroupBox(1,TQt::Horizontal, i18n("Choose Backside"), plainPage());
     layout->addWidget(grp1);
 
     d->deckIconView = new TDEIconView(grp1,"decks");
@@ -304,8 +304,8 @@ void KCardDialog::setupDialog(bool showResizeBox)
 
     d->randomDeck = new TQCheckBox(plainPage());
     d->randomDeck->setChecked(false);
-    connect(d->randomDeck, TQT_SIGNAL(toggled(bool)), this,
-            TQT_SLOT(slotRandomDeckToggled(bool)));
+    connect(d->randomDeck, TQ_SIGNAL(toggled(bool)), this,
+            TQ_SLOT(slotRandomDeckToggled(bool)));
     d->randomDeck->setText(i18n("Random backside"));
     l->addWidget(d->randomDeck, 0, AlignTop|AlignHCenter);
 
@@ -315,18 +315,18 @@ void KCardDialog::setupDialog(bool showResizeBox)
     l->addWidget(d->globalDeck, 0, AlignTop|AlignHCenter);
 
     TQPushButton* b = new TQPushButton(i18n("Make Backside Global"), plainPage());
-    connect(b, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotSetGlobalDeck()));
+    connect(b, TQ_SIGNAL(pressed()), this, TQ_SLOT(slotSetGlobalDeck()));
     l->addWidget(b, 0, AlignTop|AlignHCenter);
 
-    connect(d->deckIconView,TQT_SIGNAL(clicked(TQIconViewItem *)),
-            this,TQT_SLOT(slotDeckClicked(TQIconViewItem *)));
+    connect(d->deckIconView,TQ_SIGNAL(clicked(TQIconViewItem *)),
+            this,TQ_SLOT(slotDeckClicked(TQIconViewItem *)));
   }
 
   if (! (flags() & NoCards))
   {
     // Cards iconview
     TQHBoxLayout* layout = new TQHBoxLayout(cardLayout);
-    TQGroupBox* grp2 = new TQGroupBox(1,Qt::Horizontal, i18n("Choose Frontside"), plainPage());
+    TQGroupBox* grp2 = new TQGroupBox(1,TQt::Horizontal, i18n("Choose Frontside"), plainPage());
     layout->addWidget(grp2);
 
     d->cardIconView =new TDEIconView(grp2,"cards");
@@ -354,8 +354,8 @@ void KCardDialog::setupDialog(bool showResizeBox)
 
     d->randomCardDir = new TQCheckBox(plainPage());
     d->randomCardDir->setChecked(false);
-    connect(d->randomCardDir, TQT_SIGNAL(toggled(bool)), this,
-            TQT_SLOT(slotRandomCardDirToggled(bool)));
+    connect(d->randomCardDir, TQ_SIGNAL(toggled(bool)), this,
+            TQ_SLOT(slotRandomCardDirToggled(bool)));
     d->randomCardDir->setText(i18n("Random frontside"));
     l->addWidget(d->randomCardDir, 0, AlignTop|AlignHCenter);
 
@@ -365,11 +365,11 @@ void KCardDialog::setupDialog(bool showResizeBox)
     l->addWidget(d->globalCardDir, 0, AlignTop|AlignHCenter);
 
     TQPushButton* b = new TQPushButton(i18n("Make Frontside Global"), plainPage());
-    connect(b, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotSetGlobalCardDir()));
+    connect(b, TQ_SIGNAL(pressed()), this, TQ_SLOT(slotSetGlobalCardDir()));
     l->addWidget(b, 0, AlignTop|AlignHCenter);
 
-    connect(d->cardIconView,TQT_SIGNAL(clicked(TQIconViewItem *)),
-            this,TQT_SLOT(slotCardClicked(TQIconViewItem *)));
+    connect(d->cardIconView,TQ_SIGNAL(clicked(TQIconViewItem *)),
+            this,TQ_SLOT(slotCardClicked(TQIconViewItem *)));
   }
 
   // Insert deck icons
@@ -423,7 +423,7 @@ void KCardDialog::setupDialog(bool showResizeBox)
     // larger but i want the complete pixmap to be displayed. the dialog is not
     // resized if you make the pixmap smaller again.
     TQVBoxLayout* layout = new TQVBoxLayout(topLayout);
-    TQGroupBox* grp = new TQGroupBox(1,Qt::Horizontal, i18n("Resize Cards"), plainPage());
+    TQGroupBox* grp = new TQGroupBox(1,TQt::Horizontal, i18n("Resize Cards"), plainPage());
     layout->setResizeMode(TQLayout::Fixed);
     layout->addWidget(grp);
     TQWidget* box = new TQWidget(grp);
@@ -431,13 +431,13 @@ void KCardDialog::setupDialog(bool showResizeBox)
     TQVBoxLayout* boxLayout = new TQVBoxLayout(hbox);
     hbox->addStretch(0);
 
-    d->scaleSlider = new TQSlider(1, SLIDER_MAX, 1, (-1000+SLIDER_MIN+SLIDER_MAX),Qt::Horizontal, box);
+    d->scaleSlider = new TQSlider(1, SLIDER_MAX, 1, (-1000+SLIDER_MIN+SLIDER_MAX),TQt::Horizontal, box);
     d->scaleSlider->setMinValue(SLIDER_MIN);
-    connect(d->scaleSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotCardResized(int)));
+    connect(d->scaleSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotCardResized(int)));
     boxLayout->addWidget(d->scaleSlider, 0, AlignLeft);
 
     TQPushButton* b = new TQPushButton(i18n("Default Size"), box);
-    connect(b, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotDefaultSize()));
+    connect(b, TQ_SIGNAL(pressed()), this, TQ_SLOT(slotDefaultSize()));
     boxLayout->addWidget(b, 0, AlignLeft);
 
     TQLabel* l = new TQLabel(i18n("Preview:"), box);
