@@ -64,12 +64,12 @@ AddresseeView::AddresseeView( TQWidget *parent, const char *name,
   TQStyleSheetItem *link = sheet->item( "a" );
   link->setColor( TDEGlobalSettings::linkColor() );
 
-  connect( this, TQT_SIGNAL( mailClick( const TQString&, const TQString& ) ),
-           this, TQT_SLOT( slotMailClicked( const TQString&, const TQString& ) ) );
-  connect( this, TQT_SIGNAL( urlClick( const TQString& ) ),
-           this, TQT_SLOT( slotUrlClicked( const TQString& ) ) );
-  connect( this, TQT_SIGNAL( highlighted( const TQString& ) ),
-           this, TQT_SLOT( slotHighlighted( const TQString& ) ) );
+  connect( this, TQ_SIGNAL( mailClick( const TQString&, const TQString& ) ),
+           this, TQ_SLOT( slotMailClicked( const TQString&, const TQString& ) ) );
+  connect( this, TQ_SIGNAL( urlClick( const TQString& ) ),
+           this, TQ_SLOT( slotUrlClicked( const TQString& ) ) );
+  connect( this, TQ_SIGNAL( highlighted( const TQString& ) ),
+           this, TQ_SLOT( slotHighlighted( const TQString& ) ) );
 
   setNotifyClick( true );
 
@@ -88,13 +88,13 @@ AddresseeView::AddresseeView( TQWidget *parent, const char *name,
   mActionShowCustomFields = new TDEToggleAction( i18n( "Show Custom Fields" ) );
   mActionShowCustomFields->setCheckedState( i18n( "Hide Custom Fields" ) );
 
-  connect( mActionShowBirthday, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( configChanged() ) );
-  connect( mActionShowAddresses, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( configChanged() ) );
-  connect( mActionShowEmails, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( configChanged() ) );
-  connect( mActionShowPhones, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( configChanged() ) );
-  connect( mActionShowURLs, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( configChanged() ) );
-  connect( mActionShowIMAddresses, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( configChanged() ) );
-  connect( mActionShowCustomFields, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( configChanged() ) );
+  connect( mActionShowBirthday, TQ_SIGNAL( toggled( bool ) ), TQ_SLOT( configChanged() ) );
+  connect( mActionShowAddresses, TQ_SIGNAL( toggled( bool ) ), TQ_SLOT( configChanged() ) );
+  connect( mActionShowEmails, TQ_SIGNAL( toggled( bool ) ), TQ_SLOT( configChanged() ) );
+  connect( mActionShowPhones, TQ_SIGNAL( toggled( bool ) ), TQ_SLOT( configChanged() ) );
+  connect( mActionShowURLs, TQ_SIGNAL( toggled( bool ) ), TQ_SLOT( configChanged() ) );
+  connect( mActionShowIMAddresses, TQ_SIGNAL( toggled( bool ) ), TQ_SLOT( configChanged() ) );
+  connect( mActionShowCustomFields, TQ_SIGNAL( toggled( bool ) ), TQ_SLOT( configChanged() ) );
 
   if ( !config ) {
     mConfig = new TDEConfig( "kaddressbookrc" );
@@ -106,10 +106,10 @@ AddresseeView::AddresseeView( TQWidget *parent, const char *name,
 
   // set up IMProxy to display contacts' IM presence and make connections to keep the display live
   mKIMProxy = ::KIMProxy::instance( kapp->dcopClient() );
-  connect( mKIMProxy, TQT_SIGNAL( sigContactPresenceChanged( const TQString& ) ),
-           this, TQT_SLOT( slotPresenceChanged( const TQString& ) ) );
-  connect( mKIMProxy, TQT_SIGNAL( sigPresenceInfoExpired() ),
-           this, TQT_SLOT( slotPresenceInfoExpired() ) );
+  connect( mKIMProxy, TQ_SIGNAL( sigContactPresenceChanged( const TQString& ) ),
+           this, TQ_SLOT( slotPresenceChanged( const TQString& ) ) );
+  connect( mKIMProxy, TQ_SIGNAL( sigPresenceInfoExpired() ),
+           this, TQ_SLOT( slotPresenceInfoExpired() ) );
 }
 
 AddresseeView::~AddresseeView()
@@ -547,10 +547,10 @@ void AddresseeView::updateView()
         TQMimeSourceFactory::defaultFactory()->setImage( imageURL, TQImage(mImageData) );
       else {
         mImageJob = TDEIO::get( KURL( picture.url() ), false, false );
-        connect( mImageJob, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
-                 this, TQT_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
-        connect( mImageJob, TQT_SIGNAL( result( TDEIO::Job* ) ),
-                 this, TQT_SLOT( result( TDEIO::Job* ) ) );
+        connect( mImageJob, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+                 this, TQ_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
+        connect( mImageJob, TQ_SIGNAL( result( TDEIO::Job* ) ),
+                 this, TQ_SLOT( result( TDEIO::Job* ) ) );
       }
     } else {
       TQMimeSourceFactory::defaultFactory()->setPixmap( imageURL,
