@@ -34,7 +34,7 @@
 #define __KPIM_COLLECTINGPROCESS_H__
 
 #include <kprocess.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace KPIM {
 
@@ -46,7 +46,7 @@ namespace KPIM {
  *
  * @author Ingo Kloecker <kloecker@kde.org>
  */
-class KDE_EXPORT CollectingProcess : public TDEProcess {
+class TDE_EXPORT CollectingProcess : public TDEProcess {
   TQ_OBJECT
   
 public:
