@@ -61,11 +61,11 @@ KIncidenceChooser::KIncidenceChooser(TQWidget *parent, char *name) :
     topLayout->addMultiCellWidget(b_box, iii,iii,0,2);
     ++iii;
     TQPushButton* button = new TQPushButton( i18n("Take Local"), b_box );
-    connect ( button, TQT_SIGNAL( clicked()), this, TQT_SLOT (takeIncidence1() ) );
+    connect ( button, TQ_SIGNAL( clicked()), this, TQ_SLOT (takeIncidence1() ) );
     button = new TQPushButton( i18n("Take New"), b_box );
-    connect ( button, TQT_SIGNAL( clicked()), this, TQT_SLOT (takeIncidence2() ) );
+    connect ( button, TQ_SIGNAL( clicked()), this, TQ_SLOT (takeIncidence2() ) );
     button = new TQPushButton( i18n("Take Both"), b_box );
-    connect ( button, TQT_SIGNAL( clicked()), this, TQT_SLOT (takeBoth() ) );
+    connect ( button, TQ_SIGNAL( clicked()), this, TQ_SLOT (takeBoth() ) );
     topLayout->setSpacing(spacingHint());
     topLayout->setMargin(marginHint());
     // text is not translated, because text has to be set later
@@ -78,7 +78,7 @@ KIncidenceChooser::KIncidenceChooser(TQWidget *parent, char *name) :
     mMod1lab = new TQLabel ( "Set Last modified", topFrame);
     topLayout->addWidget(mMod1lab,iii,1);
     mShowDetails1 = new TQPushButton( i18n("Show Details"),topFrame );
-    connect ( mShowDetails1, TQT_SIGNAL( clicked()), this, TQT_SLOT (showIncidence1() ) );
+    connect ( mShowDetails1, TQ_SIGNAL( clicked()), this, TQ_SLOT (showIncidence1() ) );
     topLayout->addWidget(mShowDetails1,iii,2);
     ++iii;
 
@@ -91,20 +91,20 @@ KIncidenceChooser::KIncidenceChooser(TQWidget *parent, char *name) :
     mMod2lab = new TQLabel ( "Set Last modified", topFrame);
     topLayout->addWidget(mMod2lab,iii,1);
     mShowDetails2 = new TQPushButton( i18n("Show Details"), topFrame);
-    connect ( mShowDetails2, TQT_SIGNAL( clicked()), this, TQT_SLOT (showIncidence2() ) );
+    connect ( mShowDetails2, TQ_SIGNAL( clicked()), this, TQ_SLOT (showIncidence2() ) );
     topLayout->addWidget(mShowDetails2,iii,2);
     ++iii;
     //
 #if 0
     // commented out for now, because the diff code has too many bugs
     mDiffBut = new TQPushButton( i18n("Show Differences"), topFrame );
-    connect ( mDiffBut, TQT_SIGNAL( clicked()), this, TQT_SLOT ( showDiff() ) );
+    connect ( mDiffBut, TQ_SIGNAL( clicked()), this, TQ_SLOT ( showDiff() ) );
     topLayout->addMultiCellWidget(mDiffBut, iii,iii,0,2);
     ++iii;
 #else
     mDiffBut = 0;
 #endif
-    mBg = new TQButtonGroup ( 1,  Qt::Horizontal, i18n("Sync Preferences"), topFrame);
+    mBg = new TQButtonGroup ( 1,  TQt::Horizontal, i18n("Sync Preferences"), topFrame);
     topLayout->addMultiCellWidget(mBg, iii,iii,0,2);
     ++iii;
     mBg->insert( new TQRadioButton ( i18n("Take local entry on conflict"), mBg ), KIncidenceChooser::local);
@@ -118,7 +118,7 @@ KIncidenceChooser::KIncidenceChooser(TQWidget *parent, char *name) :
     mDisplayDiff = 0;
     mSelIncidence = 0;
     button = new TQPushButton( i18n("Apply This to All Conflicts of This Sync"), topFrame );
-    connect ( button, TQT_SIGNAL( clicked()), this, TQT_SLOT ( setSyncMode() ) );
+    connect ( button, TQ_SIGNAL( clicked()), this, TQ_SLOT ( setSyncMode() ) );
     topLayout->addMultiCellWidget(button, iii,iii,0,2);
 }
 
@@ -237,7 +237,7 @@ void KIncidenceChooser::showIncidence1()
     }
     mTbL = new KDialogBase( this, "", false /*not modal*/, mInc1lab->text(), KDialogBase::Ok );
     mTbL->setEscapeButton( KDialogBase::Ok );
-    connect( mTbL, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( detailsDialogClosed() ) );
+    connect( mTbL, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( detailsDialogClosed() ) );
     TQTextBrowser* textBrowser = new TQTextBrowser( mTbL );
     mTbL->setMainWidget( textBrowser );
     textBrowser->setText( KCal::IncidenceFormatter::extensiveDisplayString( mInc1 )  );
@@ -249,7 +249,7 @@ void KIncidenceChooser::showIncidence1()
 
 void KIncidenceChooser::detailsDialogClosed()
 {
-    KDialogBase* dialog =  static_cast<KDialogBase *>(TQT_TQWIDGET(const_cast<TQObject*>(sender()))) ;
+    KDialogBase* dialog =  static_cast<KDialogBase *>(const_cast<TQObject*>(sender())) ;
     if ( dialog == mTbL )
         mShowDetails1->setText( i18n( "Show details..." ) );
     else
@@ -293,7 +293,7 @@ void KIncidenceChooser::showIncidence2()
     }
     mTbN = new KDialogBase( this, "", false /*not modal*/, mInc2lab->text(), KDialogBase::Ok );
     mTbN->setEscapeButton( KDialogBase::Ok );
-    connect( mTbN, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( detailsDialogClosed() ) );
+    connect( mTbN, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( detailsDialogClosed() ) );
     TQTextBrowser* textBrowser = new TQTextBrowser( mTbN );
     mTbN->setMainWidget( textBrowser );
     textBrowser->setText( KCal::IncidenceFormatter::extensiveDisplayString( mInc2 ) );
