@@ -15,10 +15,10 @@ TestManager::TestManager( TQObject *parent )
   : TQObject( parent )
 {
   m_manager = new PluginManager( this );
-  connect( m_manager, TQT_SIGNAL(pluginLoaded(Plugin*)),
-           TQT_SLOT(slotPluginLoaded(Plugin*)) );
-  connect( m_manager, TQT_SIGNAL(allPluginsLoaded()),
-           TQT_SLOT(slotAllPluginsLoaded()) );
+  connect( m_manager, TQ_SIGNAL(pluginLoaded(Plugin*)),
+           TQ_SLOT(slotPluginLoaded(Plugin*)) );
+  connect( m_manager, TQ_SIGNAL(allPluginsLoaded()),
+           TQ_SLOT(slotAllPluginsLoaded()) );
   m_manager->loadAllPlugins();
 
   TQValueList<KPluginInfo*> plugins = m_manager->availablePlugins();
