@@ -18,8 +18,6 @@
 #undef TQT_NO_ASCII_CAST
 #endif
 
-#undef TQT_NO_COMPAT
-
 #include <iostream>
 
 #include <tqfile.h>
@@ -86,7 +84,7 @@ NotifyDialog::NotifyDialog(TQWidget* p)
   TQCheckBox *check = new TQCheckBox(i18n("Do not show this message again"),f);
   check->setChecked(true);
   topL->addWidget(check);
-  connect(check,TQT_SIGNAL(toggled(bool)),TQT_SLOT(slotShowAgainToggled(bool)));
+  connect(check,TQ_SIGNAL(toggled(bool)),TQ_SLOT(slotShowAgainToggled(bool)));
 }
 
 void NotifyDialog::slotShowAgainToggled(bool flag)
