@@ -30,7 +30,7 @@
 #include <tqobject.h>
 #include <setjmp.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // #define WIDTH 48
 // #define HEIGHT WIDTH
@@ -519,7 +519,7 @@ class TQString;
 
 namespace KPIM {
 
-  class KDE_EXPORT KXFace : public TQObject
+  class TDE_EXPORT KXFace : public TQObject
   {
     TQ_OBJECT
   
