@@ -62,7 +62,7 @@ static TQString join( const KPIM::LdapAttrValue& lst, const TQString& sep )
   for ( KPIM::LdapAttrValue::ConstIterator it = lst.begin(); it != lst.end(); ++it ) {
     if ( alredy )
       res += sep;
-    alredy = TRUE;
+    alredy = true;
     res += asUtf8( *it );
   }
   return res;
