@@ -183,7 +183,7 @@ TDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
 
   //assert(aFileName!=0);
   if(aFileName.isEmpty())
-    return FALSE;
+    return false;
 
   if (file.exists())
   {
@@ -194,7 +194,7 @@ TDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
 		  .arg(aFileName);
       rc = KMessageBox::warningContinueCancel(0,
 	   str, i18n("Save to File"), i18n("&Replace"));
-      if (rc != KMessageBox::Continue) return FALSE;
+      if (rc != KMessageBox::Continue) return false;
     }
     if (aBackup)
     {
@@ -206,12 +206,12 @@ TDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
       if( !TQDir::current().rename(aFileName, bakName) )
       {
 	// failed to rename file
-	if (!aVerbose) return FALSE;
+	if (!aVerbose) return false;
 	rc = KMessageBox::warningContinueCancel(0,
 	     i18n("Failed to make a backup copy of %1.\nContinue anyway?")
 	     .arg(aFileName),
              i18n("Save to File"), KStdGuiItem::save() );
-	if (rc != KMessageBox::Continue) return FALSE;
+	if (rc != KMessageBox::Continue) return false;
       }
     }
   }
@@ -230,7 +230,7 @@ TDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
     default:
       msgDialog(i18n("Error while writing file:\n%1").arg(aFileName));
     }
-    return FALSE;
+    return false;
   }
 
   writeLen = file.writeBlock(aBuffer, len);
@@ -239,7 +239,7 @@ TDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
   {
     if (aVerbose)
       msgDialog(i18n("Could not write to file:\n%1").arg(aFileName));
-    return FALSE;
+    return false;
   }
   else if (writeLen < len)
   {
@@ -247,10 +247,10 @@ TDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
 		.arg(writeLen).arg(len);
     if (aVerbose)
       msgDialog(msg);
-    return FALSE;
+    return false;
   }
 
-  return TRUE;
+  return true;
 }
 
 TDE_EXPORT bool kCStringToFile(const TQCString& aBuffer, const TQString &aFileName,
