@@ -33,7 +33,7 @@ class TQCheckBox;
 */
 class DelegateSelector : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
