@@ -23,25 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQCOMMONSTYLE_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QCommonStyle class
-// For Qt3, no changes are needed
-
 #include <ntqcommonstyle.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QCommonStyle class
-// For Qt4, some changes are needed
-
-#include <ntqstyle.h>
-#include <tqt4/Qt/ntqcommonstyle.h>
-#include <Qt/ntqpainter.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQCOMMONSTYLE_H */
