@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQDOCKWINDOW_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QDockWindow class
-// For Qt3, no changes are needed
-
 #include <ntqdockwindow.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QDockWindow class
-// For Qt4, some changes are needed
-
-#include <Qt/q3dockwindow.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQDOCKWINDOW_H */
