@@ -23,21 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQJPUNICODE_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QJpUnicodeConv class
-// For Qt3, no changes are needed
-
 #include <ntqjpunicode.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QJpUnicodeConv class
-// For Qt4, this class was removed!
-
-#endif // USE_QT4
-
 #endif /* TQT_TQJPUNICODE_H */
