@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQSQLFIELD_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QSqlField class
-// For Qt3, no changes are needed
-
 #include <ntqsqlfield.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QSqlField class
-// For Qt4, some changes are needed
-
-#include <Qt/q3sqlfieldinfo.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQSQLFIELD_H */
