@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQTHREADSTORAGE_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QThreadStorage class
-// For Qt3, no changes are needed
-
 #include <ntqthreadstorage.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QThreadStorage class
-// For Qt4, some changes are needed
-
-#include <Qt/ntqthreadstorage.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQTHREADSTORAGE_H */
