@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQURLOPERATOR_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QUrlOperator class
-// For Qt3, no changes are needed
-
 #include <ntqurloperator.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QUrlOperator class
-// For Qt4, some changes are needed
-
-#include <Qt/q3urloperator.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQURLOPERATOR_H */
