@@ -207,7 +207,7 @@ static char qtSignalString[200];
 		if (strcmp(javaTypeSignature, javaToQtTypeSignatureMap[index][0]) == 0) {
 			(void) sprintf(qtSignalString, "%s%s", signalName, javaToQtTypeSignatureMap[index][1]);
 
-			if (smeta == 0 || smeta->findSignal(((const char *) qtSignalString + 1), TRUE) >= 0) {
+			if (smeta == 0 || smeta->findSignal(((const char *) qtSignalString + 1), true) >= 0) {
 				return qtSignalString;
 			}
 		}
