@@ -27,7 +27,7 @@
   */
 
 class encodingSelector : public encodingSelectorS {
-  Q_OBJECT
+  TQ_OBJECT
   
                  
   public: 
