@@ -143,35 +143,35 @@ TemplatesTreeView::TemplatesTreeView(TDEMainWindow *parent, const char *name )
 
   m_fileMenu = new TDEPopupMenu(this);
 
-  m_openId = m_fileMenu->insertItem(i18n("Open"), this ,TQT_SLOT(slotInsert()));
-  m_fileMenu->insertItem(SmallIcon("document-open"), i18n("&Open"), this ,TQT_SLOT(slotOpen()));
-  m_fileMenu->insertItem(SmallIcon("mail-send"), i18n("Send in E&mail..."), this, TQT_SLOT(slotSendInMail()));
-  m_fileMenu->insertItem(SmallIcon("network"), i18n("&Upload Template..."), this, TQT_SLOT(slotUploadTemplate()));
-  m_insertFileInProject = m_fileMenu->insertItem(i18n("&Insert in Project..."), this, TQT_SLOT(slotInsertInProject()));
-  m_menuClose = m_fileMenu->insertItem(SmallIcon("window-close"), i18n("Clos&e"), this, TQT_SLOT(slotClose()));
+  m_openId = m_fileMenu->insertItem(i18n("Open"), this ,TQ_SLOT(slotInsert()));
+  m_fileMenu->insertItem(SmallIcon("document-open"), i18n("&Open"), this ,TQ_SLOT(slotOpen()));
+  m_fileMenu->insertItem(SmallIcon("mail-send"), i18n("Send in E&mail..."), this, TQ_SLOT(slotSendInMail()));
+  m_fileMenu->insertItem(SmallIcon("network"), i18n("&Upload Template..."), this, TQ_SLOT(slotUploadTemplate()));
+  m_insertFileInProject = m_fileMenu->insertItem(i18n("&Insert in Project..."), this, TQ_SLOT(slotInsertInProject()));
+  m_menuClose = m_fileMenu->insertItem(SmallIcon("window-close"), i18n("Clos&e"), this, TQ_SLOT(slotClose()));
   m_fileMenu->insertSeparator();
-  m_fileMenu->insertItem(SmallIcon("edit-copy"), i18n("&Copy"), this, TQT_SLOT(slotCopy()));
-  m_fileMenu->insertItem(SmallIcon("edit-delete"), i18n("&Delete"), this, TQT_SLOT(slotDelete()));
+  m_fileMenu->insertItem(SmallIcon("edit-copy"), i18n("&Copy"), this, TQ_SLOT(slotCopy()));
+  m_fileMenu->insertItem(SmallIcon("edit-delete"), i18n("&Delete"), this, TQ_SLOT(slotDelete()));
   m_fileMenu->insertSeparator();
-  m_fileMenu->insertItem(SmallIcon("application-vnd.tde.info"), i18n("&Properties"), this, TQT_SLOT(slotProperties()));
+  m_fileMenu->insertItem(SmallIcon("application-vnd.tde.info"), i18n("&Properties"), this, TQ_SLOT(slotProperties()));
 
   m_folderMenu = new TDEPopupMenu(this);
 
-  m_folderMenu->insertItem(SmallIcon("folder-new"), i18n("&New Folder..."), this, TQT_SLOT(slotNewDir()));
-  m_folderMenu->insertItem(SmallIcon("mail-send"), i18n("Send in E&mail..."), this, TQT_SLOT(slotSendInMail()));
-  m_folderMenu->insertItem(SmallIcon("network"), i18n("&Upload Template..."), this, TQT_SLOT(slotUploadTemplate()));
-  m_downloadMenuId = m_folderMenu->insertItem(SmallIcon("network"), i18n("&Download Template..."), this, TQT_SIGNAL(downloadTemplate()));
-  m_insertFolderInProject = m_folderMenu->insertItem(i18n("&Insert in Project..."), this, TQT_SLOT(slotInsertDirInProject()));
+  m_folderMenu->insertItem(SmallIcon("folder-new"), i18n("&New Folder..."), this, TQ_SLOT(slotNewDir()));
+  m_folderMenu->insertItem(SmallIcon("mail-send"), i18n("Send in E&mail..."), this, TQ_SLOT(slotSendInMail()));
+  m_folderMenu->insertItem(SmallIcon("network"), i18n("&Upload Template..."), this, TQ_SLOT(slotUploadTemplate()));
+  m_downloadMenuId = m_folderMenu->insertItem(SmallIcon("network"), i18n("&Download Template..."), this, TQ_SIGNAL(downloadTemplate()));
+  m_insertFolderInProject = m_folderMenu->insertItem(i18n("&Insert in Project..."), this, TQ_SLOT(slotInsertDirInProject()));
   m_folderMenu->insertSeparator();
-  m_folderMenu->insertItem(SmallIcon("edit-copy"), i18n("&Copy"), this, TQT_SLOT(slotCopy()));
-  m_menuPasteFolder = m_folderMenu->insertItem(SmallIcon("edit-paste"), i18n("&Paste"), this, TQT_SLOT(slotPaste()));
-  m_deleteMenuId = m_folderMenu->insertItem(SmallIcon("edit-delete"), i18n("&Delete"), this, TQT_SLOT(slotDelete()));
+  m_folderMenu->insertItem(SmallIcon("edit-copy"), i18n("&Copy"), this, TQ_SLOT(slotCopy()));
+  m_menuPasteFolder = m_folderMenu->insertItem(SmallIcon("edit-paste"), i18n("&Paste"), this, TQ_SLOT(slotPaste()));
+  m_deleteMenuId = m_folderMenu->insertItem(SmallIcon("edit-delete"), i18n("&Delete"), this, TQ_SLOT(slotDelete()));
   m_folderMenu->insertSeparator();
-  m_folderMenu->insertItem(SmallIcon("application-vnd.tde.info"), i18n("&Properties"), this, TQT_SLOT(slotProperties()));
-  m_reloadMenuId = m_folderMenu->insertItem(SmallIcon("document-revert"), i18n("&Reload"), this, TQT_SLOT(slotReload()));
+  m_folderMenu->insertItem(SmallIcon("application-vnd.tde.info"), i18n("&Properties"), this, TQ_SLOT(slotProperties()));
+  m_reloadMenuId = m_folderMenu->insertItem(SmallIcon("document-revert"), i18n("&Reload"), this, TQ_SLOT(slotReload()));
 
   m_emptyAreaMenu = new TDEPopupMenu(this);
-  m_emptyAreaMenu->insertItem(SmallIcon("network"), i18n("&Download Template..."), this, TQT_SIGNAL(downloadTemplate()));
+  m_emptyAreaMenu->insertItem(SmallIcon("network"), i18n("&Download Template..."), this, TQ_SIGNAL(downloadTemplate()));
 
   addColumn(i18n("Templates"), -1);
   addColumn(i18n("Group"), -1);
@@ -182,11 +182,11 @@ TemplatesTreeView::TemplatesTreeView(TDEMainWindow *parent, const char *name )
   localURL.setPath(locateLocal("data", resourceDir + "templates/"));
   newBranch(localURL);
 
-  connect(this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-          this, TQT_SLOT(slotMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
+  connect(this, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+          this, TQ_SLOT(slotMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
 
-  connect(this, TQT_SIGNAL(open(TQListViewItem *)),
-          this,  TQT_SLOT(slotSelectFile(TQListViewItem *)));
+  connect(this, TQ_SIGNAL(open(TQListViewItem *)),
+          this,  TQ_SLOT(slotSelectFile(TQListViewItem *)));
 
   setAcceptDrops(true);
   setSelectionMode(TQListView::Single);
@@ -629,7 +629,7 @@ void TemplatesTreeView::slotProperties()
    }
 
    topLayout->addWidget( m_quantaProperties );
-   connect( propDlg, TQT_SIGNAL( applied() ), this , TQT_SLOT( slotPropertiesApplied()) );
+   connect( propDlg, TQ_SIGNAL( applied() ), this , TQ_SLOT( slotPropertiesApplied()) );
 
   TQString name = url.path() + TMPL;
   TDEConfig config(name);
@@ -862,7 +862,7 @@ void TemplatesTreeView::slotPaste()
     if ( ! currentKFileTreeViewItem()->isDir() )
       url.setFileName("");   // don't paste on files but in dirs
     TDEIO::Job *job = TDEIO::copy( list, url);
-    connect( job, TQT_SIGNAL( result( TDEIO::Job *) ), this , TQT_SLOT( slotJobFinished( TDEIO::Job *) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job *) ), this , TQ_SLOT( slotJobFinished( TDEIO::Job *) ) );
   }
 }
 
@@ -880,11 +880,11 @@ void TemplatesTreeView::slotDelete()
     if ( KMessageBox::warningContinueCancel(this, msg, TQString(), KStdGuiItem::del()) == KMessageBox::Continue )
     {
       TDEIO::Job *job = TDEIO::del(url);
-      connect( job, TQT_SIGNAL( result( TDEIO::Job *) ), this , TQT_SLOT( slotJobFinished( TDEIO::Job *) ) );
+      connect( job, TQ_SIGNAL( result( TDEIO::Job *) ), this , TQ_SLOT( slotJobFinished( TDEIO::Job *) ) );
       url.setFileName(url.fileName()+ TMPL);
       if ( TQFileInfo(url.path()).exists() ) {
         TDEIO::Job *job2 = TDEIO::del(url);
-        connect( job2, TQT_SIGNAL( result( TDEIO::Job *) ), this , TQT_SLOT( slotJobFinished( TDEIO::Job *) ) );
+        connect( job2, TQ_SIGNAL( result( TDEIO::Job *) ), this , TQ_SLOT( slotJobFinished( TDEIO::Job *) ) );
       };
     }
   }
