@@ -339,7 +339,7 @@ class KABC_EXPORT AddressBook : public TQObject
     /**
       @deprecated There is no need to call this function anymore.
      */
-    void cleanUp() KDE_DEPRECATED;
+    void cleanUp() TDE_DEPRECATED;
 
     /**
       Used for debug output. This function prints out the list
