@@ -104,22 +104,22 @@ void AddressLineEdit::init()
         ldapSearchDeleter.setObject( s_LDAPSearch, new LdapSearch );
         ldapTextDeleter.setObject( s_LDAPText, new TQString );
       }
-      connect( s_LDAPTimer, TQT_SIGNAL( timeout()), TQT_SLOT( slotStartLDAPLookup()));
-      connect( s_LDAPSearch, TQT_SIGNAL( searchData( const TQStringList& )),
-        TQT_SLOT( slotLDAPSearchData( const TQStringList& )));
+      connect( s_LDAPTimer, TQ_SIGNAL( timeout()), TQ_SLOT( slotStartLDAPLookup()));
+      connect( s_LDAPSearch, TQ_SIGNAL( searchData( const TQStringList& )),
+        TQ_SLOT( slotLDAPSearchData( const TQStringList& )));
   }
 
   if ( m_useCompletion && !m_completionInitialized )
   {
       setCompletionObject( s_completion, false ); // we handle it ourself
-      connect( this, TQT_SIGNAL( completion(const TQString&)),
-               this, TQT_SLOT(slotCompletion() ));
+      connect( this, TQ_SIGNAL( completion(const TQString&)),
+               this, TQ_SLOT(slotCompletion() ));
       
       TDECompletionBox *box = completionBox();
-      connect( box, TQT_SIGNAL( highlighted( const TQString& )),
-               this, TQT_SLOT( slotPopupCompletion( const TQString& ) ));
-      connect( box, TQT_SIGNAL( userCancelled( const TQString& )),
-               TQT_SLOT( userCancelled( const TQString& )));
+      connect( box, TQ_SIGNAL( highlighted( const TQString& )),
+               this, TQ_SLOT( slotPopupCompletion( const TQString& ) ));
+      connect( box, TQ_SIGNAL( userCancelled( const TQString& )),
+               TQ_SLOT( userCancelled( const TQString& )));
 
       m_completionInitialized = true; // don't connect muliple times. That's
                                       // ugly, tho, better have completionBox()
@@ -190,7 +190,7 @@ void AddressLineEdit::keyPressEvent(TQKeyEvent *e)
 
 void AddressLineEdit::mouseReleaseEvent( TQMouseEvent * e )
 {
-   if (m_useCompletion && (e->button() == Qt::MidButton))
+   if (m_useCompletion && (e->button() == TQt::MidButton))
    {
       m_smartPaste = true;
       KLineEdit::mouseReleaseEvent(e);
