@@ -805,7 +805,7 @@ GraphNode* GraphExporter::node(TraceFunction* f)
 
 GraphEdge* GraphExporter::edge(TraceFunction* f1, TraceFunction* f2)
 {
-  GraphEdgeMap::Iterator it = _edgeMap.find(tqMakePair(f1, f2));
+  GraphEdgeMap::Iterator it = _edgeMap.find(qMakePair(f1, f2));
   if (it == _edgeMap.end()) return 0;
 
   return &(*it);
@@ -1095,7 +1095,7 @@ void CanvasNode::drawShape(TQPainter& p)
   r.setRect(r.x()+2, r.y()+2, r.width()-4, r.height()-4);
 
   if (StoredDrawParams::selected() && _view->hasFocus()) {
-    _view->style().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, r,
+    _view->style().drawPrimitive( TQStyle::PE_FocusRect, &p, r,
 				  _view->colorGroup());
   }
 
@@ -1388,15 +1388,15 @@ CallGraphView::CallGraphView(TraceItemView* parentView,
   _completeView->raise();
   _completeView->hide();
 
-  setFocusPolicy(TQ_StrongFocus);
+  setFocusPolicy(TQWidget::StrongFocus);
   setBackgroundMode(TQt::NoBackground);
 
-  connect(this, TQT_SIGNAL(contentsMoving(int,int)),
-          this, TQT_SLOT(contentsMovingSlot(int,int)));
-  connect(_completeView, TQT_SIGNAL(zoomRectMoved(int,int)),
-          this, TQT_SLOT(zoomRectMoved(int,int)));
-  connect(_completeView, TQT_SIGNAL(zoomRectMoveFinished()),
-          this, TQT_SLOT(zoomRectMoveFinished()));
+  connect(this, TQ_SIGNAL(contentsMoving(int,int)),
+          this, TQ_SLOT(contentsMovingSlot(int,int)));
+  connect(_completeView, TQ_SIGNAL(zoomRectMoved(int,int)),
+          this, TQ_SLOT(zoomRectMoved(int,int)));
+  connect(_completeView, TQ_SIGNAL(zoomRectMoveFinished()),
+          this, TQ_SLOT(zoomRectMoveFinished()));
 
   TQWhatsThis::add( this, whatsThis() );
 
@@ -1405,8 +1405,8 @@ CallGraphView::CallGraphView(TraceItemView* parentView,
 
   _renderProcess = 0;
   _prevSelectedNode = 0;
-  connect(&_renderTimer, TQT_SIGNAL(timeout()),
-          this, TQT_SLOT(showRenderWarning()));
+  connect(&_renderTimer, TQ_SIGNAL(timeout()),
+          this, TQ_SLOT(showRenderWarning()));
 }
 
 CallGraphView::~CallGraphView()
@@ -1846,7 +1846,7 @@ void CallGraphView::refresh()
   _exporter.reset(_data, _activeItem, _costType, _groupType);
   _exporter.writeDot();
 
-  _renderProcess = new TQProcess(TQT_TQOBJECT(this));
+  _renderProcess = new TQProcess(this);
   if (_layout == GraphOptions::Circular)
     _renderProcess->addArgument( "twopi" );
   else
@@ -1854,10 +1854,10 @@ void CallGraphView::refresh()
   _renderProcess->addArgument(_exporter.filename());
   _renderProcess->addArgument( "-Tplain" );
 
-  connect( _renderProcess, TQT_SIGNAL(readyReadStdout()),
-	   this, TQT_SLOT(readDotOutput()) );
-  connect( _renderProcess, TQT_SIGNAL(processExited()),
-	   this, TQT_SLOT(dotExited()) );
+  connect( _renderProcess, TQ_SIGNAL(readyReadStdout()),
+	   this, TQ_SLOT(readDotOutput()) );
+  connect( _renderProcess, TQ_SIGNAL(processExited()),
+	   this, TQ_SLOT(dotExited()) );
 
   if (1) kdDebug() << "Running '" 
 		   << _renderProcess->arguments().join(" ")
