@@ -17,7 +17,7 @@
 
 class DumpSelection : public DumpSelectionBase, public TraceItemView
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
