@@ -35,7 +35,7 @@
 #include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <tdeaboutdata.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdetempfile.h>
 
 static TDECmdLineOptions options[] =
@@ -938,7 +938,7 @@ void KonfUpdate::resetOptions()
 }
 
 
-extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
+extern "C" TDE_EXPORT int kdemain(int argc, char **argv)
 {
    TDEAboutData aboutData("tdeconf_update", I18N_NOOP("KConf Update"),
                         "1.0.2",
