@@ -48,7 +48,7 @@
 
 #include "kstandarddirs.h"
 #include "tdeconfig.h"
-#include "kinstance.h"
+#include "tdeinstance.h"
 #include "kshell.h"
 #include "ksimpleconfig.h"
 #include "kuser.h"
@@ -441,7 +441,7 @@ TQString TDEStandardDirs::findResourceDir( const char *type,
 
 #ifndef NDEBUG
     if(false && strcmp(type, "locale"))
-      fprintf(stderr, "KStdDirs::findResDir(): can't find \"%s\" in type \"%s\".\n", filename.ascii(), type);
+      fprintf(stderr, "TDEStandardDirs::findResourceDir(): can't find \"%s\" in type \"%s\".\n", filename.ascii(), type);
 #endif
 
     return TQString::null;
