@@ -245,7 +245,7 @@ TQDateTime KTimezone::convert(const KTimezone *newZone, const TQDateTime &dateTi
     ::setenv("TZ", newZone->name().utf8(), 1);
     tzset();
     TQDateTime remoteTime;
-    remoteTime.setTime_t(utc, Qt::LocalTime);
+    remoteTime.setTime_t(utc, TQt::LocalTime);
 
     // Now restore things
     if (!originalZone)
@@ -280,7 +280,7 @@ TQString KTimezone::name() const
     return m_name;
 }
 
-int KTimezone::offset(Qt::TimeSpec basisSpec) const
+int KTimezone::offset(TQt::TimeSpec basisSpec) const
 {
     char *originalZone = ::getenv("TZ");
 
@@ -290,7 +290,7 @@ int KTimezone::offset(Qt::TimeSpec basisSpec) const
     // Set the timezone and find out what time it is there compared to the basis.
     ::setenv("TZ", m_name.utf8(), 1);
     tzset();
-    TQDateTime remoteTime = TQDateTime::currentDateTime(Qt::LocalTime);
+    TQDateTime remoteTime = TQDateTime::currentDateTime(TQt::LocalTime);
     int offset = remoteTime.secsTo(basisTime);
 
     // Now restore things
@@ -605,7 +605,7 @@ const KTimezone *KTimezones::local()
         for (ZoneMap::Iterator it = m_zones->begin(); it != m_zones->end(); ++it)
         {
             KTimezone *zone = it.data();
-            int candidateOffset = QABS(zone->offset(Qt::LocalTime));
+            int candidateOffset = TQABS(zone->offset(TQt::LocalTime));
             if (zone->parse(matcher) && matcher.test() && (candidateOffset < bestOffset))
             {
                 // kdError() << "local=" << zone->name() << endl;
