@@ -39,7 +39,7 @@
 #include <tdenetworkconnections.h>
 #endif
 #include <kstandarddirs.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include "kstaticdeleter.h"
 
 #include <tqfont.h>
