@@ -35,7 +35,7 @@
 #include "tdeglobal.h"
 #include "kstandarddirs.h"
 #include "ksimpleconfig.h"
-#include "kinstance.h"
+#include "tdeinstance.h"
 #include "tdeconfig.h"
 #include "kdebug.h"
 #include "kcalendarsystem.h"
