@@ -88,25 +88,25 @@ int main(int argc, char *argv[])
   KURL::List lst;
 
   KURL emptyURL;
-  check( "KURL::isMalformed()", emptyURL.isMalformed() ? "TRUE":"FALSE", "TRUE");
-  check( "KURL::isValid()", emptyURL.isValid() ? "TRUE":"FALSE", "FALSE");
-  check( "KURL::isEmpty()", emptyURL.isEmpty() ? "TRUE":"FALSE", "TRUE");
+  check( "KURL::isMalformed()", emptyURL.isMalformed() ? "true":"false", "true");
+  check( "KURL::isValid()", emptyURL.isValid() ? "true":"false", "false");
+  check( "KURL::isEmpty()", emptyURL.isEmpty() ? "true":"false", "true");
   check( "prettyURL()", emptyURL.prettyURL(), "");
-  check( "isLocalFile()", emptyURL.isLocalFile()?"TRUE":"FALSE", "FALSE" );
+  check( "isLocalFile()", emptyURL.isLocalFile()?"true":"false", "false" );
 
   emptyURL = "";
-  check( "KURL::isMalformed()", emptyURL.isMalformed() ? "TRUE":"FALSE", "TRUE");
-  check( "KURL::isValid()", emptyURL.isValid() ? "TRUE":"FALSE", "FALSE");
-  check( "KURL::isEmpty()", emptyURL.isEmpty() ? "TRUE":"FALSE", "TRUE");
+  check( "KURL::isMalformed()", emptyURL.isMalformed() ? "true":"false", "true");
+  check( "KURL::isValid()", emptyURL.isValid() ? "true":"false", "false");
+  check( "KURL::isEmpty()", emptyURL.isEmpty() ? "true":"false", "true");
 
   KURL fileURL = "file:/";
-  check( "KURL::isEmpty()", fileURL.isEmpty() ? "TRUE":"FALSE", "FALSE");
+  check( "KURL::isEmpty()", fileURL.isEmpty() ? "true":"false", "false");
 
   fileURL = "file:///";
-  check( "KURL::isEmpty()", fileURL.isEmpty() ? "TRUE":"FALSE", "FALSE");
+  check( "KURL::isEmpty()", fileURL.isEmpty() ? "true":"false", "false");
 
   KURL baseURL ("hTTp://www.foo.bar:80" );
-  check( "KURL::isValid()", baseURL.isValid() ? "TRUE":"FALSE", "TRUE");
+  check( "KURL::isValid()", baseURL.isValid() ? "true":"false", "true");
   check( "KURL::protocol()", baseURL.protocol(), "http"); // lowercase
   KURL url1 ( baseURL, "//www1.foo.bar" );
   check( "KURL::host()", url1.host(), "www1.foo.bar");
@@ -184,13 +184,13 @@ int main(int argc, char *argv[])
   check("KURL::upURL()", url1.upURL().url(), "file:///home/dfaure/");
 
   url1 = "gg:www.kde.org";
-  check("KURL::isValid()", url1.isValid()?"TRUE":"FALSE", "TRUE" );
+  check("KURL::isValid()", url1.isValid()?"true":"false", "true" );
 
   url1= "KDE";
-  check("KURL::isValid()", url1.isValid()?"TRUE":"FALSE", "FALSE" );
+  check("KURL::isValid()", url1.isValid()?"true":"false", "false" );
 
   url1= "$HOME/.trinity/share/config";
-  check("KURL::isValid()", url1.isValid()?"TRUE":"FALSE", "FALSE" );
+  check("KURL::isValid()", url1.isValid()?"true":"false", "false" );
 
   u1 = "file:/opt/kde2/qt2/doc/html/showimg-main-cpp.html#TQObject::connect";
   url1 = u1;
@@ -1115,9 +1115,9 @@ int main(int argc, char *argv[])
   KURL emptyUserTest1("http://www.foobar.com/");
   KURL emptyUserTest2("http://www.foobar.com/");
   emptyUserTest2.setUser("");
-  check("Empty vs. null fields: user", emptyUserTest1==emptyUserTest2?"TRUE":"FALSE","TRUE");
+  check("Empty vs. null fields: user", emptyUserTest1==emptyUserTest2?"true":"false","true");
   emptyUserTest2.setPass("");
-  check("Empty vs. null fields: password", emptyUserTest1==emptyUserTest2?"TRUE":"FALSE","TRUE");
+  check("Empty vs. null fields: password", emptyUserTest1==emptyUserTest2?"true":"false","true");
 
   printf("\nTest OK !\n");
 }
