@@ -28,7 +28,7 @@
 #include <kbugreport.h>
 #include <tdeconfig.h>
 #include <tdefiledialog.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeio/netaccess.h>
 #include <tdelocale.h>
 #include <tdemessagebox.h>
@@ -506,53 +506,53 @@ void TDEFileReplacePart::initGUI()
     }
 
   // GUI
-  connect(m_view, TQT_SIGNAL(updateGUI()), this, TQT_SLOT(updateGUI()));
+  connect(m_view, TQ_SIGNAL(updateGUI()), this, TQ_SLOT(updateGUI()));
 
   // File
-  (void)new TDEAction(i18n("Customize Search/Replace Session..."), "projectopen", TDEShortcut(CTRL + Key_F), TQT_TQOBJECT(this), TQT_SLOT(slotSetNewParameters()), actionCollection(), "new_project");
-  (void)new TDEAction(i18n("&Search"), "filesearch", 0, TQT_TQOBJECT(this), TQT_SLOT(slotSearchingOperation()), actionCollection(), "search");
-  (void)new TDEAction(i18n("S&imulate"), "filesimulate", 0, TQT_TQOBJECT(this), TQT_SLOT(slotSimulatingOperation()), actionCollection(), "file_simulate");
-  (void)new TDEAction(i18n("&Replace"),  "filereplace", 0, TQT_TQOBJECT(this), TQT_SLOT(slotReplacingOperation()), actionCollection(), "replace");
-  (void)new TDEAction(i18n("Sto&p"), "process-stop", 0, TQT_TQOBJECT(this), TQT_SLOT(slotStop()), actionCollection(), "stop");
-  (void)new TDEAction(i18n("Cre&ate Report File..."), "document-save-as", 0, TQT_TQOBJECT(this), TQT_SLOT(slotCreateReport()), actionCollection(), "results_create_report");
-  (void)new TDEAction(i18n("&Save Results List to File..."), "document-save-as", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultSave()), actionCollection(), "results_save");
-  (void)new TDEAction(i18n("&Load Results List From File..."), "unsortedList", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultLoad()), actionCollection(), "results_load");
+  (void)new TDEAction(i18n("Customize Search/Replace Session..."), "projectopen", TDEShortcut(CTRL + Key_F), this, TQ_SLOT(slotSetNewParameters()), actionCollection(), "new_project");
+  (void)new TDEAction(i18n("&Search"), "filesearch", 0, this, TQ_SLOT(slotSearchingOperation()), actionCollection(), "search");
+  (void)new TDEAction(i18n("S&imulate"), "filesimulate", 0, this, TQ_SLOT(slotSimulatingOperation()), actionCollection(), "file_simulate");
+  (void)new TDEAction(i18n("&Replace"),  "filereplace", 0, this, TQ_SLOT(slotReplacingOperation()), actionCollection(), "replace");
+  (void)new TDEAction(i18n("Sto&p"), "process-stop", 0, this, TQ_SLOT(slotStop()), actionCollection(), "stop");
+  (void)new TDEAction(i18n("Cre&ate Report File..."), "document-save-as", 0, this, TQ_SLOT(slotCreateReport()), actionCollection(), "results_create_report");
+  (void)new TDEAction(i18n("&Save Results List to File..."), "document-save-as", 0, m_view, TQ_SLOT(slotResultSave()), actionCollection(), "results_save");
+  (void)new TDEAction(i18n("&Load Results List From File..."), "unsortedList", 0, m_view, TQ_SLOT(slotResultLoad()), actionCollection(), "results_load");
 
   // Strings
-  (void)new TDEAction(i18n("&Add String..."), "editadd", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotStringsAdd()), actionCollection(), "strings_add");
-  (void)new TDEAction(i18n("&Delete String"), "editremove", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotStringsDeleteItem()), actionCollection(), "strings_del");
-  (void)new TDEAction(i18n("&Empty Strings List"), "edit-delete", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotStringsEmpty()), actionCollection(), "strings_empty");
-  (void)new TDEAction(i18n("&Save Strings List to File..."), "document-save-as", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotStringsSave()), actionCollection(), "strings_save");
-  (void)new TDEAction(i18n("&Load Strings List From File..."), "unsortedList", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotStringsLoad()), actionCollection(), "strings_load");
-  (void)new TDEAction(i18n("&Invert Current String (search <--> replace)"), "invert", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotStringsInvertCur()), actionCollection(), "strings_invert");
-  (void)new TDEAction(i18n("&Invert All Strings (search <--> replace)"), "invert", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotStringsInvertAll()), actionCollection(), "strings_invert_all");
+  (void)new TDEAction(i18n("&Add String..."), "editadd", 0, m_view, TQ_SLOT(slotStringsAdd()), actionCollection(), "strings_add");
+  (void)new TDEAction(i18n("&Delete String"), "editremove", 0, m_view, TQ_SLOT(slotStringsDeleteItem()), actionCollection(), "strings_del");
+  (void)new TDEAction(i18n("&Empty Strings List"), "edit-delete", 0, m_view, TQ_SLOT(slotStringsEmpty()), actionCollection(), "strings_empty");
+  (void)new TDEAction(i18n("&Save Strings List to File..."), "document-save-as", 0, m_view, TQ_SLOT(slotStringsSave()), actionCollection(), "strings_save");
+  (void)new TDEAction(i18n("&Load Strings List From File..."), "unsortedList", 0, m_view, TQ_SLOT(slotStringsLoad()), actionCollection(), "strings_load");
+  (void)new TDEAction(i18n("&Invert Current String (search <--> replace)"), "invert", 0, m_view, TQ_SLOT(slotStringsInvertCur()), actionCollection(), "strings_invert");
+  (void)new TDEAction(i18n("&Invert All Strings (search <--> replace)"), "invert", 0, m_view, TQ_SLOT(slotStringsInvertAll()), actionCollection(), "strings_invert_all");
 
   // Options
-  (void)new TDEToggleAction(i18n("&Include Sub-Folders"), "recursive_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionRecursive()), actionCollection(), "options_recursive");
-  (void)new TDEToggleAction(i18n("Create &Backup Files"), "backup_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionBackup()), actionCollection(), "options_backup");
-  (void)new TDEToggleAction(i18n("Case &Sensitive"), "casesensitive_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionCaseSensitive()), actionCollection(), "options_case");
-  (void)new TDEToggleAction(i18n("Enable Commands &in Replace String: [$command:option$]"), "command_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionVariables()), actionCollection(), "options_var");
-  (void)new TDEToggleAction(i18n("Enable &Regular Expressions"), "regularexpression_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionRegularExpressions()), actionCollection(), "options_regularexpressions");
-  (void)new TDEAction(i18n("Configure &TDEFileReplace..."), "configure", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionPreferences()), actionCollection(), "configure_tdefilereplace");
+  (void)new TDEToggleAction(i18n("&Include Sub-Folders"), "recursive_option", 0, this, TQ_SLOT(slotOptionRecursive()), actionCollection(), "options_recursive");
+  (void)new TDEToggleAction(i18n("Create &Backup Files"), "backup_option", 0, this, TQ_SLOT(slotOptionBackup()), actionCollection(), "options_backup");
+  (void)new TDEToggleAction(i18n("Case &Sensitive"), "casesensitive_option", 0, this, TQ_SLOT(slotOptionCaseSensitive()), actionCollection(), "options_case");
+  (void)new TDEToggleAction(i18n("Enable Commands &in Replace String: [$command:option$]"), "command_option", 0, this, TQ_SLOT(slotOptionVariables()), actionCollection(), "options_var");
+  (void)new TDEToggleAction(i18n("Enable &Regular Expressions"), "regularexpression_option", 0, this, TQ_SLOT(slotOptionRegularExpressions()), actionCollection(), "options_regularexpressions");
+  (void)new TDEAction(i18n("Configure &TDEFileReplace..."), "configure", 0, this, TQ_SLOT(slotOptionPreferences()), actionCollection(), "configure_tdefilereplace");
 
   // Results
-  (void)new TDEAction(i18n("&Properties"), "informations", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultProperties()), actionCollection(), "results_infos");
-  (void)new TDEAction(i18n("&Open"), "document-open", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultOpen()), actionCollection(), "results_openfile");
-  (void)new TDEAction(i18n("Open &With..."), "document-open", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultOpenWith()), actionCollection(), "results_openfilewith");
+  (void)new TDEAction(i18n("&Properties"), "informations", 0, m_view, TQ_SLOT(slotResultProperties()), actionCollection(), "results_infos");
+  (void)new TDEAction(i18n("&Open"), "document-open", 0, m_view, TQ_SLOT(slotResultOpen()), actionCollection(), "results_openfile");
+  (void)new TDEAction(i18n("Open &With..."), "document-open", 0, m_view, TQ_SLOT(slotResultOpenWith()), actionCollection(), "results_openfilewith");
   if(quantaFound)
   {
-    (void)new TDEAction(i18n("&Edit in Quanta"), "quanta", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultEdit()), actionCollection(), "results_editfile");
+    (void)new TDEAction(i18n("&Edit in Quanta"), "quanta", 0, m_view, TQ_SLOT(slotResultEdit()), actionCollection(), "results_editfile");
   }
-  (void)new TDEAction(i18n("Open Parent &Folder"), "go-up", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultDirOpen()), actionCollection(), "results_opendir");
-  (void)new TDEAction(i18n("Remove &Entry"), "edit-clear", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultRemoveEntry()), actionCollection(), "results_removeentry");
-  (void)new TDEAction(i18n("&Delete"), "edit-delete", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultDelete()), actionCollection(), "results_delete");
-  (void)new TDEAction(i18n("E&xpand Tree"), 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultTreeExpand()), actionCollection(), "results_treeexpand");
-  (void)new TDEAction(i18n("&Reduce Tree"), 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultTreeReduce()), actionCollection(), "results_treereduce");
+  (void)new TDEAction(i18n("Open Parent &Folder"), "go-up", 0, m_view, TQ_SLOT(slotResultDirOpen()), actionCollection(), "results_opendir");
+  (void)new TDEAction(i18n("Remove &Entry"), "edit-clear", 0, m_view, TQ_SLOT(slotResultRemoveEntry()), actionCollection(), "results_removeentry");
+  (void)new TDEAction(i18n("&Delete"), "edit-delete", 0, m_view, TQ_SLOT(slotResultDelete()), actionCollection(), "results_delete");
+  (void)new TDEAction(i18n("E&xpand Tree"), 0, m_view, TQ_SLOT(slotResultTreeExpand()), actionCollection(), "results_treeexpand");
+  (void)new TDEAction(i18n("&Reduce Tree"), 0, m_view, TQ_SLOT(slotResultTreeReduce()), actionCollection(), "results_treereduce");
 
   // Help
-  (void)new TDEAction(i18n("&About TDEFileReplace"), "tdefilereplace", 0, TQT_TQOBJECT(this), TQT_SLOT(showAboutApplication()), actionCollection(), "help_about_tdefilereplace");
-  (void)new TDEAction(i18n("TDEFileReplace &Handbook"), "help", 0, TQT_TQOBJECT(this), TQT_SLOT(appHelpActivated()), actionCollection(), "help_tdefilereplace");
-  (void)new TDEAction(i18n("&Report Bug"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(reportBug()), actionCollection(), "report_bug");
+  (void)new TDEAction(i18n("&About TDEFileReplace"), "tdefilereplace", 0, this, TQ_SLOT(showAboutApplication()), actionCollection(), "help_about_tdefilereplace");
+  (void)new TDEAction(i18n("TDEFileReplace &Handbook"), "help", 0, this, TQ_SLOT(appHelpActivated()), actionCollection(), "help_tdefilereplace");
+  (void)new TDEAction(i18n("&Report Bug"), 0, 0, this, TQ_SLOT(reportBug()), actionCollection(), "report_bug");
 }
 
 void TDEFileReplacePart::initView()
