@@ -956,8 +956,8 @@ void TDEHTMLPartBrowserHostExtension::virtual_hook( int id, void *data )
 
 
 // defined in tdehtml_part.cpp
-extern const int KDE_NO_EXPORT fastZoomSizes[];
-extern const int KDE_NO_EXPORT fastZoomSizeCount;
+extern const int TDE_NO_EXPORT fastZoomSizes[];
+extern const int TDE_NO_EXPORT fastZoomSizeCount;
 
 // BCI: remove in KDE 4
 TDEHTMLZoomFactorAction::TDEHTMLZoomFactorAction( TDEHTMLPart *part, bool direction, const TQString &text, const TQString &icon, const TQObject *receiver, const char *slot, TQObject *parent, const char *name )
