@@ -29,7 +29,7 @@
 #include "misc/loader.h"
 #include "misc/arena.h"
 
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaboutdata.h>
 #include <tdelocale.h>
 
