@@ -94,9 +94,9 @@ KBookmarkMenu::KBookmarkMenu( KBookmarkManager* mgr,
   if (m_actionCollection)
   {
     m_actionCollection->setHighlightingEnabled(true);
-    disconnect( m_actionCollection, TQT_SIGNAL( actionHighlighted( TDEAction * ) ), 0, 0 );
-    connect( m_actionCollection, TQT_SIGNAL( actionHighlighted( TDEAction * ) ),
-             this, TQT_SLOT( slotActionHighlighted( TDEAction * ) ) );
+    disconnect( m_actionCollection, TQ_SIGNAL( actionHighlighted( TDEAction * ) ), 0, 0 );
+    connect( m_actionCollection, TQ_SIGNAL( actionHighlighted( TDEAction * ) ),
+             this, TQ_SLOT( slotActionHighlighted( TDEAction * ) ) );
   }
 
   m_bNSBookmark = m_parentAddress.isNull();
@@ -104,20 +104,20 @@ KBookmarkMenu::KBookmarkMenu( KBookmarkManager* mgr,
   {
     //kdDebug(7043) << "KBookmarkMenu::KBookmarkMenu " << this << " address : " << m_parentAddress << endl;
 
-    connect( _parentMenu, TQT_SIGNAL( aboutToShow() ),
-             TQT_SLOT( slotAboutToShow() ) );
+    connect( _parentMenu, TQ_SIGNAL( aboutToShow() ),
+             TQ_SLOT( slotAboutToShow() ) );
 
     if ( KBookmarkSettings::self()->m_contextmenu )
     {
       (void) _parentMenu->contextMenu();
-      connect( _parentMenu, TQT_SIGNAL( aboutToShowContextMenu(TDEPopupMenu*, int, TQPopupMenu*) ),
-               this, TQT_SLOT( slotAboutToShowContextMenu(TDEPopupMenu*, int, TQPopupMenu*) ));
+      connect( _parentMenu, TQ_SIGNAL( aboutToShowContextMenu(TDEPopupMenu*, int, TQPopupMenu*) ),
+               this, TQ_SLOT( slotAboutToShowContextMenu(TDEPopupMenu*, int, TQPopupMenu*) ));
     }
 
     if ( m_bIsRoot )
     {
-      connect( m_pManager, TQT_SIGNAL( changed(const TQString &, const TQString &) ),
-               TQT_SLOT( slotBookmarksChanged(const TQString &) ) );
+      connect( m_pManager, TQ_SIGNAL( changed(const TQString &, const TQString &) ),
+               TQ_SLOT( slotBookmarksChanged(const TQString &) ) );
     }
   }
 
@@ -254,12 +254,12 @@ void RMB::fillContextMenu( TQPopupMenu* contextMenu, const TQString & address, i
   // TODO rename these, but, message freeze... umm...
 
 //  if (bookmark.isGroup()) {
-    id = contextMenu->insertItem( SmallIcon("bookmark_add"), i18n( "Add Bookmark Here" ), recv, TQT_SLOT(slotRMBActionInsert(int)) );
+    id = contextMenu->insertItem( SmallIcon("bookmark_add"), i18n( "Add Bookmark Here" ), recv, TQ_SLOT(slotRMBActionInsert(int)) );
     contextMenu->setItemParameter( id, val );
 /*  }
   else
   {
-    id = contextMenu->insertItem( SmallIcon("bookmark_add"), i18n( "Add Bookmark Here" ), recv, TQT_SLOT(slotRMBActionInsert(int)) );
+    id = contextMenu->insertItem( SmallIcon("bookmark_add"), i18n( "Add Bookmark Here" ), recv, TQ_SLOT(slotRMBActionInsert(int)) );
     contextMenu->setItemParameter( id, val );
   }*/
 }
@@ -271,24 +271,24 @@ void RMB::fillContextMenu2( TQPopupMenu* contextMenu, const TQString & address,
   int id;
 
   if (bookmark.isGroup()) {
-    id = contextMenu->insertItem( i18n( "Open Folder in Bookmark Editor" ), recv, TQT_SLOT(slotRMBActionEditAt(int)) );
+    id = contextMenu->insertItem( i18n( "Open Folder in Bookmark Editor" ), recv, TQ_SLOT(slotRMBActionEditAt(int)) );
     contextMenu->setItemParameter( id, val );
     contextMenu->insertSeparator();
-    id = contextMenu->insertItem( SmallIcon("edit-delete"), i18n( "Delete Folder" ), recv, TQT_SLOT(slotRMBActionRemove(int)) );
+    id = contextMenu->insertItem( SmallIcon("edit-delete"), i18n( "Delete Folder" ), recv, TQ_SLOT(slotRMBActionRemove(int)) );
     contextMenu->setItemParameter( id, val );
     contextMenu->insertSeparator();
-    id = contextMenu->insertItem( i18n( "Properties" ), recv, TQT_SLOT(slotRMBActionProperties(int)) );
+    id = contextMenu->insertItem( i18n( "Properties" ), recv, TQ_SLOT(slotRMBActionProperties(int)) );
     contextMenu->setItemParameter( id, val );
   }
   else
   {
-    id = contextMenu->insertItem( i18n( "Copy Link Address" ), recv, TQT_SLOT(slotRMBActionCopyLocation(int)) );
+    id = contextMenu->insertItem( i18n( "Copy Link Address" ), recv, TQ_SLOT(slotRMBActionCopyLocation(int)) );
     contextMenu->setItemParameter( id, val );
     contextMenu->insertSeparator();
-    id = contextMenu->insertItem( SmallIcon("edit-delete"), i18n( "Delete Bookmark" ), recv, TQT_SLOT(slotRMBActionRemove(int)) );
+    id = contextMenu->insertItem( SmallIcon("edit-delete"), i18n( "Delete Bookmark" ), recv, TQ_SLOT(slotRMBActionRemove(int)) );
     contextMenu->setItemParameter( id, val );
     contextMenu->insertSeparator();
-    id = contextMenu->insertItem( i18n( "Properties" ), recv, TQT_SLOT(slotRMBActionProperties(int)) );
+    id = contextMenu->insertItem( i18n( "Properties" ), recv, TQ_SLOT(slotRMBActionProperties(int)) );
     contextMenu->setItemParameter( id, val );
   }
 }
@@ -487,7 +487,7 @@ void KBookmarkMenu::addAddBookmarksList()
                                           "bookmarks_list_add",
                                           0,
                                           this,
-                                          TQT_SLOT( slotAddBookmarksList() ),
+                                          TQ_SLOT( slotAddBookmarksList() ),
                                           m_actionCollection, m_bIsRoot ? "add_bookmarks_list" : 0 );
 
   paAddBookmarksList->setToolTip( i18n( "Add a folder of bookmarks for all open tabs." ) );
@@ -507,7 +507,7 @@ void KBookmarkMenu::addAddBookmark()
                                           "bookmark_add",
                                           m_bIsRoot && m_bAddShortcuts ? TDEStdAccel::addBookmark() : TDEShortcut(),
                                           this,
-                                          TQT_SLOT( slotAddBookmark() ),
+                                          TQ_SLOT( slotAddBookmark() ),
                                           m_actionCollection, m_bIsRoot ? "add_bookmark" : 0 );
 
   paAddBookmarks->setToolTip( i18n( "Add a bookmark for the current document" ) );
@@ -521,7 +521,7 @@ void KBookmarkMenu::addEditBookmarks()
   if (!kapp->authorizeTDEAction("bookmarks"))
      return;
 
-  TDEAction * m_paEditBookmarks = KStdAction::editBookmarks( m_pManager, TQT_SLOT( slotEditBookmarks() ),
+  TDEAction * m_paEditBookmarks = KStdAction::editBookmarks( m_pManager, TQ_SLOT( slotEditBookmarks() ),
                                                              m_actionCollection, "edit_bookmarks" );
   m_paEditBookmarks->plug( m_parentMenu );
   m_paEditBookmarks->setToolTip( i18n( "Edit your bookmark collection in a separate window" ) );
@@ -542,7 +542,7 @@ void KBookmarkMenu::addNewFolder()
                                        "folder-new", //"folder",
                                        0,
                                        this,
-                                       TQT_SLOT( slotNewFolder() ),
+                                       TQ_SLOT( slotNewFolder() ),
                                        m_actionCollection );
 
   paNewFolder->setToolTip( i18n( "Create a new bookmark folder in this menu" ) );
@@ -607,11 +607,11 @@ void KBookmarkMenu::fillBookmarkMenu()
           new KBookmarkMenu( m_pManager, m_pOwner, actionMenu->popupMenu(),
                              m_actionCollection, false,
                              m_bAddBookmark, TQString::null );
-       connect( subMenu, TQT_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ),
-                this, TQT_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ));
+       connect( subMenu, TQ_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ),
+                this, TQ_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ));
        m_lstSubMenus.append(subMenu);
 
-       connect(actionMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), subMenu, TQT_SLOT(slotNSLoad()));
+       connect(actionMenu->popupMenu(), TQ_SIGNAL(aboutToShow()), subMenu, TQ_SLOT(slotNSLoad()));
     }
   }
 
@@ -637,8 +637,8 @@ void KBookmarkMenu::fillBookmarkMenu()
       {
         //kdDebug(7043) << "Creating URL bookmark menu item for " << bm.text() << endl;
         TDEAction * action = new KBookmarkAction( text, bm.icon(), 0, m_actionCollection, 0 );
-        connect(action, TQT_SIGNAL( activated ( TDEAction::ActivationReason, TQt::ButtonState )),
-                this, TQT_SLOT( slotBookmarkSelected( TDEAction::ActivationReason, TQt::ButtonState ) ));
+        connect(action, TQ_SIGNAL( activated ( TDEAction::ActivationReason, TQt::ButtonState )),
+                this, TQ_SLOT( slotBookmarkSelected( TDEAction::ActivationReason, TQt::ButtonState ) ));
 
         action->setProperty( "url", bm.url().url() );
         action->setProperty( "address", bm.address() );
@@ -664,10 +664,10 @@ void KBookmarkMenu::fillBookmarkMenu()
                                                   m_bAddBookmark,
                                                   bm.address() );
 
-      connect(subMenu, TQT_SIGNAL( aboutToShowContextMenu( const KBookmark &, TQPopupMenu * ) ),
-                 this, TQT_SIGNAL( aboutToShowContextMenu( const KBookmark &, TQPopupMenu * ) ));
-      connect(subMenu, TQT_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ),
-                this, TQT_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ));
+      connect(subMenu, TQ_SIGNAL( aboutToShowContextMenu( const KBookmark &, TQPopupMenu * ) ),
+                 this, TQ_SIGNAL( aboutToShowContextMenu( const KBookmark &, TQPopupMenu * ) ));
+      connect(subMenu, TQ_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ),
+                this, TQ_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ));
       m_lstSubMenus.append( subMenu );
     }
   }
@@ -756,7 +756,7 @@ void KBookmarkMenu::slotBookmarkSelected( TDEAction::ActivationReason /*reason*/
 
 void KBookmarkMenu::slotBookmarkSelected()
 {
-    slotBookmarkSelected(TDEAction::PopupMenuActivation, Qt::NoButton);
+    slotBookmarkSelected(TDEAction::PopupMenuActivation, TQt::NoButton);
 }
 
 KExtendedBookmarkOwner* KBookmarkMenu::extOwner()
@@ -767,7 +767,7 @@ KExtendedBookmarkOwner* KBookmarkMenu::extOwner()
 void KBookmarkMenu::slotNSLoad()
 {
   // only fill menu once
-  m_parentMenu->disconnect(TQT_SIGNAL(aboutToShow()));
+  m_parentMenu->disconnect(TQ_SIGNAL(aboutToShow()));
 
   // not NSImporter, but kept old name for BC reasons
   KBookmarkMenuNSImporter importer( m_pManager, this, m_actionCollection );
@@ -846,10 +846,10 @@ KBookmarkEditDialog::KBookmarkEditDialog(const TQString& title, const TQString&
   if ( editType == InsertionMode )
   {
     m_folderTree = KBookmarkFolderTree::createTree( m_mgr, m_main, name, m_address );
-    connect( m_folderTree, TQT_SIGNAL( doubleClicked(TQListViewItem*) ),
-             this,         TQT_SLOT( slotDoubleClicked(TQListViewItem*) ) );
+    connect( m_folderTree, TQ_SIGNAL( doubleClicked(TQListViewItem*) ),
+             this,         TQ_SLOT( slotDoubleClicked(TQListViewItem*) ) );
     vbox->addWidget( m_folderTree );
-    connect( this, TQT_SIGNAL( user1Clicked() ), TQT_SLOT( slotUser1() ) );
+    connect( this, TQ_SIGNAL( user1Clicked() ), TQ_SLOT( slotUser1() ) );
   }
 }
 
@@ -1043,12 +1043,12 @@ void KBookmarkMenuNSImporter::openBookmarks( const TQString &location, const TQS
 
 void KBookmarkMenuNSImporter::connectToImporter(const TQObject &importer)
 {
-  connect( &importer, TQT_SIGNAL( newBookmark( const TQString &, const TQCString &, const TQString & ) ),
-           TQT_SLOT( newBookmark( const TQString &, const TQCString &, const TQString & ) ) );
-  connect( &importer, TQT_SIGNAL( newFolder( const TQString &, bool, const TQString & ) ),
-           TQT_SLOT( newFolder( const TQString &, bool, const TQString & ) ) );
-  connect( &importer, TQT_SIGNAL( newSeparator() ), TQT_SLOT( newSeparator() ) );
-  connect( &importer, TQT_SIGNAL( endFolder() ), TQT_SLOT( endFolder() ) );
+  connect( &importer, TQ_SIGNAL( newBookmark( const TQString &, const TQCString &, const TQString & ) ),
+           TQ_SLOT( newBookmark( const TQString &, const TQCString &, const TQString & ) ) );
+  connect( &importer, TQ_SIGNAL( newFolder( const TQString &, bool, const TQString & ) ),
+           TQ_SLOT( newFolder( const TQString &, bool, const TQString & ) ) );
+  connect( &importer, TQ_SIGNAL( newSeparator() ), TQ_SLOT( newSeparator() ) );
+  connect( &importer, TQ_SIGNAL( endFolder() ), TQ_SLOT( endFolder() ) );
 }
 
 void KBookmarkMenuNSImporter::newBookmark( const TQString & text, const TQCString & url, const TQString & )
@@ -1056,8 +1056,8 @@ void KBookmarkMenuNSImporter::newBookmark( const TQString & text, const TQCStrin
   TQString _text = KStringHandler::csqueeze(text);
   _text.replace( '&', "&&" );
   TDEAction * action = new KBookmarkAction(_text, "text-html", 0, 0, "", m_actionCollection, 0);
-  connect(action, TQT_SIGNAL( activated ( TDEAction::ActivationReason, TQt::ButtonState )),
-          m_menu, TQT_SLOT( slotBookmarkSelected( TDEAction::ActivationReason, TQt::ButtonState ) ));
+  connect(action, TQ_SIGNAL( activated ( TDEAction::ActivationReason, TQt::ButtonState )),
+          m_menu, TQ_SLOT( slotBookmarkSelected( TDEAction::ActivationReason, TQt::ButtonState ) ));
   action->setProperty( "url", url );
   action->setToolTip( url );
   action->plug( mstack.top()->m_parentMenu );
@@ -1074,8 +1074,8 @@ void KBookmarkMenuNSImporter::newFolder( const TQString & text, bool, const TQSt
   KBookmarkMenu *subMenu = new KBookmarkMenu( m_pManager, m_menu->m_pOwner, actionMenu->popupMenu(),
                                               m_actionCollection, false,
                                               m_menu->m_bAddBookmark, TQString::null );
-  connect( subMenu, TQT_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ),
-           m_menu, TQT_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ));
+  connect( subMenu, TQ_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ),
+           m_menu, TQ_SIGNAL( openBookmark( const TQString &, TQt::ButtonState ) ));
   mstack.top()->m_lstSubMenus.append( subMenu );
 
   mstack.push(subMenu);
