@@ -62,7 +62,7 @@ public:
     bool setMaskPermissions( unsigned short v );
     TQString getUserName( uid_t uid ) const;
     TQString getGroupName( gid_t gid ) const;
-    bool setAllUsersOrGroups( const TQValueList< QPair<TQString, unsigned short> > &list, acl_tag_t type );
+    bool setAllUsersOrGroups( const TQValueList< TQPair<TQString, unsigned short> > &list, acl_tag_t type );
     bool setNamedUserOrGroupPermissions( const TQString& name, unsigned short permissions, acl_tag_t type );
 
     acl_t m_acl;
@@ -429,7 +429,7 @@ ACLUserPermissionsList KACL::allUserPermissions() const
 }
 
 #ifdef USE_POSIX_ACL
-bool KACL::KACLPrivate::setAllUsersOrGroups( const TQValueList< QPair<TQString, unsigned short> > &list, acl_tag_t type )
+bool KACL::KACLPrivate::setAllUsersOrGroups( const TQValueList< TQPair<TQString, unsigned short> > &list, acl_tag_t type )
 {
     bool allIsWell = true;
     bool atLeastOneUserOrGroup = false;
@@ -456,7 +456,7 @@ bool KACL::KACLPrivate::setAllUsersOrGroups( const TQValueList< QPair<TQString,
 //printACL( newACL, "After cleaning out entries: " );
 
     // now add the entries from the list
-    TQValueList< QPair<TQString, unsigned short> >::const_iterator it = list.constBegin();
+    TQValueList< TQPair<TQString, unsigned short> >::const_iterator it = list.constBegin();
     while ( it != list.constEnd() ) {
         acl_create_entry( &newACL, &entry );
         acl_set_tag_type( entry, type );
