@@ -1,5 +1,3 @@
-// -*- c++ -*-
-// vim: ts=4 sw=4 et
 /*  This file is part of the KDE libraries
     Copyright (C) 2000 David Faure <faure@kde.org>
                   2000 Carsten Pfeiffer <pfeiffer@kde.org>
@@ -141,7 +139,7 @@ PreviewJob::PreviewJob( const KFileItemList &items, int width, int height,
     d->ignoreMaximumSize = false;
 
     // Return to event loop first, determineNextFile() might delete this;
-    connect(&d->startPreviewTimer, TQT_SIGNAL(timeout()), TQT_SLOT(startPreview()) );
+    connect(&d->startPreviewTimer, TQ_SIGNAL(timeout()), TQ_SLOT(startPreview()) );
     d->startPreviewTimer.start(0, true);
 }
 
@@ -452,7 +450,7 @@ void PreviewJob::createThumbnail( TQString pixPath )
     thumbURL.setPath(pixPath);
     TDEIO::TransferJob *job = TDEIO::get(thumbURL, false, false);
     addSubjob(job);
-    connect(job, TQT_SIGNAL(data(TDEIO::Job *, const TQByteArray &)), TQT_SLOT(slotThumbData(TDEIO::Job *, const TQByteArray &)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job *, const TQByteArray &)), TQ_SLOT(slotThumbData(TDEIO::Job *, const TQByteArray &)));
     bool save = d->bSave && d->currentItem.plugin->property("CacheThumbnail").toBool();
     job->addMetaData("mimeType", d->currentItem.item->mimetype());
     job->addMetaData("width", TQString().setNum(save ? d->cacheWidth : d->width));
