@@ -53,7 +53,7 @@
 
 #include <kdebug.h>
 #include <tdelocale.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kmimemagic.h>
 #include <kmimetype.h>
 #include <ksockaddr.h>
