@@ -24,7 +24,7 @@
 
 // #include <iostream.h>
 #include <tdeglobal.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
 #include <kmimemagic.h>
@@ -730,7 +730,7 @@ mimeHeader::magicSetType (bool aAutoDecode)
   TQByteArray body;
   KMimeMagicResult *result;
 
-  KMimeMagic::self ()->setFollowLinks (TRUE); // is it necessary ?
+  KMimeMagic::self ()->setFollowLinks (true); // is it necessary ?
 
   if (aAutoDecode)
     body = bodyDecodedBinary ();
