@@ -30,7 +30,7 @@
 #include <tqfileinfo.h>
 
 #include <klibloader.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kxmlguifactory.h>
