@@ -5,7 +5,7 @@
 
 class Shell : public KParts::MainWindow
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   Shell();
   virtual ~Shell();
