@@ -47,7 +47,7 @@ class PrinterFilter;
  */
 class TDEPRINT_EXPORT KMManager : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 friend class KMVirtualManager;
 friend class KMSpecialManager;
@@ -170,7 +170,7 @@ protected:
 	virtual void checkUpdatePossibleInternal();
 
 protected:
-	QString			m_errormsg;
+	TQString			m_errormsg;
 	KMPrinterList		m_printers, m_fprinters;	// filtered printers
 	bool 			m_hasmanagement;
 	int			m_printeroperationmask;
