@@ -101,14 +101,14 @@ public:
 	bool		m_restore;
 	bool		m_previewonly;
 	WId		m_parentId;
-	QString		m_docfilename;
+	TQString		m_docfilename;
 	TQString m_docdirectory;
 	KPrinterWrapper		*m_wrapper;
 	TQMap<TQString,TQString>	m_options;
-	QString			m_tmpbuffer;
-	QString			m_printername;
-	QString			m_searchname;
-	QString			m_errormsg;
+	TQString			m_tmpbuffer;
+	TQString			m_printername;
+	TQString			m_searchname;
+	TQString			m_errormsg;
 	bool			m_ready;
 	int		m_pagenumber;
 	DrPageSize *m_pagesize;
