@@ -48,7 +48,7 @@ class TQCheckBox;
  */
 class TDEPRINT_EXPORT KMJobViewer : public TDEMainWindow, public KMPrinterPage, public KPReloadObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	KMJobViewer(TQWidget *parent = 0, const char *name = 0);
 	~KMJobViewer();
