@@ -23,7 +23,7 @@
 PluginAction::PluginAction(int ID, const TQString& txt, const TQString& icon, int accel, TQObject *parent, const char *name)
 : TDEAction(txt, icon, accel, parent, name), m_id(ID)
 {
-	connect(this, TQT_SIGNAL(activated()), TQT_SLOT(slotActivated()));
+	connect(this, TQ_SIGNAL(activated()), TQ_SLOT(slotActivated()));
 }
 
 void PluginAction::slotActivated()
