@@ -22,14 +22,14 @@
 #define RESOURCEXMLRPCCONFIG_H
 
 #include <tderesources/configwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class KLineEdit;
 class KURLRequester;
 
 namespace TDEABC {
 
-class KDE_EXPORT ResourceXMLRPCConfig : public KRES::ConfigWidget
+class TDE_EXPORT ResourceXMLRPCConfig : public KRES::ConfigWidget
 { 
   TQ_OBJECT
   
