@@ -114,7 +114,7 @@ int GroupwiseServer::gSoapOpen( struct soap *soap, const char *,
 //    kdDebug() << "Creating KSSLSocket()" << endl;
     m_sock = new KSSLSocket();
     m_sock->setTimeout( KProtocolManager::connectTimeout() );
-    connect( m_sock, TQT_SIGNAL( sslFailure() ), TQT_SLOT( slotSslError() ) );
+    connect( m_sock, TQ_SIGNAL( sslFailure() ), TQ_SLOT( slotSslError() ) );
   } else {
     m_sock = new KExtendedSocket();
   }
