@@ -26,7 +26,7 @@
 // #include "tderesources_groupwareprefs.h"
 /*#include "groupwareresourcejob.h"*/
 #include <kurl.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include <tqvaluelist.h>
 #include <tqstring.h>
@@ -45,7 +45,7 @@ class GroupwareDataAdaptor;
 class GroupwarePrefsBase;
 
 
-class KDE_EXPORT FolderLister : public TQObject
+class TDE_EXPORT FolderLister : public TQObject
 {
     TQ_OBJECT
   
