@@ -32,7 +32,7 @@ class Job;
 
 class PasswordPage : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
