@@ -1195,16 +1195,16 @@ void AASaver::paintEvent(TQPaintEvent* pe)
 // libkscreensaver interface
 extern "C"
 {
-    KDE_EXPORT const char *kss_applicationName = "tdeasciiquarium.kss";
-    KDE_EXPORT const char *kss_description = I18N_NOOP( "TDEAsciiquarium" );
-    KDE_EXPORT const char *kss_version = "0.3.2";
+    TDE_EXPORT const char *kss_applicationName = "tdeasciiquarium.kss";
+    TDE_EXPORT const char *kss_description = I18N_NOOP( "TDEAsciiquarium" );
+    TDE_EXPORT const char *kss_version = "0.3.2";
 
-    KDE_EXPORT KScreenSaver *kss_create( WId id )
+    TDE_EXPORT KScreenSaver *kss_create( WId id )
     {
         return new AASaver( id );
     }
 
-    KDE_EXPORT TQDialog *kss_setup()
+    TDE_EXPORT TQDialog *kss_setup()
     {
         TDEConfigDialog *dialog = TDEConfigDialog::exists("settings");
         if(dialog)
