@@ -114,7 +114,7 @@ class KURL;
  * KComboBox *combo = new KComboBox( true, this, "mywidget" );
  * TDECompletion *comp = combo->completionObject();
  * // Connect to the return pressed signal - optional
- * connect(combo,TQT_SIGNAL(returnPressed(const TQString&)),comp,TQT_SLOT(addItem(const TQString&)));
+ * connect(combo,TQ_SIGNAL(returnPressed(const TQString&)),comp,TQ_SLOT(addItem(const TQString&)));
  *
  * // Provide the to be completed strings. Note that those are separate from the combo's
  * // contents.
@@ -128,7 +128,7 @@ class KURL;
  * KURLCompletion *comp = new KURLCompletion();
  * combo->setCompletionObject( comp );
  * // Connect to the return pressed signal - optional
- * connect(combo,TQT_SIGNAL(returnPressed(const TQString&)),comp,TQT_SLOT(addItem(const TQString&)));
+ * connect(combo,TQ_SIGNAL(returnPressed(const TQString&)),comp,TQ_SLOT(addItem(const TQString&)));
  * \endcode
  *
  * Note that you have to either delete the allocated completion object
@@ -141,7 +141,7 @@ class KURL;
  * // Tell the widget not to handle completion and rotation
  * combo->setHandleSignals( false );
  * // Set your own completion key for manual completions.
- * combo->setKeyBinding( TDECompletionBase::TextCompletion, Qt::End );
+ * combo->setKeyBinding( TDECompletionBase::TextCompletion, TQt::End );
  * // Hide the context (popup) menu
  * combo->setContextMenuEnabled( false );
  * \endcode
@@ -150,7 +150,7 @@ class KURL;
  */
 class TDEUI_EXPORT KComboBox : public TQComboBox, public TDECompletionBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   TQ_PROPERTY( bool autoCompletion READ autoCompletion WRITE setAutoCompletion )
   TQ_PROPERTY( bool contextMenuEnabled READ isContextMenuEnabled WRITE setContextMenuEnabled )
   TQ_PROPERTY( bool urlDropsEnabled READ isURLDropsEnabled WRITE setURLDropsEnabled )
@@ -539,7 +539,7 @@ class KPixmapProvider;
  */
 class TDEUI_EXPORT KHistoryCombo : public KComboBox
 {
-    Q_OBJECT
+    TQ_OBJECT
     TQ_PROPERTY( TQStringList historyItems READ historyItems WRITE setHistoryItems )
 
 public:
@@ -553,8 +553,8 @@ public:
      * use
      *
      * \code
-     * connect( combo, TQT_SIGNAL( activated( const TQString& )),
-     *          combo, TQT_SLOT( addToHistory( const TQString& )));
+     * connect( combo, TQ_SIGNAL( activated( const TQString& )),
+     *          combo, TQ_SLOT( addToHistory( const TQString& )));
      * \endcode
      *
      * Use TQComboBox::setMaxCount() to limit the history.
@@ -798,7 +798,7 @@ private:
 
 class TDEUI_EXPORT KHistoryComboEditor : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     KHistoryComboEditor( const TQStringList& entries, TQWidget *parent = 0L );
