@@ -300,11 +300,11 @@ KDictSpellingHighlighter::KDictSpellingHighlighter( TQTextEdit *textEdit,
     textEdit->viewport()->installEventFilter( this );
 
     d->rehighlightRequest = new TQTimer(this);
-    connect( d->rehighlightRequest, TQT_SIGNAL( timeout() ),
-	     this, TQT_SLOT( slotRehighlight() ));
+    connect( d->rehighlightRequest, TQ_SIGNAL( timeout() ),
+	     this, TQ_SLOT( slotRehighlight() ));
     d->spellTimeout = new TQTimer(this);
-    connect( d->spellTimeout, TQT_SIGNAL( timeout() ),
-	     this, TQT_SLOT( slotKSpellNotResponding() ));
+    connect( d->spellTimeout, TQ_SIGNAL( timeout() ),
+	     this, TQ_SLOT( slotKSpellNotResponding() ));
 
     if ( d->globalConfig ) {
         d->spellKey = spellKey();
@@ -314,8 +314,8 @@ KDictSpellingHighlighter::KDictSpellingHighlighter( TQTextEdit *textEdit,
     }
     else {
         d->mDict = new TQDict<int>(4001);
-        connect( d->mSpellConfig, TQT_SIGNAL( configChanged() ),
-                 this, TQT_SLOT( slotLocalSpellConfigChanged() ) );
+        connect( d->mSpellConfig, TQ_SIGNAL( configChanged() ),
+                 this, TQ_SLOT( slotLocalSpellConfigChanged() ) );
     }
 
     slotDictionaryChanged();
@@ -339,8 +339,8 @@ void KDictSpellingHighlighter::slotSpellReady( KSpell *spell )
     if ( cg.readEntry("KSpell_DoSpellChecking") != "0" )
     {
       if ( d->globalConfig ) {
-          connect( d->sDictionaryMonitor, TQT_SIGNAL( destroyed()),
-                   this, TQT_SLOT( slotDictionaryChanged() ));
+          connect( d->sDictionaryMonitor, TQ_SIGNAL( destroyed()),
+                   this, TQ_SLOT( slotDictionaryChanged() ));
       }
       if ( spell != d->spell )
       {
@@ -352,10 +352,10 @@ void KDictSpellingHighlighter::slotSpellReady( KSpell *spell )
       for ( TQStringList::ConstIterator it = l.begin(); it != l.end(); ++it ) {
           d->spell->addPersonal( *it );
       }
-      connect( spell, TQT_SIGNAL( misspelling( const TQString &, const TQStringList &, unsigned int )),
-	       this, TQT_SLOT( slotMisspelling( const TQString &, const TQStringList &, unsigned int )));
-      connect( spell, TQT_SIGNAL( corrected( const TQString &, const TQString &, unsigned int )),
-               this, TQT_SLOT( slotCorrected( const TQString &, const TQString &, unsigned int )));
+      connect( spell, TQ_SIGNAL( misspelling( const TQString &, const TQStringList &, unsigned int )),
+	       this, TQ_SLOT( slotMisspelling( const TQString &, const TQStringList &, unsigned int )));
+      connect( spell, TQ_SIGNAL( corrected( const TQString &, const TQString &, unsigned int )),
+               this, TQ_SLOT( slotCorrected( const TQString &, const TQString &, unsigned int )));
       d->checksRequested = 0;
       d->checksDone = 0;
       d->completeRehighlightRequired = true;
@@ -514,7 +514,7 @@ void KDictSpellingHighlighter::slotRehighlight()
     }
     if (d->checksDone == d->checksRequested)
 	d->completeRehighlightRequired = false;
-    TQTimer::singleShot( 0, this, TQT_SLOT( slotAutoDetection() ));
+    TQTimer::singleShot( 0, this, TQ_SLOT( slotAutoDetection() ));
 }
 
 void KDictSpellingHighlighter::slotDictionaryChanged()
@@ -526,7 +526,7 @@ void KDictSpellingHighlighter::slotDictionaryChanged()
     d->autoDict.clear();
 
     d->spell = new KSpell( 0, i18n( "Incremental Spellcheck" ), this,
-		TQT_SLOT( slotSpellReady( KSpell * ) ), d->mSpellConfig );
+		TQ_SLOT( slotSpellReady( KSpell * ) ), d->mSpellConfig );
 }
 
 void KDictSpellingHighlighter::slotLocalSpellConfigChanged()
@@ -609,7 +609,7 @@ void KDictSpellingHighlighter::slotKSpellNotResponding()
 
 bool KDictSpellingHighlighter::eventFilter( TQObject *o, TQEvent *e)
 {
-    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(textEdit()) && (e->type() == TQEvent::FocusIn)) {
+    if (o == textEdit() && (e->type() == TQEvent::FocusIn)) {
         if ( d->globalConfig ) {
             TQString skey = spellKey();
             if ( d->spell && d->spellKey != skey ) {
@@ -619,8 +619,8 @@ bool KDictSpellingHighlighter::eventFilter( TQObject *o, TQEvent *e)
         }
     }
 
-    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(textEdit()) && (e->type() == TQEvent::KeyPress)) {
-	TQKeyEvent *k = TQT_TQKEYEVENT(e);
+    if (o == textEdit() && (e->type() == TQEvent::KeyPress)) {
+	TQKeyEvent *k = static_cast<TQKeyEvent*>(e);
 	d->autoReady = true;
 	if (d->rehighlightRequest->isActive()) // try to stay out of the users way
 	    d->rehighlightRequest->changeInterval( 500 );
@@ -657,11 +657,11 @@ bool KDictSpellingHighlighter::eventFilter( TQObject *o, TQEvent *e)
 	if ( k->key() == Key_Space ||
 	     k->key() == Key_Enter ||
 	     k->key() == Key_Return ) {
-	    TQTimer::singleShot( 0, this, TQT_SLOT( slotAutoDetection() ));
+	    TQTimer::singleShot( 0, this, TQ_SLOT( slotAutoDetection() ));
 	}
     }
 
-    else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(textEdit()->viewport()) &&
+    else if ( o == textEdit()->viewport() &&
 	 ( e->type() == TQEvent::MouseButtonPress )) {
 	d->autoReady = true;
 	if ( intraWordEditing() ) {
