@@ -256,13 +256,13 @@ void TDEAction::initPrivate( const TQString& text, const TDEShortcut& cut,
 {
     d->m_cutDefault = cut;
 
-    m_parentCollection = tqt_dynamic_cast<TDEActionCollection *>( parent() );
+    m_parentCollection = dynamic_cast<TDEActionCollection *>( parent() );
     kdDebug(129) << "TDEAction::initPrivate(): this = " << this << " name = \"" << name() << "\" cut = " << cut.toStringInternal() << " m_parentCollection = " << m_parentCollection << endl;
     if ( m_parentCollection )
         m_parentCollection->insert( this );
 
     if ( receiver && slot )
-        connect( this, TQT_SIGNAL( activated() ), receiver, slot );
+        connect( this, TQ_SIGNAL( activated() ), receiver, slot );
 
     if( !cut.isNull() && !qstrcmp( name(), "unnamed" ) )
         kdWarning(129) << "TDEAction::initPrivate(): trying to assign a shortcut (" << cut.toStringInternal() << ") to an unnamed action." << endl;
@@ -462,7 +462,7 @@ bool TDEAction::updateTDEAccelShortcut( TDEAccel* tdeaccel )
       kdDebug(129) << "Inserting " << name() << ", " << d->text() << ", " << d->plainText() << endl;
       b = tdeaccel->insert( name(), d->plainText(), TQString::null,
           d->m_cut,
-          this, TQT_SLOT(slotActivated()),
+          this, TQ_SLOT(slotActivated()),
           isShortcutConfigurable(), isEnabled() );
     }
   }
@@ -478,7 +478,7 @@ void TDEAction::insertTDEAccel( TDEAccel* tdeaccel )
   if ( !tdeaccel->actions().actionPtr( name() ) ) {
     if( updateTDEAccelShortcut( tdeaccel ) ) {
       d->m_tdeaccelList.append( tdeaccel );
-      connect( tdeaccel, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotDestroyed()) );
+      connect( tdeaccel, TQ_SIGNAL(destroyed()), this, TQ_SLOT(slotDestroyed()) );
     }
   }
   else
@@ -496,7 +496,7 @@ void TDEAction::removeTDEAccel( TDEAccel* tdeaccel )
     if( (*itr) == tdeaccel ) {
       tdeaccel->remove( name() );
       accelList.remove( itr );
-      disconnect( tdeaccel, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotDestroyed()) );
+      disconnect( tdeaccel, TQ_SIGNAL(destroyed()), this, TQ_SLOT(slotDestroyed()) );
       break;
     }
   }
@@ -515,11 +515,11 @@ void TDEAction::updateShortcut( int i )
   int id = itemId( i );
 
   TQWidget* w = container( i );
-  if ( ::tqqt_cast<TQPopupMenu *>( w ) ) {
+  if ( ::tqt_cast<TQPopupMenu *>( w ) ) {
     TQPopupMenu* menu = static_cast<TQPopupMenu*>(w);
     updateShortcut( menu, id );
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( w ) )
+  else if ( ::tqt_cast<TQMenuBar *>( w ) )
     static_cast<TQMenuBar*>(w)->setAccel( d->m_cut.keyCodeQt(), id );
 }
 
@@ -616,7 +616,7 @@ void TDEAction::updateToolTip( int i )
 {
   TQWidget *w = container( i );
 
-  if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  if ( ::tqt_cast<TDEToolBar *>( w ) )
     TQToolTip::add( static_cast<TDEToolBar*>(w)->getWidget( itemId( i ) ), d->toolTip() );
 }
 
@@ -649,7 +649,7 @@ int TDEAction::plug( TQWidget *w, int index )
 
   plugShortcut();
 
-  if ( ::tqqt_cast<TQPopupMenu *>( w ) )
+  if ( ::tqt_cast<TQPopupMenu *>( w ) )
   {
     TQPopupMenu* menu = static_cast<TQPopupMenu*>( w );
     int id;
@@ -664,12 +664,12 @@ int TDEAction::plug( TQWidget *w, int index )
         else
           instance = TDEGlobal::instance();
         id = menu->insertItem( d->iconSet( TDEIcon::Small, 0, instance ), d->text(), this,//dsweet
-                                 TQT_SLOT( slotPopupActivated() ), keyQt,
+                                 TQ_SLOT( slotPopupActivated() ), keyQt,
                                  -1, index );
     }
     else
         id = menu->insertItem( d->text(), this,
-                               TQT_SLOT( slotPopupActivated() ),
+                               TQ_SLOT( slotPopupActivated() ),
                                keyQt, -1, index );
 
     // If the shortcut is already in a TDEAccel object, then
@@ -686,14 +686,14 @@ int TDEAction::plug( TQWidget *w, int index )
         menu->TQMenuData::setWhatsThis( id, whatsThisWithIcon() );
 
     addContainer( menu, id );
-    connect( menu, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( menu, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     if ( m_parentCollection )
       m_parentCollection->connectHighlight( menu, this );
 
     return d->m_containers.count() - 1;
   }
-  else if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  else if ( ::tqt_cast<TDEToolBar *>( w ) )
   {
     TDEToolBar *bar = static_cast<TDEToolBar *>( w );
 
@@ -706,8 +706,8 @@ int TDEAction::plug( TQWidget *w, int index )
 
     if ( icon().isEmpty() && !iconSet().pixmap().isNull() ) // old code using TQIconSet directly
     {
-        bar->insertButton( iconSet().pixmap(), id_, TQT_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
-                           TQT_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
+        bar->insertButton( iconSet().pixmap(), id_, TQ_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
+                           TQ_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
                            d->isEnabled(), d->plainText(), index );
     }
     else
@@ -715,8 +715,8 @@ int TDEAction::plug( TQWidget *w, int index )
         TQString icon = d->iconName();
         if ( icon.isEmpty() )
             icon = "unknown";
-        bar->insertButton( icon, id_, TQT_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
-                           TQT_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
+        bar->insertButton( icon, id_, TQ_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
+                           TQ_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
                            d->isEnabled(), d->plainText(), index, instance );
     }
 
@@ -731,7 +731,7 @@ int TDEAction::plug( TQWidget *w, int index )
 
     addContainer( bar, id_ );
 
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     if ( m_parentCollection )
       m_parentCollection->connectHighlight( bar, this );
@@ -749,17 +749,17 @@ void TDEAction::unplug( TQWidget *w )
     return;
   int id = itemId( i );
 
-  if ( ::tqqt_cast<TQPopupMenu *>( w ) )
+  if ( ::tqt_cast<TQPopupMenu *>( w ) )
   {
     TQPopupMenu *menu = static_cast<TQPopupMenu *>( w );
     menu->removeItem( id );
   }
-  else if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  else if ( ::tqt_cast<TDEToolBar *>( w ) )
   {
     TDEToolBar *bar = static_cast<TDEToolBar *>( w );
     bar->removeItemDelayed( id );
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( w ) )
+  else if ( ::tqt_cast<TQMenuBar *>( w ) )
   {
     TQMenuBar *bar = static_cast<TQMenuBar *>( w );
     bar->removeItem( id );
@@ -791,10 +791,10 @@ void TDEAction::plugAccel(TDEAccel *kacc, bool configurable)
     d->m_tdeaccel = kacc;
     d->m_tdeaccel->insert(name(), d->plainText(), TQString::null,
         TDEShortcut(d->m_cut),
-        this, TQT_SLOT(slotActivated()),
+        this, TQ_SLOT(slotActivated()),
         configurable, isEnabled());
-    connect(d->m_tdeaccel, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotDestroyed()));
-    //connect(d->m_tdeaccel, TQT_SIGNAL(keycodeChanged()), this, TQT_SLOT(slotKeycodeChanged()));
+    connect(d->m_tdeaccel, TQ_SIGNAL(destroyed()), this, TQ_SLOT(slotDestroyed()));
+    //connect(d->m_tdeaccel, TQ_SIGNAL(keycodeChanged()), this, TQ_SLOT(slotKeycodeChanged()));
   }
   else
   {
@@ -822,7 +822,7 @@ void TDEAction::plugMainWindowAccel( TQWidget *w )
   while ( !tl->isDialog() && ( n = tl->parentWidget() ) ) // lookup parent and store
     tl = n;
 
-  TDEMainWindow * mw = tqt_dynamic_cast<TDEMainWindow *>(tl); // try to see if it's a tdemainwindow
+  TDEMainWindow * mw = dynamic_cast<TDEMainWindow *>(tl); // try to see if it's a tdemainwindow
   if (mw)
     plugAccel( mw->accel() );
   else
@@ -863,11 +863,11 @@ void TDEAction::updateEnabled( int i )
 {
     TQWidget *w = container( i );
 
-    if ( ::tqqt_cast<TQPopupMenu *>( w ) )
+    if ( ::tqt_cast<TQPopupMenu *>( w ) )
       static_cast<TQPopupMenu*>(w)->setItemEnabled( itemId( i ), d->isEnabled() );
-    else if ( ::tqqt_cast<TQMenuBar *>( w ) )
+    else if ( ::tqt_cast<TQMenuBar *>( w ) )
       static_cast<TQMenuBar*>(w)->setItemEnabled( itemId( i ), d->isEnabled() );
-    else if ( ::tqqt_cast<TDEToolBar *>( w ) )
+    else if ( ::tqt_cast<TDEToolBar *>( w ) )
       static_cast<TDEToolBar*>(w)->setItemEnabled( itemId( i ), d->isEnabled() );
 }
 
@@ -909,18 +909,18 @@ void TDEAction::updateText( int i )
 {
   TQWidget *w = container( i );
 
-  if ( ::tqqt_cast<TQPopupMenu *>( w ) ) {
+  if ( ::tqt_cast<TQPopupMenu *>( w ) ) {
     int id = itemId( i );
     static_cast<TQPopupMenu*>(w)->changeItem( id, d->text() );
     if (!d->m_cut.isNull())
       updateShortcut( static_cast<TQPopupMenu*>(w), id );
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( w ) )
+  else if ( ::tqt_cast<TQMenuBar *>( w ) )
     static_cast<TQMenuBar*>(w)->changeItem( itemId( i ), d->text() );
-  else if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  else if ( ::tqt_cast<TDEToolBar *>( w ) )
   {
     TQWidget *button = static_cast<TDEToolBar *>(w)->getWidget( itemId( i ) );
-    if ( ::tqqt_cast<TDEToolBarButton *>( button ) )
+    if ( ::tqt_cast<TDEToolBarButton *>( button ) )
       static_cast<TDEToolBarButton *>(button)->setText( d->plainText() );
   }
 }
@@ -949,15 +949,15 @@ void TDEAction::updateIcon( int id )
 {
   TQWidget* w = container( id );
 
-  if ( ::tqqt_cast<TQPopupMenu *>( w ) ) {
+  if ( ::tqt_cast<TQPopupMenu *>( w ) ) {
     int itemId_ = itemId( id );
     static_cast<TQPopupMenu*>(w)->changeItem( itemId_, d->iconSet( TDEIcon::Small ), d->text() );
     if (!d->m_cut.isNull())
       updateShortcut( static_cast<TQPopupMenu*>(w), itemId_ );
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( w ) )
+  else if ( ::tqt_cast<TQMenuBar *>( w ) )
     static_cast<TQMenuBar*>(w)->changeItem( itemId( id ), d->iconSet( TDEIcon::Small ), d->text() );
-  else if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  else if ( ::tqt_cast<TDEToolBar *>( w ) )
     static_cast<TDEToolBar *>(w)->setButtonIcon( itemId( id ), d->iconName() );
 }
 
@@ -980,16 +980,16 @@ void TDEAction::updateIconSet( int id )
 {
   TQWidget *w = container( id );
 
-  if ( ::tqqt_cast<TQPopupMenu *>( w ) )
+  if ( ::tqt_cast<TQPopupMenu *>( w ) )
   {
     int itemId_ = itemId( id );
     static_cast<TQPopupMenu*>(w)->changeItem( itemId_, d->iconSet(), d->text() );
     if (!d->m_cut.isNull())
       updateShortcut( static_cast<TQPopupMenu*>(w), itemId_ );
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( w ) )
+  else if ( ::tqt_cast<TQMenuBar *>( w ) )
     static_cast<TQMenuBar*>(w)->changeItem( itemId( id ), d->iconSet(), d->text() );
-  else if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  else if ( ::tqt_cast<TDEToolBar *>( w ) )
   {
     if ( icon().isEmpty() && d->hasIcon() ) // only if there is no named icon ( scales better )
       static_cast<TDEToolBar *>(w)->setButtonIconSet( itemId( id ), d->iconSet() );
@@ -1057,12 +1057,12 @@ TQWidget* TDEAction::container( int index ) const
 
 TDEToolBar* TDEAction::toolBar( int index ) const
 {
-    return tqt_dynamic_cast<TDEToolBar *>( d->m_containers[ index ].m_container );
+    return dynamic_cast<TDEToolBar *>( d->m_containers[ index ].m_container );
 }
 
 TQPopupMenu* TDEAction::popupMenu( int index ) const
 {
-    return tqt_dynamic_cast<TQPopupMenu *>( d->m_containers[ index ].m_container );
+    return dynamic_cast<TQPopupMenu *>( d->m_containers[ index ].m_container );
 }
 
 TQWidget* TDEAction::representative( int index ) const
@@ -1103,17 +1103,17 @@ void TDEAction::addContainer( TQWidget* c, TQWidget* w )
 
 void TDEAction::activate()
 {
-  emit activated( TDEAction::EmulatedActivation, Qt::NoButton );
+  emit activated( TDEAction::EmulatedActivation, TQt::NoButton );
   slotActivated();
 }
 
 void TDEAction::slotActivated()
 {
-  const TQObject *senderObj = TQT_TQOBJECT_CONST(sender());
+  const TQObject *senderObj = sender();
   if ( senderObj )
   {
-    if ( ::tqqt_cast<TDEAccelPrivate *>( senderObj ) )
-        emit activated( TDEAction::AccelActivation, Qt::NoButton );
+    if ( ::tqt_cast<TDEAccelPrivate *>( senderObj ) )
+        emit activated( TDEAction::AccelActivation, TQt::NoButton );
   }
   emit activated();
 }
@@ -1124,16 +1124,16 @@ void TDEAction::slotActivated()
 // only called by QPopupMenus, we plugged us in.
 void TDEAction::slotPopupActivated()
 {
-  if( ::tqqt_cast<TQSignal *>(sender()))
+  if( ::tqt_cast<TQSignal *>(sender()))
   {
-    int id = tqt_dynamic_cast<const TQSignal *>(sender())->value().toInt();
+    int id = dynamic_cast<const TQSignal *>(sender())->value().toInt();
     int pos = findContainer(id);
     if(pos != -1)
     {
-      TQPopupMenu* qpm = tqt_dynamic_cast<TQPopupMenu *>( container(pos) );
+      TQPopupMenu* qpm = dynamic_cast<TQPopupMenu *>( container(pos) );
       if(qpm)
       {
-        TDEPopupMenu* kpm = tqt_dynamic_cast<TDEPopupMenu *>( qpm );
+        TDEPopupMenu* kpm = dynamic_cast<TDEPopupMenu *>( qpm );
         TQt::ButtonState state;
         if ( kpm ) // TDEPopupMenu? Nice, it stores the state.
             state = kpm->state();
@@ -1149,7 +1149,7 @@ void TDEAction::slotPopupActivated()
   }
 
   kdWarning(129)<<"Don't connect TDEAction::slotPopupActivated() to anything, expect into QPopupMenus which are in containers. Use slotActivated instead."<<endl;
-  emit activated( TDEAction::PopupMenuActivation, Qt::NoButton );
+  emit activated( TDEAction::PopupMenuActivation, TQt::NoButton );
   slotActivated();
 }
 
@@ -1159,7 +1159,7 @@ void TDEAction::slotButtonClicked( int, TQt::ButtonState state )
   emit activated( TDEAction::ToolBarActivation, state );
 
   // RightButton isn't really an activation
-  if ( ( state & Qt::LeftButton ) || ( state & Qt::MidButton ) )
+  if ( ( state & TQt::LeftButton ) || ( state & TQt::MidButton ) )
     slotActivated();
 }
 
@@ -1167,7 +1167,7 @@ void TDEAction::slotButtonClicked( int, TQt::ButtonState state )
 void TDEAction::slotDestroyed()
 {
   kdDebug(129) << "TDEAction::slotDestroyed(): this = " << this << ", name = \"" << name() << "\", sender = " << sender() << endl;
-  const TQObject* const o = TQT_TQOBJECT_CONST(sender());
+  const TQObject* const o = sender();
 
 #ifndef KDE_NO_COMPAT  // KDE 4: remove
   if ( o == d->m_tdeaccel )
@@ -1184,7 +1184,7 @@ void TDEAction::slotDestroyed()
   {
     if ( o == *itr )
     {
-      disconnect( *itr, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotDestroyed()) );
+      disconnect( *itr, TQ_SIGNAL(destroyed()), this, TQ_SLOT(slotDestroyed()) );
       accelList.remove(itr);
       return;
     }
@@ -1193,7 +1193,7 @@ void TDEAction::slotDestroyed()
   int i;
   do
   {
-    i = findContainer( TQT_TQWIDGET_CONST( static_cast<const QObject*>(o) ) );
+    i = findContainer(  static_cast<const TQWidget*>(o)  );
     if ( i != -1 )
       removeContainer( i );
   } while ( i != -1 );
