@@ -504,7 +504,7 @@ void Lexer::resetSkipWords()
 
 void Lexer::addSkipWord( const TQString& word, SkipType skipType, const TQString& str )
 {
-    m_words[ word ] = tqMakePair( skipType, str );
+    m_words[ word ] = qMakePair( skipType, str );
 }
 
 void Lexer::skip( int l, int r )
