@@ -20,7 +20,7 @@ information about setting up the cvs repository.
 */
 class CvsForm : public CvsFormBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CvsForm( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
